<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'puss: person, person, ljus hy, mellanljus hy',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'puss: person, person, ljus hy, mellanfärgad hy',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'puss: person, person, ljus hy, mellanmörk hy',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'puss: person, person, ljus hy, mörk hy',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'puss: person, person, mellanljus hy, ljus hy',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'puss: person, person, mellanljus hy, mellanfärgad hy',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'puss: person, person, mellanljus hy, mellanmörk hy',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'puss: person, person, mellanljus hy, mörk hy',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'puss: person, person, mellanfärgad hy, ljus hy',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'puss: person, person, mellanfärgad hy, mellanljus hy',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'puss: person, person, mellanfärgad hy, mellanmörk hy',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'puss: person, person, mellanfärgad hy, mörk hy',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'puss: person, person, mellanmörk hy, ljus hy',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'puss: person, person, mellanmörk hy, mellanljus hy',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'puss: person, person, mellanmörk hy, mellanfärgad hy',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'puss: person, person, mellanmörk hy, mörk hy',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'puss: person, person, mörk hy, ljus hy',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'puss: person, person, mörk hy, mellanljus hy',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'puss: person, person, mörk hy, mellanfärgad hy',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'puss: person, person, mörk hy, mellanmörk hy',
    '👨🏻‍❤‍💋‍👨🏻' => 'puss: man, man, ljus hy',
    '👨🏻‍❤‍💋‍👨🏼' => 'puss: man, man, ljus hy, mellanljus hy',
    '👨🏻‍❤‍💋‍👨🏽' => 'puss: man, man, ljus hy, mellanfärgad hy',
    '👨🏻‍❤‍💋‍👨🏾' => 'puss: man, man, ljus hy, mellanmörk hy',
    '👨🏻‍❤‍💋‍👨🏿' => 'puss: man, man, ljus hy, mörk hy',
    '👨🏼‍❤‍💋‍👨🏻' => 'puss: man, man, mellanljus hy, ljus hy',
    '👨🏼‍❤‍💋‍👨🏼' => 'puss: man, man, mellanljus hy',
    '👨🏼‍❤‍💋‍👨🏽' => 'puss: man, man, mellanljus hy, mellanfärgad hy',
    '👨🏼‍❤‍💋‍👨🏾' => 'puss: man, man, mellanljus hy, mellanmörk hy',
    '👨🏼‍❤‍💋‍👨🏿' => 'puss: man, man, mellanljus hy, mörk hy',
    '👨🏽‍❤‍💋‍👨🏻' => 'puss: man, man, mellanfärgad hy, ljus hy',
    '👨🏽‍❤‍💋‍👨🏼' => 'puss: man, man, mellanfärgad hy, mellanljus hy',
    '👨🏽‍❤‍💋‍👨🏽' => 'puss: man, man, mellanfärgad hy',
    '👨🏽‍❤‍💋‍👨🏾' => 'puss: man, man, mellanfärgad hy, mellanmörk hy',
    '👨🏽‍❤‍💋‍👨🏿' => 'puss: man, man, mellanfärgad hy, mörk hy',
    '👨🏾‍❤‍💋‍👨🏻' => 'puss: man, man, mellanmörk hy, ljus hy',
    '👨🏾‍❤‍💋‍👨🏼' => 'puss: man, man, mellanmörk hy, mellanljus hy',
    '👨🏾‍❤‍💋‍👨🏽' => 'puss: man, man, mellanmörk hy, mellanfärgad hy',
    '👨🏾‍❤‍💋‍👨🏾' => 'puss: man, man, mellanmörk hy',
    '👨🏾‍❤‍💋‍👨🏿' => 'puss: man, man, mellanmörk hy, mörk hy',
    '👨🏿‍❤‍💋‍👨🏻' => 'puss: man, man, mörk hy, ljus hy',
    '👨🏿‍❤‍💋‍👨🏼' => 'puss: man, man, mörk hy, mellanljus hy',
    '👨🏿‍❤‍💋‍👨🏽' => 'puss: man, man, mörk hy, mellanfärgad hy',
    '👨🏿‍❤‍💋‍👨🏾' => 'puss: man, man, mörk hy, mellanmörk hy',
    '👨🏿‍❤‍💋‍👨🏿' => 'puss: man, man, mörk hy',
    '👩🏻‍❤‍💋‍👨🏻' => 'puss: kvinna, man, ljus hy',
    '👩🏻‍❤‍💋‍👨🏼' => 'puss: kvinna, man, ljus hy, mellanljus hy',
    '👩🏻‍❤‍💋‍👨🏽' => 'puss: kvinna, man, ljus hy, mellanfärgad hy',
    '👩🏻‍❤‍💋‍👨🏾' => 'puss: kvinna, man, ljus hy, mellanmörk hy',
    '👩🏻‍❤‍💋‍👨🏿' => 'puss: kvinna, man, ljus hy, mörk hy',
    '👩🏼‍❤‍💋‍👨🏻' => 'puss: kvinna, man, mellanljus hy, ljus hy',
    '👩🏼‍❤‍💋‍👨🏼' => 'puss: kvinna, man, mellanljus hy',
    '👩🏼‍❤‍💋‍👨🏽' => 'puss: kvinna, man, mellanljus hy, mellanfärgad hy',
    '👩🏼‍❤‍💋‍👨🏾' => 'puss: kvinna, man, mellanljus hy, mellanmörk hy',
    '👩🏼‍❤‍💋‍👨🏿' => 'puss: kvinna, man, mellanljus hy, mörk hy',
    '👩🏽‍❤‍💋‍👨🏻' => 'puss: kvinna, man, mellanfärgad hy, ljus hy',
    '👩🏽‍❤‍💋‍👨🏼' => 'puss: kvinna, man, mellanfärgad hy, mellanljus hy',
    '👩🏽‍❤‍💋‍👨🏽' => 'puss: kvinna, man, mellanfärgad hy',
    '👩🏽‍❤‍💋‍👨🏾' => 'puss: kvinna, man, mellanfärgad hy, mellanmörk hy',
    '👩🏽‍❤‍💋‍👨🏿' => 'puss: kvinna, man, mellanfärgad hy, mörk hy',
    '👩🏾‍❤‍💋‍👨🏻' => 'puss: kvinna, man, mellanmörk hy, ljus hy',
    '👩🏾‍❤‍💋‍👨🏼' => 'puss: kvinna, man, mellanmörk hy, mellanljus hy',
    '👩🏾‍❤‍💋‍👨🏽' => 'puss: kvinna, man, mellanmörk hy, mellanfärgad hy',
    '👩🏾‍❤‍💋‍👨🏾' => 'puss: kvinna, man, mellanmörk hy',
    '👩🏾‍❤‍💋‍👨🏿' => 'puss: kvinna, man, mellanmörk hy, mörk hy',
    '👩🏿‍❤‍💋‍👨🏻' => 'puss: kvinna, man, mörk hy, ljus hy',
    '👩🏿‍❤‍💋‍👨🏼' => 'puss: kvinna, man, mörk hy, mellanljus hy',
    '👩🏿‍❤‍💋‍👨🏽' => 'puss: kvinna, man, mörk hy, mellanfärgad hy',
    '👩🏿‍❤‍💋‍👨🏾' => 'puss: kvinna, man, mörk hy, mellanmörk hy',
    '👩🏿‍❤‍💋‍👨🏿' => 'puss: kvinna, man, mörk hy',
    '👩🏻‍❤‍💋‍👩🏻' => 'puss: kvinna, kvinna, ljus hy',
    '👩🏻‍❤‍💋‍👩🏼' => 'puss: kvinna, kvinna, ljus hy, mellanljus hy',
    '👩🏻‍❤‍💋‍👩🏽' => 'puss: kvinna, kvinna, ljus hy, mellanfärgad hy',
    '👩🏻‍❤‍💋‍👩🏾' => 'puss: kvinna, kvinna, ljus hy, mellanmörk hy',
    '👩🏻‍❤‍💋‍👩🏿' => 'puss: kvinna, kvinna, ljus hy, mörk hy',
    '👩🏼‍❤‍💋‍👩🏻' => 'puss: kvinna, kvinna, mellanljus hy, ljus hy',
    '👩🏼‍❤‍💋‍👩🏼' => 'puss: kvinna, kvinna, mellanljus hy',
    '👩🏼‍❤‍💋‍👩🏽' => 'puss: kvinna, kvinna, mellanljus hy, mellanfärgad hy',
    '👩🏼‍❤‍💋‍👩🏾' => 'puss: kvinna, kvinna, mellanljus hy, mellanmörk hy',
    '👩🏼‍❤‍💋‍👩🏿' => 'puss: kvinna, kvinna, mellanljus hy, mörk hy',
    '👩🏽‍❤‍💋‍👩🏻' => 'puss: kvinna, kvinna, mellanfärgad hy, ljus hy',
    '👩🏽‍❤‍💋‍👩🏼' => 'puss: kvinna, kvinna, mellanfärgad hy, mellanljus hy',
    '👩🏽‍❤‍💋‍👩🏽' => 'puss: kvinna, kvinna, mellanfärgad hy',
    '👩🏽‍❤‍💋‍👩🏾' => 'puss: kvinna, kvinna, mellanfärgad hy, mellanmörk hy',
    '👩🏽‍❤‍💋‍👩🏿' => 'puss: kvinna, kvinna, mellanfärgad hy, mörk hy',
    '👩🏾‍❤‍💋‍👩🏻' => 'puss: kvinna, kvinna, mellanmörk hy, ljus hy',
    '👩🏾‍❤‍💋‍👩🏼' => 'puss: kvinna, kvinna, mellanmörk hy, mellanljus hy',
    '👩🏾‍❤‍💋‍👩🏽' => 'puss: kvinna, kvinna, mellanmörk hy, mellanfärgad hy',
    '👩🏾‍❤‍💋‍👩🏾' => 'puss: kvinna, kvinna, mellanmörk hy',
    '👩🏾‍❤‍💋‍👩🏿' => 'puss: kvinna, kvinna, mellanmörk hy, mörk hy',
    '👩🏿‍❤‍💋‍👩🏻' => 'puss: kvinna, kvinna, mörk hy, ljus hy',
    '👩🏿‍❤‍💋‍👩🏼' => 'puss: kvinna, kvinna, mörk hy, mellanljus hy',
    '👩🏿‍❤‍💋‍👩🏽' => 'puss: kvinna, kvinna, mörk hy, mellanfärgad hy',
    '👩🏿‍❤‍💋‍👩🏾' => 'puss: kvinna, kvinna, mörk hy, mellanmörk hy',
    '👩🏿‍❤‍💋‍👩🏿' => 'puss: kvinna, kvinna, mörk hy',
    '🧑🏻‍🫯‍🧑🏼' => 'brottande personer: ljus hy, mellanljus hy',
    '🧑🏻‍🫯‍🧑🏽' => 'brottande personer: ljus hy, mellanfärgad hy',
    '🧑🏻‍🫯‍🧑🏾' => 'brottande personer: ljus hy, mellanmörk hy',
    '🧑🏻‍🫯‍🧑🏿' => 'brottande personer: ljus hy, mörk hy',
    '🧑🏼‍🫯‍🧑🏻' => 'brottande personer: mellanljus hy, ljus hy',
    '🧑🏼‍🫯‍🧑🏽' => 'brottande personer: mellanljus hy, mellanfärgad hy',
    '🧑🏼‍🫯‍🧑🏾' => 'brottande personer: mellanljus hy, mellanmörk hy',
    '🧑🏼‍🫯‍🧑🏿' => 'brottande personer: mellanljus hy, mörk hy',
    '🧑🏽‍🫯‍🧑🏻' => 'brottande personer: mellanfärgad hy, ljus hy',
    '🧑🏽‍🫯‍🧑🏼' => 'brottande personer: mellanfärgad hy, mellanljus hy',
    '🧑🏽‍🫯‍🧑🏾' => 'brottande personer: mellanfärgad hy, mellanmörk hy',
    '🧑🏽‍🫯‍🧑🏿' => 'brottande personer: mellanfärgad hy, mörk hy',
    '🧑🏾‍🫯‍🧑🏻' => 'brottande personer: mellanmörk hy, ljus hy',
    '🧑🏾‍🫯‍🧑🏼' => 'brottande personer: mellanmörk hy, mellanljus hy',
    '🧑🏾‍🫯‍🧑🏽' => 'brottande personer: mellanmörk hy, mellanfärgad hy',
    '🧑🏾‍🫯‍🧑🏿' => 'brottande personer: mellanmörk hy, mörk hy',
    '🧑🏿‍🫯‍🧑🏻' => 'brottande personer: mörk hy, ljus hy',
    '🧑🏿‍🫯‍🧑🏼' => 'brottande personer: mörk hy, mellanljus hy',
    '🧑🏿‍🫯‍🧑🏽' => 'brottande personer: mörk hy, mellanfärgad hy',
    '🧑🏿‍🫯‍🧑🏾' => 'brottande personer: mörk hy, mellanmörk hy',
    '🧑🏻‍❤‍🧑🏼' => 'par med hjärta: person, person, ljus hy, mellanljus hy',
    '🧑🏻‍❤‍🧑🏽' => 'par med hjärta: person, person, ljus hy, mellanfärgad hy',
    '🧑🏻‍❤‍🧑🏾' => 'par med hjärta: person, person, ljus hy, mellanmörk hy',
    '🧑🏻‍❤‍🧑🏿' => 'par med hjärta: person, person, ljus hy, mörk hy',
    '🧑🏼‍❤‍🧑🏻' => 'par med hjärta: person, person, mellanljus hy, ljus hy',
    '🧑🏼‍❤‍🧑🏽' => 'par med hjärta: person, person, mellanljus hy, mellanfärgad hy',
    '🧑🏼‍❤‍🧑🏾' => 'par med hjärta: person, person, mellanljus hy, mellanmörk hy',
    '🧑🏼‍❤‍🧑🏿' => 'par med hjärta: person, person, mellanljus hy, mörk hy',
    '🧑🏽‍❤‍🧑🏻' => 'par med hjärta: person, person, mellanfärgad hy, ljus hy',
    '🧑🏽‍❤‍🧑🏼' => 'par med hjärta: person, person, mellanfärgad hy, mellanljus hy',
    '🧑🏽‍❤‍🧑🏾' => 'par med hjärta: person, person, mellanfärgad hy, mellanmörk hy',
    '🧑🏽‍❤‍🧑🏿' => 'par med hjärta: person, person, mellanfärgad hy, mörk hy',
    '🧑🏾‍❤‍🧑🏻' => 'par med hjärta: person, person, mellanmörk hy, ljus hy',
    '🧑🏾‍❤‍🧑🏼' => 'par med hjärta: person, person, mellanmörk hy, mellanljus hy',
    '🧑🏾‍❤‍🧑🏽' => 'par med hjärta: person, person, mellanmörk hy, mellanfärgad hy',
    '🧑🏾‍❤‍🧑🏿' => 'par med hjärta: person, person, mellanmörk hy, mörk hy',
    '🧑🏿‍❤‍🧑🏻' => 'par med hjärta: person, person, mörk hy, ljus hy',
    '🧑🏿‍❤‍🧑🏼' => 'par med hjärta: person, person, mörk hy, mellanljus hy',
    '🧑🏿‍❤‍🧑🏽' => 'par med hjärta: person, person, mörk hy, mellanfärgad hy',
    '🧑🏿‍❤‍🧑🏾' => 'par med hjärta: person, person, mörk hy, mellanmörk hy',
    '🧑🏻‍🐰‍🧑🏼' => 'personer med kaninöron: ljus hy, mellanljus hy',
    '🧑🏻‍🐰‍🧑🏽' => 'personer med kaninöron: ljus hy, mellanfärgad hy',
    '🧑🏻‍🐰‍🧑🏾' => 'personer med kaninöron: ljus hy, mellanmörk hy',
    '🧑🏻‍🐰‍🧑🏿' => 'personer med kaninöron: ljus hy, mörk hy',
    '🧑🏼‍🐰‍🧑🏻' => 'personer med kaninöron: mellanljus hy, ljus hy',
    '🧑🏼‍🐰‍🧑🏽' => 'personer med kaninöron: mellanljus hy, mellanfärgad hy',
    '🧑🏼‍🐰‍🧑🏾' => 'personer med kaninöron: mellanljus hy, mellanmörk hy',
    '🧑🏼‍🐰‍🧑🏿' => 'personer med kaninöron: mellanljus hy, mörk hy',
    '🧑🏽‍🐰‍🧑🏻' => 'personer med kaninöron: mellanfärgad hy, ljus hy',
    '🧑🏽‍🐰‍🧑🏼' => 'personer med kaninöron: mellanfärgad hy, mellanljus hy',
    '🧑🏽‍🐰‍🧑🏾' => 'personer med kaninöron: mellanfärgad hy, mellanmörk hy',
    '🧑🏽‍🐰‍🧑🏿' => 'personer med kaninöron: mellanfärgad hy, mörk hy',
    '🧑🏾‍🐰‍🧑🏻' => 'personer med kaninöron: mellanmörk hy, ljus hy',
    '🧑🏾‍🐰‍🧑🏼' => 'personer med kaninöron: mellanmörk hy, mellanljus hy',
    '🧑🏾‍🐰‍🧑🏽' => 'personer med kaninöron: mellanmörk hy, mellanfärgad hy',
    '🧑🏾‍🐰‍🧑🏿' => 'personer med kaninöron: mellanmörk hy, mörk hy',
    '🧑🏿‍🐰‍🧑🏻' => 'personer med kaninöron: mörk hy, ljus hy',
    '🧑🏿‍🐰‍🧑🏼' => 'personer med kaninöron: mörk hy, mellanljus hy',
    '🧑🏿‍🐰‍🧑🏽' => 'personer med kaninöron: mörk hy, mellanfärgad hy',
    '🧑🏿‍🐰‍🧑🏾' => 'personer med kaninöron: mörk hy, mellanmörk hy',
    '👨🏻‍🫯‍👨🏼' => 'brottande män: ljus hy, mellanljus hy',
    '👨🏻‍🫯‍👨🏽' => 'brottande män: ljus hy, mellanfärgad hy',
    '👨🏻‍🫯‍👨🏾' => 'brottande män: ljus hy, mellanmörk hy',
    '👨🏻‍🫯‍👨🏿' => 'brottande män: ljus hy, mörk hy',
    '👨🏼‍🫯‍👨🏻' => 'brottande män: mellanljus hy, ljus hy',
    '👨🏼‍🫯‍👨🏽' => 'brottande män: mellanljus hy, mellanfärgad hy',
    '👨🏼‍🫯‍👨🏾' => 'brottande män: mellanljus hy, mellanmörk hy',
    '👨🏼‍🫯‍👨🏿' => 'brottande män: mellanljus hy, mörk hy',
    '👨🏽‍🫯‍👨🏻' => 'brottande män: mellanfärgad hy, ljus hy',
    '👨🏽‍🫯‍👨🏼' => 'brottande män: mellanfärgad hy, mellanljus hy',
    '👨🏽‍🫯‍👨🏾' => 'brottande män: mellanfärgad hy, mellanmörk hy',
    '👨🏽‍🫯‍👨🏿' => 'brottande män: mellanfärgad hy, mörk hy',
    '👨🏾‍🫯‍👨🏻' => 'brottande män: mellanmörk hy, ljus hy',
    '👨🏾‍🫯‍👨🏼' => 'brottande män: mellanmörk hy, mellanljus hy',
    '👨🏾‍🫯‍👨🏽' => 'brottande män: mellanmörk hy, mellanfärgad hy',
    '👨🏾‍🫯‍👨🏿' => 'brottande män: mellanmörk hy, mörk hy',
    '👨🏿‍🫯‍👨🏻' => 'brottande män: mörk hy, ljus hy',
    '👨🏿‍🫯‍👨🏼' => 'brottande män: mörk hy, mellanljus hy',
    '👨🏿‍🫯‍👨🏽' => 'brottande män: mörk hy, mellanfärgad hy',
    '👨🏿‍🫯‍👨🏾' => 'brottande män: mörk hy, mellanmörk hy',
    '👨🏻‍❤‍👨🏻' => 'par med hjärta: man, man, ljus hy',
    '👨🏻‍❤‍👨🏼' => 'par med hjärta: man, man, ljus hy, mellanljus hy',
    '👨🏻‍❤‍👨🏽' => 'par med hjärta: man, man, ljus hy, mellanfärgad hy',
    '👨🏻‍❤‍👨🏾' => 'par med hjärta: man, man, ljus hy, mellanmörk hy',
    '👨🏻‍❤‍👨🏿' => 'par med hjärta: man, man, ljus hy, mörk hy',
    '👨🏼‍❤‍👨🏻' => 'par med hjärta: man, man, mellanljus hy, ljus hy',
    '👨🏼‍❤‍👨🏼' => 'par med hjärta: man, man, mellanljus hy',
    '👨🏼‍❤‍👨🏽' => 'par med hjärta: man, man, mellanljus hy, mellanfärgad hy',
    '👨🏼‍❤‍👨🏾' => 'par med hjärta: man, man, mellanljus hy, mellanmörk hy',
    '👨🏼‍❤‍👨🏿' => 'par med hjärta: man, man, mellanljus hy, mörk hy',
    '👨🏽‍❤‍👨🏻' => 'par med hjärta: man, man, mellanfärgad hy, ljus hy',
    '👨🏽‍❤‍👨🏼' => 'par med hjärta: man, man, mellanfärgad hy, mellanljus hy',
    '👨🏽‍❤‍👨🏽' => 'par med hjärta: man, man, mellanfärgad hy',
    '👨🏽‍❤‍👨🏾' => 'par med hjärta: man, man, mellanfärgad hy, mellanmörk hy',
    '👨🏽‍❤‍👨🏿' => 'par med hjärta: man, man, mellanfärgad hy, mörk hy',
    '👨🏾‍❤‍👨🏻' => 'par med hjärta: man, man, mellanmörk hy, ljus hy',
    '👨🏾‍❤‍👨🏼' => 'par med hjärta: man, man, mellanmörk hy, mellanljus hy',
    '👨🏾‍❤‍👨🏽' => 'par med hjärta: man, man, mellanmörk hy, mellanfärgad hy',
    '👨🏾‍❤‍👨🏾' => 'par med hjärta: man, man, mellanmörk hy',
    '👨🏾‍❤‍👨🏿' => 'par med hjärta: man, man, mellanmörk hy, mörk hy',
    '👨🏿‍❤‍👨🏻' => 'par med hjärta: man, man, mörk hy, ljus hy',
    '👨🏿‍❤‍👨🏼' => 'par med hjärta: man, man, mörk hy, mellanljus hy',
    '👨🏿‍❤‍👨🏽' => 'par med hjärta: man, man, mörk hy, mellanfärgad hy',
    '👨🏿‍❤‍👨🏾' => 'par med hjärta: man, man, mörk hy, mellanmörk hy',
    '👨🏿‍❤‍👨🏿' => 'par med hjärta: man, man, mörk hy',
    '👨🏻‍🐰‍👨🏼' => 'män med kaninöron: ljus hy, mellanljus hy',
    '👨🏻‍🐰‍👨🏽' => 'män med kaninöron: ljus hy, mellanfärgad hy',
    '👨🏻‍🐰‍👨🏾' => 'män med kaninöron: ljus hy, mellanmörk hy',
    '👨🏻‍🐰‍👨🏿' => 'män med kaninöron: ljus hy, mörk hy',
    '👨🏼‍🐰‍👨🏻' => 'män med kaninöron: mellanljus hy, ljus hy',
    '👨🏼‍🐰‍👨🏽' => 'män med kaninöron: mellanljus hy, mellanfärgad hy',
    '👨🏼‍🐰‍👨🏾' => 'män med kaninöron: mellanljus hy, mellanmörk hy',
    '👨🏼‍🐰‍👨🏿' => 'män med kaninöron: mellanljus hy, mörk hy',
    '👨🏽‍🐰‍👨🏻' => 'män med kaninöron: mellanfärgad hy, ljus hy',
    '👨🏽‍🐰‍👨🏼' => 'män med kaninöron: mellanfärgad hy, mellanljus hy',
    '👨🏽‍🐰‍👨🏾' => 'män med kaninöron: mellanfärgad hy, mellanmörk hy',
    '👨🏽‍🐰‍👨🏿' => 'män med kaninöron: mellanfärgad hy, mörk hy',
    '👨🏾‍🐰‍👨🏻' => 'män med kaninöron: mellanmörk hy, ljus hy',
    '👨🏾‍🐰‍👨🏼' => 'män med kaninöron: mellanmörk hy, mellanljus hy',
    '👨🏾‍🐰‍👨🏽' => 'män med kaninöron: mellanmörk hy, mellanfärgad hy',
    '👨🏾‍🐰‍👨🏿' => 'män med kaninöron: mellanmörk hy, mörk hy',
    '👨🏿‍🐰‍👨🏻' => 'män med kaninöron: mörk hy, ljus hy',
    '👨🏿‍🐰‍👨🏼' => 'män med kaninöron: mörk hy, mellanljus hy',
    '👨🏿‍🐰‍👨🏽' => 'män med kaninöron: mörk hy, mellanfärgad hy',
    '👨🏿‍🐰‍👨🏾' => 'män med kaninöron: mörk hy, mellanmörk hy',
    '👩🏻‍🫯‍👩🏼' => 'brottande kvinnor: ljus hy, mellanljus hy',
    '👩🏻‍🫯‍👩🏽' => 'brottande kvinnor: ljus hy, mellanfärgad hy',
    '👩🏻‍🫯‍👩🏾' => 'brottande kvinnor: ljus hy, mellanmörk hy',
    '👩🏻‍🫯‍👩🏿' => 'brottande kvinnor: ljus hy, mörk hy',
    '👩🏼‍🫯‍👩🏻' => 'brottande kvinnor: mellanljus hy, ljus hy',
    '👩🏼‍🫯‍👩🏽' => 'brottande kvinnor: mellanljus hy, mellanfärgad hy',
    '👩🏼‍🫯‍👩🏾' => 'brottande kvinnor: mellanljus hy, mellanmörk hy',
    '👩🏼‍🫯‍👩🏿' => 'brottande kvinnor: mellanljus hy, mörk hy',
    '👩🏽‍🫯‍👩🏻' => 'brottande kvinnor: mellanfärgad hy, ljus hy',
    '👩🏽‍🫯‍👩🏼' => 'brottande kvinnor: mellanfärgad hy, mellanljus hy',
    '👩🏽‍🫯‍👩🏾' => 'brottande kvinnor: mellanfärgad hy, mellanmörk hy',
    '👩🏽‍🫯‍👩🏿' => 'brottande kvinnor: mellanfärgad hy, mörk hy',
    '👩🏾‍🫯‍👩🏻' => 'brottande kvinnor: mellanmörk hy, ljus hy',
    '👩🏾‍🫯‍👩🏼' => 'brottande kvinnor: mellanmörk hy, mellanljus hy',
    '👩🏾‍🫯‍👩🏽' => 'brottande kvinnor: mellanmörk hy, mellanfärgad hy',
    '👩🏾‍🫯‍👩🏿' => 'brottande kvinnor: mellanmörk hy, mörk hy',
    '👩🏿‍🫯‍👩🏻' => 'brottande kvinnor: mörk hy, ljus hy',
    '👩🏿‍🫯‍👩🏼' => 'brottande kvinnor: mörk hy, mellanljus hy',
    '👩🏿‍🫯‍👩🏽' => 'brottande kvinnor: mörk hy, mellanfärgad hy',
    '👩🏿‍🫯‍👩🏾' => 'brottande kvinnor: mörk hy, mellanmörk hy',
    '👩🏻‍❤‍👨🏻' => 'par med hjärta: kvinna, man, ljus hy',
    '👩🏻‍❤‍👨🏼' => 'par med hjärta: kvinna, man, ljus hy, mellanljus hy',
    '👩🏻‍❤‍👨🏽' => 'par med hjärta: kvinna, man, ljus hy, mellanfärgad hy',
    '👩🏻‍❤‍👨🏾' => 'par med hjärta: kvinna, man, ljus hy, mellanmörk hy',
    '👩🏻‍❤‍👨🏿' => 'par med hjärta: kvinna, man, ljus hy, mörk hy',
    '👩🏼‍❤‍👨🏻' => 'par med hjärta: kvinna, man, mellanljus hy, ljus hy',
    '👩🏼‍❤‍👨🏼' => 'par med hjärta: kvinna, man, mellanljus hy',
    '👩🏼‍❤‍👨🏽' => 'par med hjärta: kvinna, man, mellanljus hy, mellanfärgad hy',
    '👩🏼‍❤‍👨🏾' => 'par med hjärta: kvinna, man, mellanljus hy, mellanmörk hy',
    '👩🏼‍❤‍👨🏿' => 'par med hjärta: kvinna, man, mellanljus hy, mörk hy',
    '👩🏽‍❤‍👨🏻' => 'par med hjärta: kvinna, man, mellanfärgad hy, ljus hy',
    '👩🏽‍❤‍👨🏼' => 'par med hjärta: kvinna, man, mellanfärgad hy, mellanljus hy',
    '👩🏽‍❤‍👨🏽' => 'par med hjärta: kvinna, man, mellanfärgad hy',
    '👩🏽‍❤‍👨🏾' => 'par med hjärta: kvinna, man, mellanfärgad hy, mellanmörk hy',
    '👩🏽‍❤‍👨🏿' => 'par med hjärta: kvinna, man, mellanfärgad hy, mörk hy',
    '👩🏾‍❤‍👨🏻' => 'par med hjärta: kvinna, man, mellanmörk hy, ljus hy',
    '👩🏾‍❤‍👨🏼' => 'par med hjärta: kvinna, man, mellanmörk hy, mellanljus hy',
    '👩🏾‍❤‍👨🏽' => 'par med hjärta: kvinna, man, mellanmörk hy, mellanfärgad hy',
    '👩🏾‍❤‍👨🏾' => 'par med hjärta: kvinna, man, mellanmörk hy',
    '👩🏾‍❤‍👨🏿' => 'par med hjärta: kvinna, man, mellanmörk hy, mörk hy',
    '👩🏿‍❤‍👨🏻' => 'par med hjärta: kvinna, man, mörk hy, ljus hy',
    '👩🏿‍❤‍👨🏼' => 'par med hjärta: kvinna, man, mörk hy, mellanljus hy',
    '👩🏿‍❤‍👨🏽' => 'par med hjärta: kvinna, man, mörk hy, mellanfärgad hy',
    '👩🏿‍❤‍👨🏾' => 'par med hjärta: kvinna, man, mörk hy, mellanmörk hy',
    '👩🏿‍❤‍👨🏿' => 'par med hjärta: kvinna, man, mörk hy',
    '👩🏻‍❤‍👩🏻' => 'par med hjärta: kvinna, kvinna, ljus hy',
    '👩🏻‍❤‍👩🏼' => 'par med hjärta: kvinna, kvinna, ljus hy, mellanljus hy',
    '👩🏻‍❤‍👩🏽' => 'par med hjärta: kvinna, kvinna, ljus hy, mellanfärgad hy',
    '👩🏻‍❤‍👩🏾' => 'par med hjärta: kvinna, kvinna, ljus hy, mellanmörk hy',
    '👩🏻‍❤‍👩🏿' => 'par med hjärta: kvinna, kvinna, ljus hy, mörk hy',
    '👩🏼‍❤‍👩🏻' => 'par med hjärta: kvinna, kvinna, mellanljus hy, ljus hy',
    '👩🏼‍❤‍👩🏼' => 'par med hjärta: kvinna, kvinna, mellanljus hy',
    '👩🏼‍❤‍👩🏽' => 'par med hjärta: kvinna, kvinna, mellanljus hy, mellanfärgad hy',
    '👩🏼‍❤‍👩🏾' => 'par med hjärta: kvinna, kvinna, mellanljus hy, mellanmörk hy',
    '👩🏼‍❤‍👩🏿' => 'par med hjärta: kvinna, kvinna, mellanljus hy, mörk hy',
    '👩🏽‍❤‍👩🏻' => 'par med hjärta: kvinna, kvinna, mellanfärgad hy, ljus hy',
    '👩🏽‍❤‍👩🏼' => 'par med hjärta: kvinna, kvinna, mellanfärgad hy, mellanljus hy',
    '👩🏽‍❤‍👩🏽' => 'par med hjärta: kvinna, kvinna, mellanfärgad hy',
    '👩🏽‍❤‍👩🏾' => 'par med hjärta: kvinna, kvinna, mellanfärgad hy, mellanmörk hy',
    '👩🏽‍❤‍👩🏿' => 'par med hjärta: kvinna, kvinna, mellanfärgad hy, mörk hy',
    '👩🏾‍❤‍👩🏻' => 'par med hjärta: kvinna, kvinna, mellanmörk hy, ljus hy',
    '👩🏾‍❤‍👩🏼' => 'par med hjärta: kvinna, kvinna, mellanmörk hy, mellanljus hy',
    '👩🏾‍❤‍👩🏽' => 'par med hjärta: kvinna, kvinna, mellanmörk hy, mellanfärgad hy',
    '👩🏾‍❤‍👩🏾' => 'par med hjärta: kvinna, kvinna, mellanmörk hy',
    '👩🏾‍❤‍👩🏿' => 'par med hjärta: kvinna, kvinna, mellanmörk hy, mörk hy',
    '👩🏿‍❤‍👩🏻' => 'par med hjärta: kvinna, kvinna, mörk hy, ljus hy',
    '👩🏿‍❤‍👩🏼' => 'par med hjärta: kvinna, kvinna, mörk hy, mellanljus hy',
    '👩🏿‍❤‍👩🏽' => 'par med hjärta: kvinna, kvinna, mörk hy, mellanfärgad hy',
    '👩🏿‍❤‍👩🏾' => 'par med hjärta: kvinna, kvinna, mörk hy, mellanmörk hy',
    '👩🏿‍❤‍👩🏿' => 'par med hjärta: kvinna, kvinna, mörk hy',
    '👩🏻‍🐰‍👩🏼' => 'kvinnor med kaninöron: ljus hy, mellanljus hy',
    '👩🏻‍🐰‍👩🏽' => 'kvinnor med kaninöron: ljus hy, mellanfärgad hy',
    '👩🏻‍🐰‍👩🏾' => 'kvinnor med kaninöron: ljus hy, mellanmörk hy',
    '👩🏻‍🐰‍👩🏿' => 'kvinnor med kaninöron: ljus hy, mörk hy',
    '👩🏼‍🐰‍👩🏻' => 'kvinnor med kaninöron: mellanljus hy, ljus hy',
    '👩🏼‍🐰‍👩🏽' => 'kvinnor med kaninöron: mellanljus hy, mellanfärgad hy',
    '👩🏼‍🐰‍👩🏾' => 'kvinnor med kaninöron: mellanljus hy, mellanmörk hy',
    '👩🏼‍🐰‍👩🏿' => 'kvinnor med kaninöron: mellanljus hy, mörk hy',
    '👩🏽‍🐰‍👩🏻' => 'kvinnor med kaninöron: mellanfärgad hy, ljus hy',
    '👩🏽‍🐰‍👩🏼' => 'kvinnor med kaninöron: mellanfärgad hy, mellanljus hy',
    '👩🏽‍🐰‍👩🏾' => 'kvinnor med kaninöron: mellanfärgad hy, mellanmörk hy',
    '👩🏽‍🐰‍👩🏿' => 'kvinnor med kaninöron: mellanfärgad hy, mörk hy',
    '👩🏾‍🐰‍👩🏻' => 'kvinnor med kaninöron: mellanmörk hy, ljus hy',
    '👩🏾‍🐰‍👩🏼' => 'kvinnor med kaninöron: mellanmörk hy, mellanljus hy',
    '👩🏾‍🐰‍👩🏽' => 'kvinnor med kaninöron: mellanmörk hy, mellanfärgad hy',
    '👩🏾‍🐰‍👩🏿' => 'kvinnor med kaninöron: mellanmörk hy, mörk hy',
    '👩🏿‍🐰‍👩🏻' => 'kvinnor med kaninöron: mörk hy, ljus hy',
    '👩🏿‍🐰‍👩🏼' => 'kvinnor med kaninöron: mörk hy, mellanljus hy',
    '👩🏿‍🐰‍👩🏽' => 'kvinnor med kaninöron: mörk hy, mellanfärgad hy',
    '👩🏿‍🐰‍👩🏾' => 'kvinnor med kaninöron: mörk hy, mellanmörk hy',
    '🧑🏻‍🤝‍🧑🏻' => 'personer som håller hand: ljus hy',
    '🧑🏻‍🤝‍🧑🏼' => 'personer som håller hand: ljus hy, mellanljus hy',
    '🧑🏻‍🤝‍🧑🏽' => 'personer som håller hand: ljus hy, mellanfärgad hy',
    '🧑🏻‍🤝‍🧑🏾' => 'personer som håller hand: ljus hy, mellanmörk hy',
    '🧑🏻‍🤝‍🧑🏿' => 'personer som håller hand: ljus hy, mörk hy',
    '🧑🏼‍🤝‍🧑🏻' => 'personer som håller hand: mellanljus hy, ljus hy',
    '🧑🏼‍🤝‍🧑🏼' => 'personer som håller hand: mellanljus hy',
    '🧑🏼‍🤝‍🧑🏽' => 'personer som håller hand: mellanljus hy, mellanfärgad hy',
    '🧑🏼‍🤝‍🧑🏾' => 'personer som håller hand: mellanljus hy, mellanmörk hy',
    '🧑🏼‍🤝‍🧑🏿' => 'personer som håller hand: mellanljus hy, mörk hy',
    '🧑🏽‍🤝‍🧑🏻' => 'personer som håller hand: mellanfärgad hy, ljus hy',
    '🧑🏽‍🤝‍🧑🏼' => 'personer som håller hand: mellanfärgad hy, mellanljus hy',
    '🧑🏽‍🤝‍🧑🏽' => 'personer som håller hand: mellanfärgad hy',
    '🧑🏽‍🤝‍🧑🏾' => 'personer som håller hand: mellanfärgad hy, mellanmörk hy',
    '🧑🏽‍🤝‍🧑🏿' => 'personer som håller hand: mellanfärgad hy, mörk hy',
    '🧑🏾‍🤝‍🧑🏻' => 'personer som håller hand: mellanmörk hy, ljus hy',
    '🧑🏾‍🤝‍🧑🏼' => 'personer som håller hand: mellanmörk hy, mellanljus hy',
    '🧑🏾‍🤝‍🧑🏽' => 'personer som håller hand: mellanmörk hy, mellanfärgad hy',
    '🧑🏾‍🤝‍🧑🏾' => 'personer som håller hand: mellanmörk hy',
    '🧑🏾‍🤝‍🧑🏿' => 'personer som håller hand: mellanmörk hy, mörk hy',
    '🧑🏿‍🤝‍🧑🏻' => 'personer som håller hand: mörk hy, ljus hy',
    '🧑🏿‍🤝‍🧑🏼' => 'personer som håller hand: mörk hy, mellanljus hy',
    '🧑🏿‍🤝‍🧑🏽' => 'personer som håller hand: mörk hy, mellanfärgad hy',
    '🧑🏿‍🤝‍🧑🏾' => 'personer som håller hand: mörk hy, mellanmörk hy',
    '🧑🏿‍🤝‍🧑🏿' => 'personer som håller hand: mörk hy',
    '👩🏻‍🤝‍👩🏼' => 'två kvinnor håller hand: ljus hy, mellanljus hy',
    '👩🏻‍🤝‍👩🏽' => 'två kvinnor håller hand: ljus hy, mellanfärgad hy',
    '👩🏻‍🤝‍👩🏾' => 'två kvinnor håller hand: ljus hy, mellanmörk hy',
    '👩🏻‍🤝‍👩🏿' => 'två kvinnor håller hand: ljus hy, mörk hy',
    '👩🏼‍🤝‍👩🏻' => 'två kvinnor håller hand: mellanljus hy, ljus hy',
    '👩🏼‍🤝‍👩🏽' => 'två kvinnor håller hand: mellanljus hy, mellanfärgad hy',
    '👩🏼‍🤝‍👩🏾' => 'två kvinnor håller hand: mellanljus hy, mellanmörk hy',
    '👩🏼‍🤝‍👩🏿' => 'två kvinnor håller hand: mellanljus hy, mörk hy',
    '👩🏽‍🤝‍👩🏻' => 'två kvinnor håller hand: mellanfärgad hy, ljus hy',
    '👩🏽‍🤝‍👩🏼' => 'två kvinnor håller hand: mellanfärgad hy, mellanljus hy',
    '👩🏽‍🤝‍👩🏾' => 'två kvinnor håller hand: mellanfärgad hy, mellanmörk hy',
    '👩🏽‍🤝‍👩🏿' => 'två kvinnor håller hand: mellanfärgad hy, mörk hy',
    '👩🏾‍🤝‍👩🏻' => 'två kvinnor håller hand: mellanmörk hy, ljus hy',
    '👩🏾‍🤝‍👩🏼' => 'två kvinnor håller hand: mellanmörk hy, mellanljus hy',
    '👩🏾‍🤝‍👩🏽' => 'två kvinnor håller hand: mellanmörk hy, mellanfärgad hy',
    '👩🏾‍🤝‍👩🏿' => 'två kvinnor håller hand: mellanmörk hy, mörk hy',
    '👩🏿‍🤝‍👩🏻' => 'två kvinnor håller hand: mörk hy, ljus hy',
    '👩🏿‍🤝‍👩🏼' => 'två kvinnor håller hand: mörk hy, mellanljus hy',
    '👩🏿‍🤝‍👩🏽' => 'två kvinnor håller hand: mörk hy, mellanfärgad hy',
    '👩🏿‍🤝‍👩🏾' => 'två kvinnor håller hand: mörk hy, mellanmörk hy',
    '👩🏻‍🤝‍👨🏼' => 'man och kvinna håller hand: ljus hy, mellanljus hy',
    '👩🏻‍🤝‍👨🏽' => 'man och kvinna håller hand: ljus hy, mellanfärgad hy',
    '👩🏻‍🤝‍👨🏾' => 'man och kvinna håller hand: ljus hy, mellanmörk hy',
    '👩🏻‍🤝‍👨🏿' => 'man och kvinna håller hand: ljus hy, mörk hy',
    '👩🏼‍🤝‍👨🏻' => 'man och kvinna håller hand: mellanljus hy, ljus hy',
    '👩🏼‍🤝‍👨🏽' => 'man och kvinna håller hand: mellanljus hy, mellanfärgad hy',
    '👩🏼‍🤝‍👨🏾' => 'man och kvinna håller hand: mellanljus hy, mellanmörk hy',
    '👩🏼‍🤝‍👨🏿' => 'man och kvinna håller hand: mellanljus hy, mörk hy',
    '👩🏽‍🤝‍👨🏻' => 'man och kvinna håller hand: mellanfärgad hy, ljus hy',
    '👩🏽‍🤝‍👨🏼' => 'man och kvinna håller hand: mellanfärgad hy, mellanljus hy',
    '👩🏽‍🤝‍👨🏾' => 'man och kvinna håller hand: mellanfärgad hy, mellanmörk hy',
    '👩🏽‍🤝‍👨🏿' => 'man och kvinna håller hand: mellanfärgad hy, mörk hy',
    '👩🏾‍🤝‍👨🏻' => 'man och kvinna håller hand: mellanmörk hy, ljus hy',
    '👩🏾‍🤝‍👨🏼' => 'man och kvinna håller hand: mellanmörk hy, mellanljus hy',
    '👩🏾‍🤝‍👨🏽' => 'man och kvinna håller hand: mellanmörk hy, mellanfärgad hy',
    '👩🏾‍🤝‍👨🏿' => 'man och kvinna håller hand: mellanmörk hy, mörk hy',
    '👩🏿‍🤝‍👨🏻' => 'man och kvinna håller hand: mörk hy, ljus hy',
    '👩🏿‍🤝‍👨🏼' => 'man och kvinna håller hand: mörk hy, mellanljus hy',
    '👩🏿‍🤝‍👨🏽' => 'man och kvinna håller hand: mörk hy, mellanfärgad hy',
    '👩🏿‍🤝‍👨🏾' => 'man och kvinna håller hand: mörk hy, mellanmörk hy',
    '👨🏻‍🤝‍👨🏼' => 'två män håller hand: ljus hy, mellanljus hy',
    '👨🏻‍🤝‍👨🏽' => 'två män håller hand: ljus hy, mellanfärgad hy',
    '👨🏻‍🤝‍👨🏾' => 'två män håller hand: ljus hy, mellanmörk hy',
    '👨🏻‍🤝‍👨🏿' => 'två män håller hand: ljus hy, mörk hy',
    '👨🏼‍🤝‍👨🏻' => 'två män håller hand: mellanljus hy, ljus hy',
    '👨🏼‍🤝‍👨🏽' => 'två män håller hand: mellanljus hy, mellanfärgad hy',
    '👨🏼‍🤝‍👨🏾' => 'två män håller hand: mellanljus hy, mellanmörk hy',
    '👨🏼‍🤝‍👨🏿' => 'två män håller hand: mellanljus hy, mörk hy',
    '👨🏽‍🤝‍👨🏻' => 'två män håller hand: mellanfärgad hy, ljus hy',
    '👨🏽‍🤝‍👨🏼' => 'två män håller hand: mellanfärgad hy, mellanljus hy',
    '👨🏽‍🤝‍👨🏾' => 'två män håller hand: mellanfärgad hy, mellanmörk hy',
    '👨🏽‍🤝‍👨🏿' => 'två män håller hand: mellanfärgad hy, mörk hy',
    '👨🏾‍🤝‍👨🏻' => 'två män håller hand: mellanmörk hy, ljus hy',
    '👨🏾‍🤝‍👨🏼' => 'två män håller hand: mellanmörk hy, mellanljus hy',
    '👨🏾‍🤝‍👨🏽' => 'två män håller hand: mellanmörk hy, mellanfärgad hy',
    '👨🏾‍🤝‍👨🏿' => 'två män håller hand: mellanmörk hy, mörk hy',
    '👨🏿‍🤝‍👨🏻' => 'två män håller hand: mörk hy, ljus hy',
    '👨🏿‍🤝‍👨🏼' => 'två män håller hand: mörk hy, mellanljus hy',
    '👨🏿‍🤝‍👨🏽' => 'två män håller hand: mörk hy, mellanfärgad hy',
    '👨🏿‍🤝‍👨🏾' => 'två män håller hand: mörk hy, mellanmörk hy',
    '👩‍❤‍💋‍👨' => 'puss: kvinna, man',
    '👨‍❤‍💋‍👨' => 'puss: man, man',
    '👩‍❤‍💋‍👩' => 'puss: kvinna, kvinna',
    '👨‍👩‍👧‍👦' => 'familj: man, kvinna, flicka, pojke',
    '👨‍👩‍👦‍👦' => 'familj: man, kvinna, pojke, pojke',
    '👨‍👩‍👧‍👧' => 'familj: man, kvinna, flicka, flicka',
    '👨‍👨‍👧‍👦' => 'familj: man, man, flicka, pojke',
    '👨‍👨‍👦‍👦' => 'familj: man, man, pojke, pojke',
    '👨‍👨‍👧‍👧' => 'familj: man, man, flicka, flicka',
    '👩‍👩‍👧‍👦' => 'familj: kvinna, kvinna, flicka, pojke',
    '👩‍👩‍👦‍👦' => 'familj: kvinna, kvinna, pojke, pojke',
    '👩‍👩‍👧‍👧' => 'familj: kvinna, kvinna, flicka, flicka',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'flagga: England',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'flagga: Skottland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'flagga: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'familj: vuxen, vuxen, barn, barn',
    '🚶🏻‍♀‍➡' => 'kvinna som går: ljus hy, åt höger',
    '🚶🏼‍♀‍➡' => 'kvinna som går: mellanljus hy, åt höger',
    '🚶🏽‍♀‍➡' => 'kvinna som går: mellanfärgad hy, åt höger',
    '🚶🏾‍♀‍➡' => 'kvinna som går: mellanmörk hy, åt höger',
    '🚶🏿‍♀‍➡' => 'kvinna som går: mörk hy, åt höger',
    '🚶🏻‍♂‍➡' => 'man som går: ljus hy, åt höger',
    '🚶🏼‍♂‍➡' => 'man som går: mellanljus hy, åt höger',
    '🚶🏽‍♂‍➡' => 'man som går: mellanfärgad hy, åt höger',
    '🚶🏾‍♂‍➡' => 'man som går: mellanmörk hy, åt höger',
    '🚶🏿‍♂‍➡' => 'man som går: mörk hy, åt höger',
    '🧎🏻‍♀‍➡' => 'knäsittande kvinna: ljus hy, åt höger',
    '🧎🏼‍♀‍➡' => 'knäsittande kvinna: mellanljus hy, åt höger',
    '🧎🏽‍♀‍➡' => 'knäsittande kvinna: mellanfärgad hy, åt höger',
    '🧎🏾‍♀‍➡' => 'knäsittande kvinna: mellanmörk hy, åt höger',
    '🧎🏿‍♀‍➡' => 'knäsittande kvinna: mörk hy, åt höger',
    '🧎🏻‍♂‍➡' => 'knäsittande man: ljus hy, åt höger',
    '🧎🏼‍♂‍➡' => 'knäsittande man: mellanljus hy, åt höger',
    '🧎🏽‍♂‍➡' => 'knäsittande man: mellanfärgad hy, åt höger',
    '🧎🏾‍♂‍➡' => 'knäsittande man: mellanmörk hy, åt höger',
    '🧎🏿‍♂‍➡' => 'knäsittande man: mörk hy, åt höger',
    '🧑🏻‍🦯‍➡' => 'person med vit käpp: ljus hy, åt höger',
    '🧑🏼‍🦯‍➡' => 'person med vit käpp: mellanljus hy, åt höger',
    '🧑🏽‍🦯‍➡' => 'person med vit käpp: mellanfärgad hy, åt höger',
    '🧑🏾‍🦯‍➡' => 'person med vit käpp: mellanmörk hy, åt höger',
    '🧑🏿‍🦯‍➡' => 'person med vit käpp: mörk hy, åt höger',
    '👨🏻‍🦯‍➡' => 'man med vit käpp: ljus hy, åt höger',
    '👨🏼‍🦯‍➡' => 'man med vit käpp: mellanljus hy, åt höger',
    '👨🏽‍🦯‍➡' => 'man med vit käpp: mellanfärgad hy, åt höger',
    '👨🏾‍🦯‍➡' => 'man med vit käpp: mellanmörk hy, åt höger',
    '👨🏿‍🦯‍➡' => 'man med vit käpp: mörk hy, åt höger',
    '👩🏻‍🦯‍➡' => 'kvinna med vit käpp: ljus hy, åt höger',
    '👩🏼‍🦯‍➡' => 'kvinna med vit käpp: mellanljus hy, åt höger',
    '👩🏽‍🦯‍➡' => 'kvinna med vit käpp: mellanfärgad hy, åt höger',
    '👩🏾‍🦯‍➡' => 'kvinna med vit käpp: mellanmörk hy, åt höger',
    '👩🏿‍🦯‍➡' => 'kvinna med vit käpp: mörk hy, åt höger',
    '🧑🏻‍🦼‍➡' => 'person i permobil: ljus hy, åt höger',
    '🧑🏼‍🦼‍➡' => 'person i permobil: mellanljus hy, åt höger',
    '🧑🏽‍🦼‍➡' => 'person i permobil: mellanfärgad hy, åt höger',
    '🧑🏾‍🦼‍➡' => 'person i permobil: mellanmörk hy, åt höger',
    '🧑🏿‍🦼‍➡' => 'person i permobil: mörk hy, åt höger',
    '👨🏻‍🦼‍➡' => 'man i permobil: ljus hy, åt höger',
    '👨🏼‍🦼‍➡' => 'man i permobil: mellanljus hy, åt höger',
    '👨🏽‍🦼‍➡' => 'man i permobil: mellanfärgad hy, åt höger',
    '👨🏾‍🦼‍➡' => 'man i permobil: mellanmörk hy, åt höger',
    '👨🏿‍🦼‍➡' => 'man i permobil: mörk hy, åt höger',
    '👩🏻‍🦼‍➡' => 'kvinna i permobil: ljus hy, åt höger',
    '👩🏼‍🦼‍➡' => 'kvinna i permobil: mellanljus hy, åt höger',
    '👩🏽‍🦼‍➡' => 'kvinna i permobil: mellanfärgad hy, åt höger',
    '👩🏾‍🦼‍➡' => 'kvinna i permobil: mellanmörk hy, åt höger',
    '👩🏿‍🦼‍➡' => 'kvinna i permobil: mörk hy, åt höger',
    '🧑🏻‍🦽‍➡' => 'person i manuell rullstol: ljus hy, åt höger',
    '🧑🏼‍🦽‍➡' => 'person i manuell rullstol: mellanljus hy, åt höger',
    '🧑🏽‍🦽‍➡' => 'person i manuell rullstol: mellanfärgad hy, åt höger',
    '🧑🏾‍🦽‍➡' => 'person i manuell rullstol: mellanmörk hy, åt höger',
    '🧑🏿‍🦽‍➡' => 'person i manuell rullstol: mörk hy, åt höger',
    '👨🏻‍🦽‍➡' => 'man i manuell rullstol: ljus hy, åt höger',
    '👨🏼‍🦽‍➡' => 'man i manuell rullstol: mellanljus hy, åt höger',
    '👨🏽‍🦽‍➡' => 'man i manuell rullstol: mellanfärgad hy, åt höger',
    '👨🏾‍🦽‍➡' => 'man i manuell rullstol: mellanmörk hy, åt höger',
    '👨🏿‍🦽‍➡' => 'man i manuell rullstol: mörk hy, åt höger',
    '👩🏻‍🦽‍➡' => 'kvinna i manuell rullstol: ljus hy, åt höger',
    '👩🏼‍🦽‍➡' => 'kvinna i manuell rullstol: mellanljus hy, åt höger',
    '👩🏽‍🦽‍➡' => 'kvinna i manuell rullstol: mellanfärgad hy, åt höger',
    '👩🏾‍🦽‍➡' => 'kvinna i manuell rullstol: mellanmörk hy, åt höger',
    '👩🏿‍🦽‍➡' => 'kvinna i manuell rullstol: mörk hy, åt höger',
    '🏃🏻‍♀‍➡' => 'kvinna som springer: ljus hy, åt höger',
    '🏃🏼‍♀‍➡' => 'kvinna som springer: mellanljus hy, åt höger',
    '🏃🏽‍♀‍➡' => 'kvinna som springer: mellanfärgad hy, åt höger',
    '🏃🏾‍♀‍➡' => 'kvinna som springer: mellanmörk hy, åt höger',
    '🏃🏿‍♀‍➡' => 'kvinna som springer: mörk hy, åt höger',
    '🏃🏻‍♂‍➡' => 'man som springer: ljus hy, åt höger',
    '🏃🏼‍♂‍➡' => 'man som springer: mellanljus hy, åt höger',
    '🏃🏽‍♂‍➡' => 'man som springer: mellanfärgad hy, åt höger',
    '🏃🏾‍♂‍➡' => 'man som springer: mellanmörk hy, åt höger',
    '🏃🏿‍♂‍➡' => 'man som springer: mörk hy, åt höger',
    '🫱🏻‍🫲🏼' => 'handskakning: ljus hy, mellanljus hy',
    '🫱🏻‍🫲🏽' => 'handskakning: ljus hy, mellanfärgad hy',
    '🫱🏻‍🫲🏾' => 'handskakning: ljus hy, mellanmörk hy',
    '🫱🏻‍🫲🏿' => 'handskakning: ljus hy, mörk hy',
    '🫱🏼‍🫲🏻' => 'handskakning: mellanljus hy, ljus hy',
    '🫱🏼‍🫲🏽' => 'handskakning: mellanljus hy, mellanfärgad hy',
    '🫱🏼‍🫲🏾' => 'handskakning: mellanljus hy, mellanmörk hy',
    '🫱🏼‍🫲🏿' => 'handskakning: mellanljus hy, mörk hy',
    '🫱🏽‍🫲🏻' => 'handskakning: mellanfärgad hy, ljus hy',
    '🫱🏽‍🫲🏼' => 'handskakning: mellanfärgad hy, mellanljus hy',
    '🫱🏽‍🫲🏾' => 'handskakning: mellanfärgad hy, mellanmörk hy',
    '🫱🏽‍🫲🏿' => 'handskakning: mellanfärgad hy, mörk hy',
    '🫱🏾‍🫲🏻' => 'handskakning: mellanmörk hy, ljus hy',
    '🫱🏾‍🫲🏼' => 'handskakning: mellanmörk hy, mellanljus hy',
    '🫱🏾‍🫲🏽' => 'handskakning: mellanmörk hy, mellanfärgad hy',
    '🫱🏾‍🫲🏿' => 'handskakning: mellanmörk hy, mörk hy',
    '🫱🏿‍🫲🏻' => 'handskakning: mörk hy, ljus hy',
    '🫱🏿‍🫲🏼' => 'handskakning: mörk hy, mellanljus hy',
    '🫱🏿‍🫲🏽' => 'handskakning: mörk hy, mellanfärgad hy',
    '🫱🏿‍🫲🏾' => 'handskakning: mörk hy, mellanmörk hy',
    '🚶‍♀‍➡' => 'kvinna som går: åt höger',
    '🚶‍♂‍➡' => 'man som går: åt höger',
    '🧎‍♀‍➡' => 'knäsittande kvinna: åt höger',
    '🧎‍♂‍➡' => 'knäsittande man: åt höger',
    '🧑‍🦯‍➡' => 'person med vit käpp: åt höger',
    '👨‍🦯‍➡' => 'man med vit käpp: åt höger',
    '👩‍🦯‍➡' => 'kvinna med vit käpp: åt höger',
    '🧑‍🦼‍➡' => 'person i permobil: åt höger',
    '👨‍🦼‍➡' => 'man i permobil: åt höger',
    '👩‍🦼‍➡' => 'kvinna i permobil: åt höger',
    '🧑‍🦽‍➡' => 'person i manuell rullstol: åt höger',
    '👨‍🦽‍➡' => 'man i manuell rullstol: åt höger',
    '👩‍🦽‍➡' => 'kvinna i manuell rullstol: åt höger',
    '🏃‍♀‍➡' => 'kvinna som springer: åt höger',
    '🏃‍♂‍➡' => 'man som springer: åt höger',
    '👩‍❤‍👨' => 'par med hjärta: kvinna, man',
    '👨‍❤‍👨' => 'par med hjärta: man, man',
    '👩‍❤‍👩' => 'par med hjärta: kvinna, kvinna',
    '👨‍👩‍👦' => 'familj: man, kvinna, pojke',
    '👨‍👩‍👧' => 'familj: man, kvinna, flicka',
    '👨‍👨‍👦' => 'familj: man, man, pojke',
    '👨‍👨‍👧' => 'familj: man, man, flicka',
    '👩‍👩‍👦' => 'familj: kvinna, kvinna, pojke',
    '👩‍👩‍👧' => 'familj: kvinna, kvinna, flicka',
    '👨‍👦‍👦' => 'familj: man, pojke, pojke',
    '👨‍👧‍👦' => 'familj: man, flicka, pojke',
    '👨‍👧‍👧' => 'familj: man, flicka, flicka',
    '👩‍👦‍👦' => 'familj: kvinna, pojke, pojke',
    '👩‍👧‍👦' => 'familj: kvinna, flicka, pojke',
    '👩‍👧‍👧' => 'familj: kvinna, flicka, flicka',
    '🧑‍🤝‍🧑' => 'personer som håller hand',
    '🧑‍🧑‍🧒' => 'familj: vuxen, vuxen, barn',
    '🧑‍🧒‍🧒' => 'familj: vuxen, barn, barn',
    '🧑🏻‍🦰' => 'person: ljus hy, rödhårig',
    '🧑🏼‍🦰' => 'person: mellanljus hy, rödhårig',
    '🧑🏽‍🦰' => 'person: mellanfärgad hy, rödhårig',
    '🧑🏾‍🦰' => 'person: mellanmörk hy, rödhårig',
    '🧑🏿‍🦰' => 'person: mörk hy, rödhårig',
    '🧑🏻‍🦱' => 'person: ljus hy, lockigt hår',
    '🧑🏼‍🦱' => 'person: mellanljus hy, lockigt hår',
    '🧑🏽‍🦱' => 'person: mellanfärgad hy, lockigt hår',
    '🧑🏾‍🦱' => 'person: mellanmörk hy, lockigt hår',
    '🧑🏿‍🦱' => 'person: mörk hy, lockigt hår',
    '🧑🏻‍🦳' => 'person: ljus hy, vithårig',
    '🧑🏼‍🦳' => 'person: mellanljus hy, vithårig',
    '🧑🏽‍🦳' => 'person: mellanfärgad hy, vithårig',
    '🧑🏾‍🦳' => 'person: mellanmörk hy, vithårig',
    '🧑🏿‍🦳' => 'person: mörk hy, vithårig',
    '🧑🏻‍🦲' => 'person: ljus hy, skallig',
    '🧑🏼‍🦲' => 'person: mellanljus hy, skallig',
    '🧑🏽‍🦲' => 'person: mellanfärgad hy, skallig',
    '🧑🏾‍🦲' => 'person: mellanmörk hy, skallig',
    '🧑🏿‍🦲' => 'person: mörk hy, skallig',
    '🧑🏻‍🩰' => 'balettdansare: ljus hy',
    '🧑🏼‍🩰' => 'balettdansare: mellanljus hy',
    '🧑🏽‍🩰' => 'balettdansare: mellanfärgad hy',
    '🧑🏾‍🩰' => 'balettdansare: mellanmörk hy',
    '🧑🏿‍🩰' => 'balettdansare: mörk hy',
    '🧔🏻‍♂' => 'man: ljus hy, skägg',
    '🧔🏼‍♂' => 'man: mellanljus hy, skägg',
    '🧔🏽‍♂' => 'man: mellanfärgad hy, skägg',
    '🧔🏾‍♂' => 'man: mellanmörk hy, skägg',
    '🧔🏿‍♂' => 'man: mörk hy, skägg',
    '👱🏻‍♂' => 'blond man: ljus hy',
    '👱🏼‍♂' => 'blond man: mellanljus hy',
    '👱🏽‍♂' => 'blond man: mellanfärgad hy',
    '👱🏾‍♂' => 'blond man: mellanmörk hy',
    '👱🏿‍♂' => 'blond man: mörk hy',
    '👨🏻‍🦰' => 'man: ljus hy, rödhårig',
    '👨🏼‍🦰' => 'man: mellanljus hy, rödhårig',
    '👨🏽‍🦰' => 'man: mellanfärgad hy, rödhårig',
    '👨🏾‍🦰' => 'man: mellanmörk hy, rödhårig',
    '👨🏿‍🦰' => 'man: mörk hy, rödhårig',
    '👨🏻‍🦱' => 'man: ljus hy, lockigt hår',
    '👨🏼‍🦱' => 'man: mellanljus hy, lockigt hår',
    '👨🏽‍🦱' => 'man: mellanfärgad hy, lockigt hår',
    '👨🏾‍🦱' => 'man: mellanmörk hy, lockigt hår',
    '👨🏿‍🦱' => 'man: mörk hy, lockigt hår',
    '👨🏻‍🦳' => 'man: ljus hy, vithårig',
    '👨🏼‍🦳' => 'man: mellanljus hy, vithårig',
    '👨🏽‍🦳' => 'man: mellanfärgad hy, vithårig',
    '👨🏾‍🦳' => 'man: mellanmörk hy, vithårig',
    '👨🏿‍🦳' => 'man: mörk hy, vithårig',
    '👨🏻‍🦲' => 'man: ljus hy, skallig',
    '👨🏼‍🦲' => 'man: mellanljus hy, skallig',
    '👨🏽‍🦲' => 'man: mellanfärgad hy, skallig',
    '👨🏾‍🦲' => 'man: mellanmörk hy, skallig',
    '👨🏿‍🦲' => 'man: mörk hy, skallig',
    '🧔🏻‍♀' => 'kvinna: ljus hy, skägg',
    '🧔🏼‍♀' => 'kvinna: mellanljus hy, skägg',
    '🧔🏽‍♀' => 'kvinna: mellanfärgad hy, skägg',
    '🧔🏾‍♀' => 'kvinna: mellanmörk hy, skägg',
    '🧔🏿‍♀' => 'kvinna: mörk hy, skägg',
    '👱🏻‍♀' => 'blond kvinna: ljus hy',
    '👱🏼‍♀' => 'blond kvinna: mellanljus hy',
    '👱🏽‍♀' => 'blond kvinna: mellanfärgad hy',
    '👱🏾‍♀' => 'blond kvinna: mellanmörk hy',
    '👱🏿‍♀' => 'blond kvinna: mörk hy',
    '👩🏻‍🦰' => 'kvinna: ljus hy, rödhårig',
    '👩🏼‍🦰' => 'kvinna: mellanljus hy, rödhårig',
    '👩🏽‍🦰' => 'kvinna: mellanfärgad hy, rödhårig',
    '👩🏾‍🦰' => 'kvinna: mellanmörk hy, rödhårig',
    '👩🏿‍🦰' => 'kvinna: mörk hy, rödhårig',
    '👩🏻‍🦱' => 'kvinna: ljus hy, lockigt hår',
    '👩🏼‍🦱' => 'kvinna: mellanljus hy, lockigt hår',
    '👩🏽‍🦱' => 'kvinna: mellanfärgad hy, lockigt hår',
    '👩🏾‍🦱' => 'kvinna: mellanmörk hy, lockigt hår',
    '👩🏿‍🦱' => 'kvinna: mörk hy, lockigt hår',
    '👩🏻‍🦳' => 'kvinna: ljus hy, vithårig',
    '👩🏼‍🦳' => 'kvinna: mellanljus hy, vithårig',
    '👩🏽‍🦳' => 'kvinna: mellanfärgad hy, vithårig',
    '👩🏾‍🦳' => 'kvinna: mellanmörk hy, vithårig',
    '👩🏿‍🦳' => 'kvinna: mörk hy, vithårig',
    '👩🏻‍🦲' => 'kvinna: ljus hy, skallig',
    '👩🏼‍🦲' => 'kvinna: mellanljus hy, skallig',
    '👩🏽‍🦲' => 'kvinna: mellanfärgad hy, skallig',
    '👩🏾‍🦲' => 'kvinna: mellanmörk hy, skallig',
    '👩🏿‍🦲' => 'kvinna: mörk hy, skallig',
    '🙍🏻‍♂' => 'sur man: ljus hy',
    '🙍🏼‍♂' => 'sur man: mellanljus hy',
    '🙍🏽‍♂' => 'sur man: mellanfärgad hy',
    '🙍🏾‍♂' => 'sur man: mellanmörk hy',
    '🙍🏿‍♂' => 'sur man: mörk hy',
    '🙍🏻‍♀' => 'sur kvinna: ljus hy',
    '🙍🏼‍♀' => 'sur kvinna: mellanljus hy',
    '🙍🏽‍♀' => 'sur kvinna: mellanfärgad hy',
    '🙍🏾‍♀' => 'sur kvinna: mellanmörk hy',
    '🙍🏿‍♀' => 'sur kvinna: mörk hy',
    '🙎🏻‍♂' => 'plutande man: ljus hy',
    '🙎🏼‍♂' => 'plutande man: mellanljus hy',
    '🙎🏽‍♂' => 'plutande man: mellanfärgad hy',
    '🙎🏾‍♂' => 'plutande man: mellanmörk hy',
    '🙎🏿‍♂' => 'plutande man: mörk hy',
    '🙎🏻‍♀' => 'plutande kvinna: ljus hy',
    '🙎🏼‍♀' => 'plutande kvinna: mellanljus hy',
    '🙎🏽‍♀' => 'plutande kvinna: mellanfärgad hy',
    '🙎🏾‍♀' => 'plutande kvinna: mellanmörk hy',
    '🙎🏿‍♀' => 'plutande kvinna: mörk hy',
    '🙅🏻‍♂' => 'man gestikulerar NEJ: ljus hy',
    '🙅🏼‍♂' => 'man gestikulerar NEJ: mellanljus hy',
    '🙅🏽‍♂' => 'man gestikulerar NEJ: mellanfärgad hy',
    '🙅🏾‍♂' => 'man gestikulerar NEJ: mellanmörk hy',
    '🙅🏿‍♂' => 'man gestikulerar NEJ: mörk hy',
    '🙅🏻‍♀' => 'kvinna gestikulerar NEJ: ljus hy',
    '🙅🏼‍♀' => 'kvinna gestikulerar NEJ: mellanljus hy',
    '🙅🏽‍♀' => 'kvinna gestikulerar NEJ: mellanfärgad hy',
    '🙅🏾‍♀' => 'kvinna gestikulerar NEJ: mellanmörk hy',
    '🙅🏿‍♀' => 'kvinna gestikulerar NEJ: mörk hy',
    '🙆🏻‍♂' => 'man gestikulerar OK: ljus hy',
    '🙆🏼‍♂' => 'man gestikulerar OK: mellanljus hy',
    '🙆🏽‍♂' => 'man gestikulerar OK: mellanfärgad hy',
    '🙆🏾‍♂' => 'man gestikulerar OK: mellanmörk hy',
    '🙆🏿‍♂' => 'man gestikulerar OK: mörk hy',
    '🙆🏻‍♀' => 'kvinna gestikulerar OK: ljus hy',
    '🙆🏼‍♀' => 'kvinna gestikulerar OK: mellanljus hy',
    '🙆🏽‍♀' => 'kvinna gestikulerar OK: mellanfärgad hy',
    '🙆🏾‍♀' => 'kvinna gestikulerar OK: mellanmörk hy',
    '🙆🏿‍♀' => 'kvinna gestikulerar OK: mörk hy',
    '💁🏻‍♂' => 'hjälpande man: ljus hy',
    '💁🏼‍♂' => 'hjälpande man: mellanljus hy',
    '💁🏽‍♂' => 'hjälpande man: mellanfärgad hy',
    '💁🏾‍♂' => 'hjälpande man: mellanmörk hy',
    '💁🏿‍♂' => 'hjälpande man: mörk hy',
    '💁🏻‍♀' => 'hjälpande kvinna: ljus hy',
    '💁🏼‍♀' => 'hjälpande kvinna: mellanljus hy',
    '💁🏽‍♀' => 'hjälpande kvinna: mellanfärgad hy',
    '💁🏾‍♀' => 'hjälpande kvinna: mellanmörk hy',
    '💁🏿‍♀' => 'hjälpande kvinna: mörk hy',
    '🙋🏻‍♂' => 'man som räcker upp handen: ljus hy',
    '🙋🏼‍♂' => 'man som räcker upp handen: mellanljus hy',
    '🙋🏽‍♂' => 'man som räcker upp handen: mellanfärgad hy',
    '🙋🏾‍♂' => 'man som räcker upp handen: mellanmörk hy',
    '🙋🏿‍♂' => 'man som räcker upp handen: mörk hy',
    '🙋🏻‍♀' => 'kvinna som räcker upp handen: ljus hy',
    '🙋🏼‍♀' => 'kvinna som räcker upp handen: mellanljus hy',
    '🙋🏽‍♀' => 'kvinna som räcker upp handen: mellanfärgad hy',
    '🙋🏾‍♀' => 'kvinna som räcker upp handen: mellanmörk hy',
    '🙋🏿‍♀' => 'kvinna som räcker upp handen: mörk hy',
    '🧏🏻‍♂' => 'hörselskadad man: ljus hy',
    '🧏🏼‍♂' => 'hörselskadad man: mellanljus hy',
    '🧏🏽‍♂' => 'hörselskadad man: mellanfärgad hy',
    '🧏🏾‍♂' => 'hörselskadad man: mellanmörk hy',
    '🧏🏿‍♂' => 'hörselskadad man: mörk hy',
    '🧏🏻‍♀' => 'hörselskadad kvinna: ljus hy',
    '🧏🏼‍♀' => 'hörselskadad kvinna: mellanljus hy',
    '🧏🏽‍♀' => 'hörselskadad kvinna: mellanfärgad hy',
    '🧏🏾‍♀' => 'hörselskadad kvinna: mellanmörk hy',
    '🧏🏿‍♀' => 'hörselskadad kvinna: mörk hy',
    '🙇🏻‍♂' => 'bugande man: ljus hy',
    '🙇🏼‍♂' => 'bugande man: mellanljus hy',
    '🙇🏽‍♂' => 'bugande man: mellanfärgad hy',
    '🙇🏾‍♂' => 'bugande man: mellanmörk hy',
    '🙇🏿‍♂' => 'bugande man: mörk hy',
    '🙇🏻‍♀' => 'bugande kvinna: ljus hy',
    '🙇🏼‍♀' => 'bugande kvinna: mellanljus hy',
    '🙇🏽‍♀' => 'bugande kvinna: mellanfärgad hy',
    '🙇🏾‍♀' => 'bugande kvinna: mellanmörk hy',
    '🙇🏿‍♀' => 'bugande kvinna: mörk hy',
    '🤦🏻‍♂' => 'man som slår sig för pannan: ljus hy',
    '🤦🏼‍♂' => 'man som slår sig för pannan: mellanljus hy',
    '🤦🏽‍♂' => 'man som slår sig för pannan: mellanfärgad hy',
    '🤦🏾‍♂' => 'man som slår sig för pannan: mellanmörk hy',
    '🤦🏿‍♂' => 'man som slår sig för pannan: mörk hy',
    '🤦🏻‍♀' => 'kvinna som slår sig för pannan: ljus hy',
    '🤦🏼‍♀' => 'kvinna som slår sig för pannan: mellanljus hy',
    '🤦🏽‍♀' => 'kvinna som slår sig för pannan: mellanfärgad hy',
    '🤦🏾‍♀' => 'kvinna som slår sig för pannan: mellanmörk hy',
    '🤦🏿‍♀' => 'kvinna som slår sig för pannan: mörk hy',
    '🤷🏻‍♂' => 'man som rycker på axlarna: ljus hy',
    '🤷🏼‍♂' => 'man som rycker på axlarna: mellanljus hy',
    '🤷🏽‍♂' => 'man som rycker på axlarna: mellanfärgad hy',
    '🤷🏾‍♂' => 'man som rycker på axlarna: mellanmörk hy',
    '🤷🏿‍♂' => 'man som rycker på axlarna: mörk hy',
    '🤷🏻‍♀' => 'kvinna som rycker på axlarna: ljus hy',
    '🤷🏼‍♀' => 'kvinna som rycker på axlarna: mellanljus hy',
    '🤷🏽‍♀' => 'kvinna som rycker på axlarna: mellanfärgad hy',
    '🤷🏾‍♀' => 'kvinna som rycker på axlarna: mellanmörk hy',
    '🤷🏿‍♀' => 'kvinna som rycker på axlarna: mörk hy',
    '🧑🏻‍⚕' => 'läkare: ljus hy',
    '🧑🏼‍⚕' => 'läkare: mellanljus hy',
    '🧑🏽‍⚕' => 'läkare: mellanfärgad hy',
    '🧑🏾‍⚕' => 'läkare: mellanmörk hy',
    '🧑🏿‍⚕' => 'läkare: mörk hy',
    '👨🏻‍⚕' => 'manlig läkare: ljus hy',
    '👨🏼‍⚕' => 'manlig läkare: mellanljus hy',
    '👨🏽‍⚕' => 'manlig läkare: mellanfärgad hy',
    '👨🏾‍⚕' => 'manlig läkare: mellanmörk hy',
    '👨🏿‍⚕' => 'manlig läkare: mörk hy',
    '👩🏻‍⚕' => 'kvinnlig läkare: ljus hy',
    '👩🏼‍⚕' => 'kvinnlig läkare: mellanljus hy',
    '👩🏽‍⚕' => 'kvinnlig läkare: mellanfärgad hy',
    '👩🏾‍⚕' => 'kvinnlig läkare: mellanmörk hy',
    '👩🏿‍⚕' => 'kvinnlig läkare: mörk hy',
    '🧑🏻‍🎓' => 'student: ljus hy',
    '🧑🏼‍🎓' => 'student: mellanljus hy',
    '🧑🏽‍🎓' => 'student: mellanfärgad hy',
    '🧑🏾‍🎓' => 'student: mellanmörk hy',
    '🧑🏿‍🎓' => 'student: mörk hy',
    '👨🏻‍🎓' => 'manlig student: ljus hy',
    '👨🏼‍🎓' => 'manlig student: mellanljus hy',
    '👨🏽‍🎓' => 'manlig student: mellanfärgad hy',
    '👨🏾‍🎓' => 'manlig student: mellanmörk hy',
    '👨🏿‍🎓' => 'manlig student: mörk hy',
    '👩🏻‍🎓' => 'kvinnlig student: ljus hy',
    '👩🏼‍🎓' => 'kvinnlig student: mellanljus hy',
    '👩🏽‍🎓' => 'kvinnlig student: mellanfärgad hy',
    '👩🏾‍🎓' => 'kvinnlig student: mellanmörk hy',
    '👩🏿‍🎓' => 'kvinnlig student: mörk hy',
    '🧑🏻‍🏫' => 'lärare: ljus hy',
    '🧑🏼‍🏫' => 'lärare: mellanljus hy',
    '🧑🏽‍🏫' => 'lärare: mellanfärgad hy',
    '🧑🏾‍🏫' => 'lärare: mellanmörk hy',
    '🧑🏿‍🏫' => 'lärare: mörk hy',
    '👨🏻‍🏫' => 'manlig lärare: ljus hy',
    '👨🏼‍🏫' => 'manlig lärare: mellanljus hy',
    '👨🏽‍🏫' => 'manlig lärare: mellanfärgad hy',
    '👨🏾‍🏫' => 'manlig lärare: mellanmörk hy',
    '👨🏿‍🏫' => 'manlig lärare: mörk hy',
    '👩🏻‍🏫' => 'kvinnlig lärare: ljus hy',
    '👩🏼‍🏫' => 'kvinnlig lärare: mellanljus hy',
    '👩🏽‍🏫' => 'kvinnlig lärare: mellanfärgad hy',
    '👩🏾‍🏫' => 'kvinnlig lärare: mellanmörk hy',
    '👩🏿‍🏫' => 'kvinnlig lärare: mörk hy',
    '🧑🏻‍⚖' => 'domare: ljus hy',
    '🧑🏼‍⚖' => 'domare: mellanljus hy',
    '🧑🏽‍⚖' => 'domare: mellanfärgad hy',
    '🧑🏾‍⚖' => 'domare: mellanmörk hy',
    '🧑🏿‍⚖' => 'domare: mörk hy',
    '👨🏻‍⚖' => 'manlig domare: ljus hy',
    '👨🏼‍⚖' => 'manlig domare: mellanljus hy',
    '👨🏽‍⚖' => 'manlig domare: mellanfärgad hy',
    '👨🏾‍⚖' => 'manlig domare: mellanmörk hy',
    '👨🏿‍⚖' => 'manlig domare: mörk hy',
    '👩🏻‍⚖' => 'kvinnlig domare: ljus hy',
    '👩🏼‍⚖' => 'kvinnlig domare: mellanljus hy',
    '👩🏽‍⚖' => 'kvinnlig domare: mellanfärgad hy',
    '👩🏾‍⚖' => 'kvinnlig domare: mellanmörk hy',
    '👩🏿‍⚖' => 'kvinnlig domare: mörk hy',
    '🧑🏻‍🌾' => 'bonde: ljus hy',
    '🧑🏼‍🌾' => 'bonde: mellanljus hy',
    '🧑🏽‍🌾' => 'bonde: mellanfärgad hy',
    '🧑🏾‍🌾' => 'bonde: mellanmörk hy',
    '🧑🏿‍🌾' => 'bonde: mörk hy',
    '👨🏻‍🌾' => 'manlig bonde: ljus hy',
    '👨🏼‍🌾' => 'manlig bonde: mellanljus hy',
    '👨🏽‍🌾' => 'manlig bonde: mellanfärgad hy',
    '👨🏾‍🌾' => 'manlig bonde: mellanmörk hy',
    '👨🏿‍🌾' => 'manlig bonde: mörk hy',
    '👩🏻‍🌾' => 'kvinnlig bonde: ljus hy',
    '👩🏼‍🌾' => 'kvinnlig bonde: mellanljus hy',
    '👩🏽‍🌾' => 'kvinnlig bonde: mellanfärgad hy',
    '👩🏾‍🌾' => 'kvinnlig bonde: mellanmörk hy',
    '👩🏿‍🌾' => 'kvinnlig bonde: mörk hy',
    '🧑🏻‍🍳' => 'kock: ljus hy',
    '🧑🏼‍🍳' => 'kock: mellanljus hy',
    '🧑🏽‍🍳' => 'kock: mellanfärgad hy',
    '🧑🏾‍🍳' => 'kock: mellanmörk hy',
    '🧑🏿‍🍳' => 'kock: mörk hy',
    '👨🏻‍🍳' => 'manlig kock: ljus hy',
    '👨🏼‍🍳' => 'manlig kock: mellanljus hy',
    '👨🏽‍🍳' => 'manlig kock: mellanfärgad hy',
    '👨🏾‍🍳' => 'manlig kock: mellanmörk hy',
    '👨🏿‍🍳' => 'manlig kock: mörk hy',
    '👩🏻‍🍳' => 'kvinnlig kock: ljus hy',
    '👩🏼‍🍳' => 'kvinnlig kock: mellanljus hy',
    '👩🏽‍🍳' => 'kvinnlig kock: mellanfärgad hy',
    '👩🏾‍🍳' => 'kvinnlig kock: mellanmörk hy',
    '👩🏿‍🍳' => 'kvinnlig kock: mörk hy',
    '🧑🏻‍🔧' => 'mekaniker: ljus hy',
    '🧑🏼‍🔧' => 'mekaniker: mellanljus hy',
    '🧑🏽‍🔧' => 'mekaniker: mellanfärgad hy',
    '🧑🏾‍🔧' => 'mekaniker: mellanmörk hy',
    '🧑🏿‍🔧' => 'mekaniker: mörk hy',
    '👨🏻‍🔧' => 'manlig mekaniker: ljus hy',
    '👨🏼‍🔧' => 'manlig mekaniker: mellanljus hy',
    '👨🏽‍🔧' => 'manlig mekaniker: mellanfärgad hy',
    '👨🏾‍🔧' => 'manlig mekaniker: mellanmörk hy',
    '👨🏿‍🔧' => 'manlig mekaniker: mörk hy',
    '👩🏻‍🔧' => 'kvinnlig mekaniker: ljus hy',
    '👩🏼‍🔧' => 'kvinnlig mekaniker: mellanljus hy',
    '👩🏽‍🔧' => 'kvinnlig mekaniker: mellanfärgad hy',
    '👩🏾‍🔧' => 'kvinnlig mekaniker: mellanmörk hy',
    '👩🏿‍🔧' => 'kvinnlig mekaniker: mörk hy',
    '🧑🏻‍🏭' => 'fabriksarbetare: ljus hy',
    '🧑🏼‍🏭' => 'fabriksarbetare: mellanljus hy',
    '🧑🏽‍🏭' => 'fabriksarbetare: mellanfärgad hy',
    '🧑🏾‍🏭' => 'fabriksarbetare: mellanmörk hy',
    '🧑🏿‍🏭' => 'fabriksarbetare: mörk hy',
    '👨🏻‍🏭' => 'manlig fabriksarbetare: ljus hy',
    '👨🏼‍🏭' => 'manlig fabriksarbetare: mellanljus hy',
    '👨🏽‍🏭' => 'manlig fabriksarbetare: mellanfärgad hy',
    '👨🏾‍🏭' => 'manlig fabriksarbetare: mellanmörk hy',
    '👨🏿‍🏭' => 'manlig fabriksarbetare: mörk hy',
    '👩🏻‍🏭' => 'kvinnlig fabriksarbetare: ljus hy',
    '👩🏼‍🏭' => 'kvinnlig fabriksarbetare: mellanljus hy',
    '👩🏽‍🏭' => 'kvinnlig fabriksarbetare: mellanfärgad hy',
    '👩🏾‍🏭' => 'kvinnlig fabriksarbetare: mellanmörk hy',
    '👩🏿‍🏭' => 'kvinnlig fabriksarbetare: mörk hy',
    '🧑🏻‍💼' => 'kontorist: ljus hy',
    '🧑🏼‍💼' => 'kontorist: mellanljus hy',
    '🧑🏽‍💼' => 'kontorist: mellanfärgad hy',
    '🧑🏾‍💼' => 'kontorist: mellanmörk hy',
    '🧑🏿‍💼' => 'kontorist: mörk hy',
    '👨🏻‍💼' => 'kontorstjänsteman: ljus hy',
    '👨🏼‍💼' => 'kontorstjänsteman: mellanljus hy',
    '👨🏽‍💼' => 'kontorstjänsteman: mellanfärgad hy',
    '👨🏾‍💼' => 'kontorstjänsteman: mellanmörk hy',
    '👨🏿‍💼' => 'kontorstjänsteman: mörk hy',
    '👩🏻‍💼' => 'kontorstjänstekvinna: ljus hy',
    '👩🏼‍💼' => 'kontorstjänstekvinna: mellanljus hy',
    '👩🏽‍💼' => 'kontorstjänstekvinna: mellanfärgad hy',
    '👩🏾‍💼' => 'kontorstjänstekvinna: mellanmörk hy',
    '👩🏿‍💼' => 'kontorstjänstekvinna: mörk hy',
    '🧑🏻‍🔬' => 'forskare: ljus hy',
    '🧑🏼‍🔬' => 'forskare: mellanljus hy',
    '🧑🏽‍🔬' => 'forskare: mellanfärgad hy',
    '🧑🏾‍🔬' => 'forskare: mellanmörk hy',
    '🧑🏿‍🔬' => 'forskare: mörk hy',
    '👨🏻‍🔬' => 'manlig forskare: ljus hy',
    '👨🏼‍🔬' => 'manlig forskare: mellanljus hy',
    '👨🏽‍🔬' => 'manlig forskare: mellanfärgad hy',
    '👨🏾‍🔬' => 'manlig forskare: mellanmörk hy',
    '👨🏿‍🔬' => 'manlig forskare: mörk hy',
    '👩🏻‍🔬' => 'kvinnlig forskare: ljus hy',
    '👩🏼‍🔬' => 'kvinnlig forskare: mellanljus hy',
    '👩🏽‍🔬' => 'kvinnlig forskare: mellanfärgad hy',
    '👩🏾‍🔬' => 'kvinnlig forskare: mellanmörk hy',
    '👩🏿‍🔬' => 'kvinnlig forskare: mörk hy',
    '🧑🏻‍💻' => 'IT-tekniker: ljus hy',
    '🧑🏼‍💻' => 'IT-tekniker: mellanljus hy',
    '🧑🏽‍💻' => 'IT-tekniker: mellanfärgad hy',
    '🧑🏾‍💻' => 'IT-tekniker: mellanmörk hy',
    '🧑🏿‍💻' => 'IT-tekniker: mörk hy',
    '👨🏻‍💻' => 'manlig IT-expert: ljus hy',
    '👨🏼‍💻' => 'manlig IT-expert: mellanljus hy',
    '👨🏽‍💻' => 'manlig IT-expert: mellanfärgad hy',
    '👨🏾‍💻' => 'manlig IT-expert: mellanmörk hy',
    '👨🏿‍💻' => 'manlig IT-expert: mörk hy',
    '👩🏻‍💻' => 'kvinnlig IT-expert: ljus hy',
    '👩🏼‍💻' => 'kvinnlig IT-expert: mellanljus hy',
    '👩🏽‍💻' => 'kvinnlig IT-expert: mellanfärgad hy',
    '👩🏾‍💻' => 'kvinnlig IT-expert: mellanmörk hy',
    '👩🏿‍💻' => 'kvinnlig IT-expert: mörk hy',
    '🧑🏻‍🎤' => 'sångare: ljus hy',
    '🧑🏼‍🎤' => 'sångare: mellanljus hy',
    '🧑🏽‍🎤' => 'sångare: mellanfärgad hy',
    '🧑🏾‍🎤' => 'sångare: mellanmörk hy',
    '🧑🏿‍🎤' => 'sångare: mörk hy',
    '👨🏻‍🎤' => 'manlig sångare: ljus hy',
    '👨🏼‍🎤' => 'manlig sångare: mellanljus hy',
    '👨🏽‍🎤' => 'manlig sångare: mellanfärgad hy',
    '👨🏾‍🎤' => 'manlig sångare: mellanmörk hy',
    '👨🏿‍🎤' => 'manlig sångare: mörk hy',
    '👩🏻‍🎤' => 'kvinnlig sångare: ljus hy',
    '👩🏼‍🎤' => 'kvinnlig sångare: mellanljus hy',
    '👩🏽‍🎤' => 'kvinnlig sångare: mellanfärgad hy',
    '👩🏾‍🎤' => 'kvinnlig sångare: mellanmörk hy',
    '👩🏿‍🎤' => 'kvinnlig sångare: mörk hy',
    '🧑🏻‍🎨' => 'konstnär: ljus hy',
    '🧑🏼‍🎨' => 'konstnär: mellanljus hy',
    '🧑🏽‍🎨' => 'konstnär: mellanfärgad hy',
    '🧑🏾‍🎨' => 'konstnär: mellanmörk hy',
    '🧑🏿‍🎨' => 'konstnär: mörk hy',
    '👨🏻‍🎨' => 'manlig konstnär: ljus hy',
    '👨🏼‍🎨' => 'manlig konstnär: mellanljus hy',
    '👨🏽‍🎨' => 'manlig konstnär: mellanfärgad hy',
    '👨🏾‍🎨' => 'manlig konstnär: mellanmörk hy',
    '👨🏿‍🎨' => 'manlig konstnär: mörk hy',
    '👩🏻‍🎨' => 'kvinnlig konstnär: ljus hy',
    '👩🏼‍🎨' => 'kvinnlig konstnär: mellanljus hy',
    '👩🏽‍🎨' => 'kvinnlig konstnär: mellanfärgad hy',
    '👩🏾‍🎨' => 'kvinnlig konstnär: mellanmörk hy',
    '👩🏿‍🎨' => 'kvinnlig konstnär: mörk hy',
    '🧑🏻‍✈' => 'pilot: ljus hy',
    '🧑🏼‍✈' => 'pilot: mellanljus hy',
    '🧑🏽‍✈' => 'pilot: mellanfärgad hy',
    '🧑🏾‍✈' => 'pilot: mellanmörk hy',
    '🧑🏿‍✈' => 'pilot: mörk hy',
    '👨🏻‍✈' => 'manlig pilot: ljus hy',
    '👨🏼‍✈' => 'manlig pilot: mellanljus hy',
    '👨🏽‍✈' => 'manlig pilot: mellanfärgad hy',
    '👨🏾‍✈' => 'manlig pilot: mellanmörk hy',
    '👨🏿‍✈' => 'manlig pilot: mörk hy',
    '👩🏻‍✈' => 'kvinnlig pilot: ljus hy',
    '👩🏼‍✈' => 'kvinnlig pilot: mellanljus hy',
    '👩🏽‍✈' => 'kvinnlig pilot: mellanfärgad hy',
    '👩🏾‍✈' => 'kvinnlig pilot: mellanmörk hy',
    '👩🏿‍✈' => 'kvinnlig pilot: mörk hy',
    '🧑🏻‍🚀' => 'astronaut: ljus hy',
    '🧑🏼‍🚀' => 'astronaut: mellanljus hy',
    '🧑🏽‍🚀' => 'astronaut: mellanfärgad hy',
    '🧑🏾‍🚀' => 'astronaut: mellanmörk hy',
    '🧑🏿‍🚀' => 'astronaut: mörk hy',
    '👨🏻‍🚀' => 'manlig astronaut: ljus hy',
    '👨🏼‍🚀' => 'manlig astronaut: mellanljus hy',
    '👨🏽‍🚀' => 'manlig astronaut: mellanfärgad hy',
    '👨🏾‍🚀' => 'manlig astronaut: mellanmörk hy',
    '👨🏿‍🚀' => 'manlig astronaut: mörk hy',
    '👩🏻‍🚀' => 'kvinnlig astronaut: ljus hy',
    '👩🏼‍🚀' => 'kvinnlig astronaut: mellanljus hy',
    '👩🏽‍🚀' => 'kvinnlig astronaut: mellanfärgad hy',
    '👩🏾‍🚀' => 'kvinnlig astronaut: mellanmörk hy',
    '👩🏿‍🚀' => 'kvinnlig astronaut: mörk hy',
    '🧑🏻‍🚒' => 'brandman: ljus hy',
    '🧑🏼‍🚒' => 'brandman: mellanljus hy',
    '🧑🏽‍🚒' => 'brandman: mellanfärgad hy',
    '🧑🏾‍🚒' => 'brandman: mellanmörk hy',
    '🧑🏿‍🚒' => 'brandman: mörk hy',
    '👨🏻‍🚒' => 'manlig brandman: ljus hy',
    '👨🏼‍🚒' => 'manlig brandman: mellanljus hy',
    '👨🏽‍🚒' => 'manlig brandman: mellanfärgad hy',
    '👨🏾‍🚒' => 'manlig brandman: mellanmörk hy',
    '👨🏿‍🚒' => 'manlig brandman: mörk hy',
    '👩🏻‍🚒' => 'kvinnlig brandman: ljus hy',
    '👩🏼‍🚒' => 'kvinnlig brandman: mellanljus hy',
    '👩🏽‍🚒' => 'kvinnlig brandman: mellanfärgad hy',
    '👩🏾‍🚒' => 'kvinnlig brandman: mellanmörk hy',
    '👩🏿‍🚒' => 'kvinnlig brandman: mörk hy',
    '👮🏻‍♂' => 'manlig polis: ljus hy',
    '👮🏼‍♂' => 'manlig polis: mellanljus hy',
    '👮🏽‍♂' => 'manlig polis: mellanfärgad hy',
    '👮🏾‍♂' => 'manlig polis: mellanmörk hy',
    '👮🏿‍♂' => 'manlig polis: mörk hy',
    '👮🏻‍♀' => 'kvinnlig polis: ljus hy',
    '👮🏼‍♀' => 'kvinnlig polis: mellanljus hy',
    '👮🏽‍♀' => 'kvinnlig polis: mellanfärgad hy',
    '👮🏾‍♀' => 'kvinnlig polis: mellanmörk hy',
    '👮🏿‍♀' => 'kvinnlig polis: mörk hy',
    '🕵🏻‍♂' => 'manlig detektiv: ljus hy',
    '🕵🏼‍♂' => 'manlig detektiv: mellanljus hy',
    '🕵🏽‍♂' => 'manlig detektiv: mellanfärgad hy',
    '🕵🏾‍♂' => 'manlig detektiv: mellanmörk hy',
    '🕵🏿‍♂' => 'manlig detektiv: mörk hy',
    '🕵🏻‍♀' => 'kvinnlig detektiv: ljus hy',
    '🕵🏼‍♀' => 'kvinnlig detektiv: mellanljus hy',
    '🕵🏽‍♀' => 'kvinnlig detektiv: mellanfärgad hy',
    '🕵🏾‍♀' => 'kvinnlig detektiv: mellanmörk hy',
    '🕵🏿‍♀' => 'kvinnlig detektiv: mörk hy',
    '💂🏻‍♂' => 'manlig grenadjär: ljus hy',
    '💂🏼‍♂' => 'manlig grenadjär: mellanljus hy',
    '💂🏽‍♂' => 'manlig grenadjär: mellanfärgad hy',
    '💂🏾‍♂' => 'manlig grenadjär: mellanmörk hy',
    '💂🏿‍♂' => 'manlig grenadjär: mörk hy',
    '💂🏻‍♀' => 'kvinnlig grenadjär: ljus hy',
    '💂🏼‍♀' => 'kvinnlig grenadjär: mellanljus hy',
    '💂🏽‍♀' => 'kvinnlig grenadjär: mellanfärgad hy',
    '💂🏾‍♀' => 'kvinnlig grenadjär: mellanmörk hy',
    '💂🏿‍♀' => 'kvinnlig grenadjär: mörk hy',
    '👷🏻‍♂' => 'manlig byggarbetare: ljus hy',
    '👷🏼‍♂' => 'manlig byggarbetare: mellanljus hy',
    '👷🏽‍♂' => 'manlig byggarbetare: mellanfärgad hy',
    '👷🏾‍♂' => 'manlig byggarbetare: mellanmörk hy',
    '👷🏿‍♂' => 'manlig byggarbetare: mörk hy',
    '👷🏻‍♀' => 'kvinnlig byggarbetare: ljus hy',
    '👷🏼‍♀' => 'kvinnlig byggarbetare: mellanljus hy',
    '👷🏽‍♀' => 'kvinnlig byggarbetare: mellanfärgad hy',
    '👷🏾‍♀' => 'kvinnlig byggarbetare: mellanmörk hy',
    '👷🏿‍♀' => 'kvinnlig byggarbetare: mörk hy',
    '👳🏻‍♂' => 'man i turban: ljus hy',
    '👳🏼‍♂' => 'man i turban: mellanljus hy',
    '👳🏽‍♂' => 'man i turban: mellanfärgad hy',
    '👳🏾‍♂' => 'man i turban: mellanmörk hy',
    '👳🏿‍♂' => 'man i turban: mörk hy',
    '👳🏻‍♀' => 'kvinna i turban: ljus hy',
    '👳🏼‍♀' => 'kvinna i turban: mellanljus hy',
    '👳🏽‍♀' => 'kvinna i turban: mellanfärgad hy',
    '👳🏾‍♀' => 'kvinna i turban: mellanmörk hy',
    '👳🏿‍♀' => 'kvinna i turban: mörk hy',
    '🤵🏻‍♂' => 'man i smoking: ljus hy',
    '🤵🏼‍♂' => 'man i smoking: mellanljus hy',
    '🤵🏽‍♂' => 'man i smoking: mellanfärgad hy',
    '🤵🏾‍♂' => 'man i smoking: mellanmörk hy',
    '🤵🏿‍♂' => 'man i smoking: mörk hy',
    '🤵🏻‍♀' => 'kvinna i smoking: ljus hy',
    '🤵🏼‍♀' => 'kvinna i smoking: mellanljus hy',
    '🤵🏽‍♀' => 'kvinna i smoking: mellanfärgad hy',
    '🤵🏾‍♀' => 'kvinna i smoking: mellanmörk hy',
    '🤵🏿‍♀' => 'kvinna i smoking: mörk hy',
    '👰🏻‍♂' => 'man i brudslöja: ljus hy',
    '👰🏼‍♂' => 'man i brudslöja: mellanljus hy',
    '👰🏽‍♂' => 'man i brudslöja: mellanfärgad hy',
    '👰🏾‍♂' => 'man i brudslöja: mellanmörk hy',
    '👰🏿‍♂' => 'man i brudslöja: mörk hy',
    '👰🏻‍♀' => 'kvinna i brudslöja: ljus hy',
    '👰🏼‍♀' => 'kvinna i brudslöja: mellanljus hy',
    '👰🏽‍♀' => 'kvinna i brudslöja: mellanfärgad hy',
    '👰🏾‍♀' => 'kvinna i brudslöja: mellanmörk hy',
    '👰🏿‍♀' => 'kvinna i brudslöja: mörk hy',
    '👩🏻‍🍼' => 'kvinna matar spädbarn: ljus hy',
    '👩🏼‍🍼' => 'kvinna matar spädbarn: mellanljus hy',
    '👩🏽‍🍼' => 'kvinna matar spädbarn: mellanfärgad hy',
    '👩🏾‍🍼' => 'kvinna matar spädbarn: mellanmörk hy',
    '👩🏿‍🍼' => 'kvinna matar spädbarn: mörk hy',
    '👨🏻‍🍼' => 'man matar spädbarn: ljus hy',
    '👨🏼‍🍼' => 'man matar spädbarn: mellanljus hy',
    '👨🏽‍🍼' => 'man matar spädbarn: mellanfärgad hy',
    '👨🏾‍🍼' => 'man matar spädbarn: mellanmörk hy',
    '👨🏿‍🍼' => 'man matar spädbarn: mörk hy',
    '🧑🏻‍🍼' => 'person ammar spädbarn: ljus hy',
    '🧑🏼‍🍼' => 'person ammar spädbarn: mellanljus hy',
    '🧑🏽‍🍼' => 'person ammar spädbarn: mellanfärgad hy',
    '🧑🏾‍🍼' => 'person ammar spädbarn: mellanmörk hy',
    '🧑🏿‍🍼' => 'person ammar spädbarn: mörk hy',
    '🧑🏻‍🎄' => 'könsneutral tomte: ljus hy',
    '🧑🏼‍🎄' => 'könsneutral tomte: mellanljus hy',
    '🧑🏽‍🎄' => 'könsneutral tomte: mellanfärgad hy',
    '🧑🏾‍🎄' => 'könsneutral tomte: mellanmörk hy',
    '🧑🏿‍🎄' => 'könsneutral tomte: mörk hy',
    '🦸🏻‍♂' => 'manlig superhjälte: ljus hy',
    '🦸🏼‍♂' => 'manlig superhjälte: mellanljus hy',
    '🦸🏽‍♂' => 'manlig superhjälte: mellanfärgad hy',
    '🦸🏾‍♂' => 'manlig superhjälte: mellanmörk hy',
    '🦸🏿‍♂' => 'manlig superhjälte: mörk hy',
    '🦸🏻‍♀' => 'kvinnlig superhjälte: ljus hy',
    '🦸🏼‍♀' => 'kvinnlig superhjälte: mellanljus hy',
    '🦸🏽‍♀' => 'kvinnlig superhjälte: mellanfärgad hy',
    '🦸🏾‍♀' => 'kvinnlig superhjälte: mellanmörk hy',
    '🦸🏿‍♀' => 'kvinnlig superhjälte: mörk hy',
    '🦹🏻‍♂' => 'manlig superskurk: ljus hy',
    '🦹🏼‍♂' => 'manlig superskurk: mellanljus hy',
    '🦹🏽‍♂' => 'manlig superskurk: mellanfärgad hy',
    '🦹🏾‍♂' => 'manlig superskurk: mellanmörk hy',
    '🦹🏿‍♂' => 'manlig superskurk: mörk hy',
    '🦹🏻‍♀' => 'kvinnlig superskurk: ljus hy',
    '🦹🏼‍♀' => 'kvinnlig superskurk: mellanljus hy',
    '🦹🏽‍♀' => 'kvinnlig superskurk: mellanfärgad hy',
    '🦹🏾‍♀' => 'kvinnlig superskurk: mellanmörk hy',
    '🦹🏿‍♀' => 'kvinnlig superskurk: mörk hy',
    '🧙🏻‍♂' => 'manlig magiker: ljus hy',
    '🧙🏼‍♂' => 'manlig magiker: mellanljus hy',
    '🧙🏽‍♂' => 'manlig magiker: mellanfärgad hy',
    '🧙🏾‍♂' => 'manlig magiker: mellanmörk hy',
    '🧙🏿‍♂' => 'manlig magiker: mörk hy',
    '🧙🏻‍♀' => 'kvinnlig magiker: ljus hy',
    '🧙🏼‍♀' => 'kvinnlig magiker: mellanljus hy',
    '🧙🏽‍♀' => 'kvinnlig magiker: mellanfärgad hy',
    '🧙🏾‍♀' => 'kvinnlig magiker: mellanmörk hy',
    '🧙🏿‍♀' => 'kvinnlig magiker: mörk hy',
    '🧚🏻‍♂' => 'manlig älva: ljus hy',
    '🧚🏼‍♂' => 'manlig älva: mellanljus hy',
    '🧚🏽‍♂' => 'manlig älva: mellanfärgad hy',
    '🧚🏾‍♂' => 'manlig älva: mellanmörk hy',
    '🧚🏿‍♂' => 'manlig älva: mörk hy',
    '🧚🏻‍♀' => 'kvinnlig fé: ljus hy',
    '🧚🏼‍♀' => 'kvinnlig fé: mellanljus hy',
    '🧚🏽‍♀' => 'kvinnlig fé: mellanfärgad hy',
    '🧚🏾‍♀' => 'kvinnlig fé: mellanmörk hy',
    '🧚🏿‍♀' => 'kvinnlig fé: mörk hy',
    '🧛🏻‍♂' => 'manlig vampyr: ljus hy',
    '🧛🏼‍♂' => 'manlig vampyr: mellanljus hy',
    '🧛🏽‍♂' => 'manlig vampyr: mellanfärgad hy',
    '🧛🏾‍♂' => 'manlig vampyr: mellanmörk hy',
    '🧛🏿‍♂' => 'manlig vampyr: mörk hy',
    '🧛🏻‍♀' => 'kvinnlig vampyr: ljus hy',
    '🧛🏼‍♀' => 'kvinnlig vampyr: mellanljus hy',
    '🧛🏽‍♀' => 'kvinnlig vampyr: mellanfärgad hy',
    '🧛🏾‍♀' => 'kvinnlig vampyr: mellanmörk hy',
    '🧛🏿‍♀' => 'kvinnlig vampyr: mörk hy',
    '🧜🏻‍♂' => 'strömkarl: ljus hy',
    '🧜🏼‍♂' => 'strömkarl: mellanljus hy',
    '🧜🏽‍♂' => 'strömkarl: mellanfärgad hy',
    '🧜🏾‍♂' => 'strömkarl: mellanmörk hy',
    '🧜🏿‍♂' => 'strömkarl: mörk hy',
    '🧜🏻‍♀' => 'sjöjungfru: ljus hy',
    '🧜🏼‍♀' => 'sjöjungfru: mellanljus hy',
    '🧜🏽‍♀' => 'sjöjungfru: mellanfärgad hy',
    '🧜🏾‍♀' => 'sjöjungfru: mellanmörk hy',
    '🧜🏿‍♀' => 'sjöjungfru: mörk hy',
    '🧝🏻‍♂' => 'manlig alv: ljus hy',
    '🧝🏼‍♂' => 'manlig alv: mellanljus hy',
    '🧝🏽‍♂' => 'manlig alv: mellanfärgad hy',
    '🧝🏾‍♂' => 'manlig alv: mellanmörk hy',
    '🧝🏿‍♂' => 'manlig alv: mörk hy',
    '🧝🏻‍♀' => 'kvinnlig alv: ljus hy',
    '🧝🏼‍♀' => 'kvinnlig alv: mellanljus hy',
    '🧝🏽‍♀' => 'kvinnlig alv: mellanfärgad hy',
    '🧝🏾‍♀' => 'kvinnlig alv: mellanmörk hy',
    '🧝🏿‍♀' => 'kvinnlig alv: mörk hy',
    '💆🏻‍♂' => 'man som blir masserad: ljus hy',
    '💆🏼‍♂' => 'man som blir masserad: mellanljus hy',
    '💆🏽‍♂' => 'man som blir masserad: mellanfärgad hy',
    '💆🏾‍♂' => 'man som blir masserad: mellanmörk hy',
    '💆🏿‍♂' => 'man som blir masserad: mörk hy',
    '💆🏻‍♀' => 'kvinna som blir masserad: ljus hy',
    '💆🏼‍♀' => 'kvinna som blir masserad: mellanljus hy',
    '💆🏽‍♀' => 'kvinna som blir masserad: mellanfärgad hy',
    '💆🏾‍♀' => 'kvinna som blir masserad: mellanmörk hy',
    '💆🏿‍♀' => 'kvinna som blir masserad: mörk hy',
    '💇🏻‍♂' => 'man som får håret klippt: ljus hy',
    '💇🏼‍♂' => 'man som får håret klippt: mellanljus hy',
    '💇🏽‍♂' => 'man som får håret klippt: mellanfärgad hy',
    '💇🏾‍♂' => 'man som får håret klippt: mellanmörk hy',
    '💇🏿‍♂' => 'man som får håret klippt: mörk hy',
    '💇🏻‍♀' => 'kvinna som får håret klippt: ljus hy',
    '💇🏼‍♀' => 'kvinna som får håret klippt: mellanljus hy',
    '💇🏽‍♀' => 'kvinna som får håret klippt: mellanfärgad hy',
    '💇🏾‍♀' => 'kvinna som får håret klippt: mellanmörk hy',
    '💇🏿‍♀' => 'kvinna som får håret klippt: mörk hy',
    '🚶🏻‍♂' => 'man som går: ljus hy',
    '🚶🏼‍♂' => 'man som går: mellanljus hy',
    '🚶🏽‍♂' => 'man som går: mellanfärgad hy',
    '🚶🏾‍♂' => 'man som går: mellanmörk hy',
    '🚶🏿‍♂' => 'man som går: mörk hy',
    '🚶🏻‍♀' => 'kvinna som går: ljus hy',
    '🚶🏼‍♀' => 'kvinna som går: mellanljus hy',
    '🚶🏽‍♀' => 'kvinna som går: mellanfärgad hy',
    '🚶🏾‍♀' => 'kvinna som går: mellanmörk hy',
    '🚶🏿‍♀' => 'kvinna som går: mörk hy',
    '🚶🏻‍➡' => 'fotgängare: ljus hy, åt höger',
    '🚶🏼‍➡' => 'fotgängare: mellanljus hy, åt höger',
    '🚶🏽‍➡' => 'fotgängare: mellanfärgad hy, åt höger',
    '🚶🏾‍➡' => 'fotgängare: mellanmörk hy, åt höger',
    '🚶🏿‍➡' => 'fotgängare: mörk hy, åt höger',
    '🧍🏻‍♂' => 'stående man: ljus hy',
    '🧍🏼‍♂' => 'stående man: mellanljus hy',
    '🧍🏽‍♂' => 'stående man: mellanfärgad hy',
    '🧍🏾‍♂' => 'stående man: mellanmörk hy',
    '🧍🏿‍♂' => 'stående man: mörk hy',
    '🧍🏻‍♀' => 'stående kvinna: ljus hy',
    '🧍🏼‍♀' => 'stående kvinna: mellanljus hy',
    '🧍🏽‍♀' => 'stående kvinna: mellanfärgad hy',
    '🧍🏾‍♀' => 'stående kvinna: mellanmörk hy',
    '🧍🏿‍♀' => 'stående kvinna: mörk hy',
    '🧎🏻‍♂' => 'knäsittande man: ljus hy',
    '🧎🏼‍♂' => 'knäsittande man: mellanljus hy',
    '🧎🏽‍♂' => 'knäsittande man: mellanfärgad hy',
    '🧎🏾‍♂' => 'knäsittande man: mellanmörk hy',
    '🧎🏿‍♂' => 'knäsittande man: mörk hy',
    '🧎🏻‍♀' => 'knäsittande kvinna: ljus hy',
    '🧎🏼‍♀' => 'knäsittande kvinna: mellanljus hy',
    '🧎🏽‍♀' => 'knäsittande kvinna: mellanfärgad hy',
    '🧎🏾‍♀' => 'knäsittande kvinna: mellanmörk hy',
    '🧎🏿‍♀' => 'knäsittande kvinna: mörk hy',
    '🧎🏻‍➡' => 'knäsittande person: ljus hy, åt höger',
    '🧎🏼‍➡' => 'knäsittande person: mellanljus hy, åt höger',
    '🧎🏽‍➡' => 'knäsittande person: mellanfärgad hy, åt höger',
    '🧎🏾‍➡' => 'knäsittande person: mellanmörk hy, åt höger',
    '🧎🏿‍➡' => 'knäsittande person: mörk hy, åt höger',
    '🧑🏻‍🦯' => 'person med vit käpp: ljus hy',
    '🧑🏼‍🦯' => 'person med vit käpp: mellanljus hy',
    '🧑🏽‍🦯' => 'person med vit käpp: mellanfärgad hy',
    '🧑🏾‍🦯' => 'person med vit käpp: mellanmörk hy',
    '🧑🏿‍🦯' => 'person med vit käpp: mörk hy',
    '👨🏻‍🦯' => 'man med vit käpp: ljus hy',
    '👨🏼‍🦯' => 'man med vit käpp: mellanljus hy',
    '👨🏽‍🦯' => 'man med vit käpp: mellanfärgad hy',
    '👨🏾‍🦯' => 'man med vit käpp: mellanmörk hy',
    '👨🏿‍🦯' => 'man med vit käpp: mörk hy',
    '👩🏻‍🦯' => 'kvinna med vit käpp: ljus hy',
    '👩🏼‍🦯' => 'kvinna med vit käpp: mellanljus hy',
    '👩🏽‍🦯' => 'kvinna med vit käpp: mellanfärgad hy',
    '👩🏾‍🦯' => 'kvinna med vit käpp: mellanmörk hy',
    '👩🏿‍🦯' => 'kvinna med vit käpp: mörk hy',
    '🧑🏻‍🦼' => 'person i permobil: ljus hy',
    '🧑🏼‍🦼' => 'person i permobil: mellanljus hy',
    '🧑🏽‍🦼' => 'person i permobil: mellanfärgad hy',
    '🧑🏾‍🦼' => 'person i permobil: mellanmörk hy',
    '🧑🏿‍🦼' => 'person i permobil: mörk hy',
    '👨🏻‍🦼' => 'man i permobil: ljus hy',
    '👨🏼‍🦼' => 'man i permobil: mellanljus hy',
    '👨🏽‍🦼' => 'man i permobil: mellanfärgad hy',
    '👨🏾‍🦼' => 'man i permobil: mellanmörk hy',
    '👨🏿‍🦼' => 'man i permobil: mörk hy',
    '👩🏻‍🦼' => 'kvinna i permobil: ljus hy',
    '👩🏼‍🦼' => 'kvinna i permobil: mellanljus hy',
    '👩🏽‍🦼' => 'kvinna i permobil: mellanfärgad hy',
    '👩🏾‍🦼' => 'kvinna i permobil: mellanmörk hy',
    '👩🏿‍🦼' => 'kvinna i permobil: mörk hy',
    '🧑🏻‍🦽' => 'person i manuell rullstol: ljus hy',
    '🧑🏼‍🦽' => 'person i manuell rullstol: mellanljus hy',
    '🧑🏽‍🦽' => 'person i manuell rullstol: mellanfärgad hy',
    '🧑🏾‍🦽' => 'person i manuell rullstol: mellanmörk hy',
    '🧑🏿‍🦽' => 'person i manuell rullstol: mörk hy',
    '👨🏻‍🦽' => 'man i manuell rullstol: ljus hy',
    '👨🏼‍🦽' => 'man i manuell rullstol: mellanljus hy',
    '👨🏽‍🦽' => 'man i manuell rullstol: mellanfärgad hy',
    '👨🏾‍🦽' => 'man i manuell rullstol: mellanmörk hy',
    '👨🏿‍🦽' => 'man i manuell rullstol: mörk hy',
    '👩🏻‍🦽' => 'kvinna i manuell rullstol: ljus hy',
    '👩🏼‍🦽' => 'kvinna i manuell rullstol: mellanljus hy',
    '👩🏽‍🦽' => 'kvinna i manuell rullstol: mellanfärgad hy',
    '👩🏾‍🦽' => 'kvinna i manuell rullstol: mellanmörk hy',
    '👩🏿‍🦽' => 'kvinna i manuell rullstol: mörk hy',
    '🏃🏻‍♂' => 'man som springer: ljus hy',
    '🏃🏼‍♂' => 'man som springer: mellanljus hy',
    '🏃🏽‍♂' => 'man som springer: mellanfärgad hy',
    '🏃🏾‍♂' => 'man som springer: mellanmörk hy',
    '🏃🏿‍♂' => 'man som springer: mörk hy',
    '🏃🏻‍♀' => 'kvinna som springer: ljus hy',
    '🏃🏼‍♀' => 'kvinna som springer: mellanljus hy',
    '🏃🏽‍♀' => 'kvinna som springer: mellanfärgad hy',
    '🏃🏾‍♀' => 'kvinna som springer: mellanmörk hy',
    '🏃🏿‍♀' => 'kvinna som springer: mörk hy',
    '🏃🏻‍➡' => 'person som springer: ljus hy, åt höger',
    '🏃🏼‍➡' => 'person som springer: mellanljus hy, åt höger',
    '🏃🏽‍➡' => 'person som springer: mellanfärgad hy, åt höger',
    '🏃🏾‍➡' => 'person som springer: mellanmörk hy, åt höger',
    '🏃🏿‍➡' => 'person som springer: mörk hy, åt höger',
    '👯🏻‍♀' => 'kvinnor med kaninöron: ljus hy',
    '👯🏼‍♀' => 'kvinnor med kaninöron: mellanljus hy',
    '👯🏽‍♀' => 'kvinnor med kaninöron: mellanfärgad hy',
    '👯🏾‍♀' => 'kvinnor med kaninöron: mellanmörk hy',
    '👯🏿‍♀' => 'kvinnor med kaninöron: mörk hy',
    '👯🏻‍♂' => 'män med kaninöron: ljus hy',
    '👯🏼‍♂' => 'män med kaninöron: mellanljus hy',
    '👯🏽‍♂' => 'män med kaninöron: mellanfärgad hy',
    '👯🏾‍♂' => 'män med kaninöron: mellanmörk hy',
    '👯🏿‍♂' => 'män med kaninöron: mörk hy',
    '🧖🏻‍♂' => 'man i ångbastu: ljus hy',
    '🧖🏼‍♂' => 'man i ångbastu: mellanljus hy',
    '🧖🏽‍♂' => 'man i ångbastu: mellanfärgad hy',
    '🧖🏾‍♂' => 'man i ångbastu: mellanmörk hy',
    '🧖🏿‍♂' => 'man i ångbastu: mörk hy',
    '🧖🏻‍♀' => 'kvinna i ångbastu: ljus hy',
    '🧖🏼‍♀' => 'kvinna i ångbastu: mellanljus hy',
    '🧖🏽‍♀' => 'kvinna i ångbastu: mellanfärgad hy',
    '🧖🏾‍♀' => 'kvinna i ångbastu: mellanmörk hy',
    '🧖🏿‍♀' => 'kvinna i ångbastu: mörk hy',
    '🧗🏻‍♂' => 'man som klättrar: ljus hy',
    '🧗🏼‍♂' => 'man som klättrar: mellanljus hy',
    '🧗🏽‍♂' => 'man som klättrar: mellanfärgad hy',
    '🧗🏾‍♂' => 'man som klättrar: mellanmörk hy',
    '🧗🏿‍♂' => 'man som klättrar: mörk hy',
    '🧗🏻‍♀' => 'kvinna som klättrar: ljus hy',
    '🧗🏼‍♀' => 'kvinna som klättrar: mellanljus hy',
    '🧗🏽‍♀' => 'kvinna som klättrar: mellanfärgad hy',
    '🧗🏾‍♀' => 'kvinna som klättrar: mellanmörk hy',
    '🧗🏿‍♀' => 'kvinna som klättrar: mörk hy',
    '🏌🏻‍♂' => 'man som spelar golf: ljus hy',
    '🏌🏼‍♂' => 'man som spelar golf: mellanljus hy',
    '🏌🏽‍♂' => 'man som spelar golf: mellanfärgad hy',
    '🏌🏾‍♂' => 'man som spelar golf: mellanmörk hy',
    '🏌🏿‍♂' => 'man som spelar golf: mörk hy',
    '🏌🏻‍♀' => 'kvinna som spelar golf: ljus hy',
    '🏌🏼‍♀' => 'kvinna som spelar golf: mellanljus hy',
    '🏌🏽‍♀' => 'kvinna som spelar golf: mellanfärgad hy',
    '🏌🏾‍♀' => 'kvinna som spelar golf: mellanmörk hy',
    '🏌🏿‍♀' => 'kvinna som spelar golf: mörk hy',
    '🏄🏻‍♂' => 'man som surfar: ljus hy',
    '🏄🏼‍♂' => 'man som surfar: mellanljus hy',
    '🏄🏽‍♂' => 'man som surfar: mellanfärgad hy',
    '🏄🏾‍♂' => 'man som surfar: mellanmörk hy',
    '🏄🏿‍♂' => 'man som surfar: mörk hy',
    '🏄🏻‍♀' => 'kvinna som surfar: ljus hy',
    '🏄🏼‍♀' => 'kvinna som surfar: mellanljus hy',
    '🏄🏽‍♀' => 'kvinna som surfar: mellanfärgad hy',
    '🏄🏾‍♀' => 'kvinna som surfar: mellanmörk hy',
    '🏄🏿‍♀' => 'kvinna som surfar: mörk hy',
    '🚣🏻‍♂' => 'man som ror en båt: ljus hy',
    '🚣🏼‍♂' => 'man som ror en båt: mellanljus hy',
    '🚣🏽‍♂' => 'man som ror en båt: mellanfärgad hy',
    '🚣🏾‍♂' => 'man som ror en båt: mellanmörk hy',
    '🚣🏿‍♂' => 'man som ror en båt: mörk hy',
    '🚣🏻‍♀' => 'kvinna som ror en båt: ljus hy',
    '🚣🏼‍♀' => 'kvinna som ror en båt: mellanljus hy',
    '🚣🏽‍♀' => 'kvinna som ror en båt: mellanfärgad hy',
    '🚣🏾‍♀' => 'kvinna som ror en båt: mellanmörk hy',
    '🚣🏿‍♀' => 'kvinna som ror en båt: mörk hy',
    '🏊🏻‍♂' => 'man som simmar: ljus hy',
    '🏊🏼‍♂' => 'man som simmar: mellanljus hy',
    '🏊🏽‍♂' => 'man som simmar: mellanfärgad hy',
    '🏊🏾‍♂' => 'man som simmar: mellanmörk hy',
    '🏊🏿‍♂' => 'man som simmar: mörk hy',
    '🏊🏻‍♀' => 'kvinna som simmar: ljus hy',
    '🏊🏼‍♀' => 'kvinna som simmar: mellanljus hy',
    '🏊🏽‍♀' => 'kvinna som simmar: mellanfärgad hy',
    '🏊🏾‍♀' => 'kvinna som simmar: mellanmörk hy',
    '🏊🏿‍♀' => 'kvinna som simmar: mörk hy',
    '⛹🏻‍♂' => 'man med boll: ljus hy',
    '⛹🏼‍♂' => 'man med boll: mellanljus hy',
    '⛹🏽‍♂' => 'man med boll: mellanfärgad hy',
    '⛹🏾‍♂' => 'man med boll: mellanmörk hy',
    '⛹🏿‍♂' => 'man med boll: mörk hy',
    '⛹🏻‍♀' => 'kvinna med boll: ljus hy',
    '⛹🏼‍♀' => 'kvinna med boll: mellanljus hy',
    '⛹🏽‍♀' => 'kvinna med boll: mellanfärgad hy',
    '⛹🏾‍♀' => 'kvinna med boll: mellanmörk hy',
    '⛹🏿‍♀' => 'kvinna med boll: mörk hy',
    '🏋🏻‍♂' => 'man som lyfter tyngder: ljus hy',
    '🏋🏼‍♂' => 'man som lyfter tyngder: mellanljus hy',
    '🏋🏽‍♂' => 'man som lyfter tyngder: mellanfärgad hy',
    '🏋🏾‍♂' => 'man som lyfter tyngder: mellanmörk hy',
    '🏋🏿‍♂' => 'man som lyfter tyngder: mörk hy',
    '🏋🏻‍♀' => 'kvinna som lyfter tyngder: ljus hy',
    '🏋🏼‍♀' => 'kvinna som lyfter tyngder: mellanljus hy',
    '🏋🏽‍♀' => 'kvinna som lyfter tyngder: mellanfärgad hy',
    '🏋🏾‍♀' => 'kvinna som lyfter tyngder: mellanmörk hy',
    '🏋🏿‍♀' => 'kvinna som lyfter tyngder: mörk hy',
    '🚴🏻‍♂' => 'man som cyklar: ljus hy',
    '🚴🏼‍♂' => 'man som cyklar: mellanljus hy',
    '🚴🏽‍♂' => 'man som cyklar: mellanfärgad hy',
    '🚴🏾‍♂' => 'man som cyklar: mellanmörk hy',
    '🚴🏿‍♂' => 'man som cyklar: mörk hy',
    '🚴🏻‍♀' => 'kvinna som cyklar: ljus hy',
    '🚴🏼‍♀' => 'kvinna som cyklar: mellanljus hy',
    '🚴🏽‍♀' => 'kvinna som cyklar: mellanfärgad hy',
    '🚴🏾‍♀' => 'kvinna som cyklar: mellanmörk hy',
    '🚴🏿‍♀' => 'kvinna som cyklar: mörk hy',
    '🚵🏻‍♂' => 'man som cyklar på en mountainbike: ljus hy',
    '🚵🏼‍♂' => 'man som cyklar på en mountainbike: mellanljus hy',
    '🚵🏽‍♂' => 'man som cyklar på en mountainbike: mellanfärgad hy',
    '🚵🏾‍♂' => 'man som cyklar på en mountainbike: mellanmörk hy',
    '🚵🏿‍♂' => 'man som cyklar på en mountainbike: mörk hy',
    '🚵🏻‍♀' => 'kvinna som cyklar på en mountainbike: ljus hy',
    '🚵🏼‍♀' => 'kvinna som cyklar på en mountainbike: mellanljus hy',
    '🚵🏽‍♀' => 'kvinna som cyklar på en mountainbike: mellanfärgad hy',
    '🚵🏾‍♀' => 'kvinna som cyklar på en mountainbike: mellanmörk hy',
    '🚵🏿‍♀' => 'kvinna som cyklar på en mountainbike: mörk hy',
    '🤸🏻‍♂' => 'man som hjular: ljus hy',
    '🤸🏼‍♂' => 'man som hjular: mellanljus hy',
    '🤸🏽‍♂' => 'man som hjular: mellanfärgad hy',
    '🤸🏾‍♂' => 'man som hjular: mellanmörk hy',
    '🤸🏿‍♂' => 'man som hjular: mörk hy',
    '🤸🏻‍♀' => 'kvinna som hjular: ljus hy',
    '🤸🏼‍♀' => 'kvinna som hjular: mellanljus hy',
    '🤸🏽‍♀' => 'kvinna som hjular: mellanfärgad hy',
    '🤸🏾‍♀' => 'kvinna som hjular: mellanmörk hy',
    '🤸🏿‍♀' => 'kvinna som hjular: mörk hy',
    '🤼🏻‍♀' => 'brottande kvinnor: ljus hy',
    '🤼🏼‍♀' => 'brottande kvinnor: mellanljus hy',
    '🤼🏽‍♀' => 'brottande kvinnor: mellanfärgad hy',
    '🤼🏾‍♀' => 'brottande kvinnor: mellanmörk hy',
    '🤼🏿‍♀' => 'brottande kvinnor: mörk hy',
    '🤼🏻‍♂' => 'brottande män: ljus hy',
    '🤼🏼‍♂' => 'brottande män: mellanljus hy',
    '🤼🏽‍♂' => 'brottande män: mellanfärgad hy',
    '🤼🏾‍♂' => 'brottande män: mellanmörk hy',
    '🤼🏿‍♂' => 'brottande män: mörk hy',
    '🤽🏻‍♂' => 'man som spelar vattenpolo: ljus hy',
    '🤽🏼‍♂' => 'man som spelar vattenpolo: mellanljus hy',
    '🤽🏽‍♂' => 'man som spelar vattenpolo: mellanfärgad hy',
    '🤽🏾‍♂' => 'man som spelar vattenpolo: mellanmörk hy',
    '🤽🏿‍♂' => 'man som spelar vattenpolo: mörk hy',
    '🤽🏻‍♀' => 'kvinna som spelar vattenpolo: ljus hy',
    '🤽🏼‍♀' => 'kvinna som spelar vattenpolo: mellanljus hy',
    '🤽🏽‍♀' => 'kvinna som spelar vattenpolo: mellanfärgad hy',
    '🤽🏾‍♀' => 'kvinna som spelar vattenpolo: mellanmörk hy',
    '🤽🏿‍♀' => 'kvinna som spelar vattenpolo: mörk hy',
    '🤾🏻‍♂' => 'man som spelar handboll: ljus hy',
    '🤾🏼‍♂' => 'man som spelar handboll: mellanljus hy',
    '🤾🏽‍♂' => 'man som spelar handboll: mellanfärgad hy',
    '🤾🏾‍♂' => 'man som spelar handboll: mellanmörk hy',
    '🤾🏿‍♂' => 'man som spelar handboll: mörk hy',
    '🤾🏻‍♀' => 'kvinna som spelar handboll: ljus hy',
    '🤾🏼‍♀' => 'kvinna som spelar handboll: mellanljus hy',
    '🤾🏽‍♀' => 'kvinna som spelar handboll: mellanfärgad hy',
    '🤾🏾‍♀' => 'kvinna som spelar handboll: mellanmörk hy',
    '🤾🏿‍♀' => 'kvinna som spelar handboll: mörk hy',
    '🤹🏻‍♂' => 'man som jonglerar: ljus hy',
    '🤹🏼‍♂' => 'man som jonglerar: mellanljus hy',
    '🤹🏽‍♂' => 'man som jonglerar: mellanfärgad hy',
    '🤹🏾‍♂' => 'man som jonglerar: mellanmörk hy',
    '🤹🏿‍♂' => 'man som jonglerar: mörk hy',
    '🤹🏻‍♀' => 'kvinna som jonglerar: ljus hy',
    '🤹🏼‍♀' => 'kvinna som jonglerar: mellanljus hy',
    '🤹🏽‍♀' => 'kvinna som jonglerar: mellanfärgad hy',
    '🤹🏾‍♀' => 'kvinna som jonglerar: mellanmörk hy',
    '🤹🏿‍♀' => 'kvinna som jonglerar: mörk hy',
    '🧘🏻‍♂' => 'man i lotusposition: ljus hy',
    '🧘🏼‍♂' => 'man i lotusposition: mellanljus hy',
    '🧘🏽‍♂' => 'man i lotusposition: mellanfärgad hy',
    '🧘🏾‍♂' => 'man i lotusposition: mellanmörk hy',
    '🧘🏿‍♂' => 'man i lotusposition: mörk hy',
    '🧘🏻‍♀' => 'kvinna i lotusposition: ljus hy',
    '🧘🏼‍♀' => 'kvinna i lotusposition: mellanljus hy',
    '🧘🏽‍♀' => 'kvinna i lotusposition: mellanfärgad hy',
    '🧘🏾‍♀' => 'kvinna i lotusposition: mellanmörk hy',
    '🧘🏿‍♀' => 'kvinna i lotusposition: mörk hy',
    '🧑‍🦰' => 'person: rödhårig',
    '🧑‍🦱' => 'person: lockigt hår',
    '🧑‍🦳' => 'person: vithårig',
    '🧑‍🦲' => 'person: skallig',
    '👨‍🦰' => 'man: rödhårig',
    '👨‍🦱' => 'man: lockigt hår',
    '👨‍🦳' => 'man: vithårig',
    '👨‍🦲' => 'man: skallig',
    '👩‍🦰' => 'kvinna: rödhårig',
    '👩‍🦱' => 'kvinna: lockigt hår',
    '👩‍🦳' => 'kvinna: vithårig',
    '👩‍🦲' => 'kvinna: skallig',
    '🚶‍➡' => 'fotgängare: åt höger',
    '🧎‍➡' => 'knäsittande person: åt höger',
    '🏃‍➡' => 'person som springer: åt höger',
    '👨‍👦' => 'familj: man, pojke',
    '👨‍👧' => 'familj: man, flicka',
    '👩‍👦' => 'familj: kvinna, pojke',
    '👩‍👧' => 'familj: kvinna, flicka',
    '😶‍🌫' => 'ansikte i moln',
    '😮‍💨' => 'ansikte andas ut',
    '🙂‍↕' => 'huvud skakar vertikalt',
    '😵‍💫' => 'ansikte med spiralögon',
    '❤‍🔥' => 'brinnande hjärta',
    '❤‍🩹' => 'läkande hjärta',
    '👁‍🗨' => 'öga i pratbubbla',
    '🧔‍♂' => 'man: skägg',
    '👱‍♂' => 'blond man',
    '🧔‍♀' => 'kvinna: skägg',
    '👱‍♀' => 'blond kvinna',
    '🙍‍♂' => 'sur man',
    '🙍‍♀' => 'sur kvinna',
    '🙎‍♂' => 'plutande man',
    '🙎‍♀' => 'plutande kvinna',
    '🙅‍♂' => 'man gestikulerar NEJ',
    '🙅‍♀' => 'kvinna gestikulerar NEJ',
    '🙆‍♂' => 'man gestikulerar OK',
    '🙆‍♀' => 'kvinna gestikulerar OK',
    '💁‍♂' => 'hjälpande man',
    '💁‍♀' => 'hjälpande kvinna',
    '🙋‍♂' => 'man som räcker upp handen',
    '🙋‍♀' => 'kvinna som räcker upp handen',
    '🧏‍♂' => 'hörselskadad man',
    '🧏‍♀' => 'hörselskadad kvinna',
    '🙇‍♂' => 'bugande man',
    '🙇‍♀' => 'bugande kvinna',
    '🤦‍♂' => 'man som slår sig för pannan',
    '🤦‍♀' => 'kvinna som slår sig för pannan',
    '🤷‍♂' => 'man som rycker på axlarna',
    '🤷‍♀' => 'kvinna som rycker på axlarna',
    '🧑‍⚕' => 'läkare',
    '👨‍⚕' => 'manlig läkare',
    '👩‍⚕' => 'kvinnlig läkare',
    '🧑‍🎓' => 'student',
    '👨‍🎓' => 'manlig student',
    '👩‍🎓' => 'kvinnlig student',
    '🧑‍🏫' => 'lärare',
    '👨‍🏫' => 'manlig lärare',
    '👩‍🏫' => 'kvinnlig lärare',
    '🧑‍⚖' => 'domare',
    '👨‍⚖' => 'manlig domare',
    '👩‍⚖' => 'kvinnlig domare',
    '🧑‍🌾' => 'bonde',
    '👨‍🌾' => 'manlig bonde',
    '👩‍🌾' => 'kvinnlig bonde',
    '🧑‍🍳' => 'kock',
    '👨‍🍳' => 'manlig kock',
    '👩‍🍳' => 'kvinnlig kock',
    '🧑‍🔧' => 'mekaniker',
    '👨‍🔧' => 'manlig mekaniker',
    '👩‍🔧' => 'kvinnlig mekaniker',
    '🧑‍🏭' => 'fabriksarbetare',
    '👨‍🏭' => 'manlig fabriksarbetare',
    '👩‍🏭' => 'kvinnlig fabriksarbetare',
    '🧑‍💼' => 'kontorist',
    '👨‍💼' => 'kontorstjänsteman',
    '👩‍💼' => 'kontorstjänstekvinna',
    '🧑‍🔬' => 'forskare',
    '👨‍🔬' => 'manlig forskare',
    '👩‍🔬' => 'kvinnlig forskare',
    '🧑‍💻' => 'IT-tekniker',
    '👨‍💻' => 'manlig IT-expert',
    '👩‍💻' => 'kvinnlig IT-expert',
    '🧑‍🎤' => 'sångare',
    '👨‍🎤' => 'manlig sångare',
    '👩‍🎤' => 'kvinnlig sångare',
    '🧑‍🎨' => 'konstnär',
    '👨‍🎨' => 'manlig konstnär',
    '👩‍🎨' => 'kvinnlig konstnär',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'manlig pilot',
    '👩‍✈' => 'kvinnlig pilot',
    '🧑‍🚀' => 'astronaut',
    '👨‍🚀' => 'manlig astronaut',
    '👩‍🚀' => 'kvinnlig astronaut',
    '🧑‍🚒' => 'brandman',
    '👨‍🚒' => 'manlig brandman',
    '👩‍🚒' => 'kvinnlig brandman',
    '👮‍♂' => 'manlig polis',
    '👮‍♀' => 'kvinnlig polis',
    '🕵‍♂' => 'manlig detektiv',
    '🕵‍♀' => 'kvinnlig detektiv',
    '💂‍♂' => 'manlig grenadjär',
    '💂‍♀' => 'kvinnlig grenadjär',
    '👷‍♂' => 'manlig byggarbetare',
    '👷‍♀' => 'kvinnlig byggarbetare',
    '👳‍♂' => 'man i turban',
    '👳‍♀' => 'kvinna i turban',
    '🤵‍♂' => 'man i smoking',
    '🤵‍♀' => 'kvinna i smoking',
    '👰‍♂' => 'man i brudslöja',
    '👰‍♀' => 'kvinna i brudslöja',
    '👩‍🍼' => 'kvinna matar spädbarn',
    '👨‍🍼' => 'man matar spädbarn',
    '🧑‍🍼' => 'person ammar spädbarn',
    '🧑‍🎄' => 'könsneutral tomte',
    '🦸‍♂' => 'manlig superhjälte',
    '🦸‍♀' => 'kvinnlig superhjälte',
    '🦹‍♂' => 'manlig superskurk',
    '🦹‍♀' => 'kvinnlig superskurk',
    '🧙‍♂' => 'manlig magiker',
    '🧙‍♀' => 'kvinnlig magiker',
    '🧚‍♂' => 'manlig älva',
    '🧚‍♀' => 'kvinnlig fé',
    '🧛‍♂' => 'manlig vampyr',
    '🧛‍♀' => 'kvinnlig vampyr',
    '🧜‍♂' => 'strömkarl',
    '🧜‍♀' => 'sjöjungfru',
    '🧝‍♂' => 'manlig alv',
    '🧝‍♀' => 'kvinnlig alv',
    '🧞‍♂' => 'manlig ande',
    '🧞‍♀' => 'kvinnlig ande',
    '🧟‍♂' => 'manlig zombie',
    '🧟‍♀' => 'kvinnlig zombie',
    '💆‍♂' => 'man som blir masserad',
    '💆‍♀' => 'kvinna som blir masserad',
    '💇‍♂' => 'man som får håret klippt',
    '💇‍♀' => 'kvinna som får håret klippt',
    '🚶‍♂' => 'man som går',
    '🚶‍♀' => 'kvinna som går',
    '🧍‍♂' => 'stående man',
    '🧍‍♀' => 'stående kvinna',
    '🧎‍♂' => 'knäsittande man',
    '🧎‍♀' => 'knäsittande kvinna',
    '🧑‍🦯' => 'person med vit käpp',
    '👨‍🦯' => 'man med vit käpp',
    '👩‍🦯' => 'kvinna med vit käpp',
    '🧑‍🦼' => 'person i permobil',
    '👨‍🦼' => 'man i permobil',
    '👩‍🦼' => 'kvinna i permobil',
    '🧑‍🦽' => 'person i manuell rullstol',
    '👨‍🦽' => 'man i manuell rullstol',
    '👩‍🦽' => 'kvinna i manuell rullstol',
    '🏃‍♂' => 'man som springer',
    '🏃‍♀' => 'kvinna som springer',
    '🧑‍🩰' => 'balettdansare',
    '👯‍♂' => 'män med kaninöron',
    '👯‍♀' => 'kvinnor med kaninöron',
    '🧖‍♂' => 'man i ångbastu',
    '🧖‍♀' => 'kvinna i ångbastu',
    '🧗‍♂' => 'man som klättrar',
    '🧗‍♀' => 'kvinna som klättrar',
    '🏌‍♂' => 'man som spelar golf',
    '🏌‍♀' => 'kvinna som spelar golf',
    '🏄‍♂' => 'man som surfar',
    '🏄‍♀' => 'kvinna som surfar',
    '🚣‍♂' => 'man som ror en båt',
    '🚣‍♀' => 'kvinna som ror en båt',
    '🏊‍♂' => 'man som simmar',
    '🏊‍♀' => 'kvinna som simmar',
    '⛹‍♂' => 'man med boll',
    '⛹‍♀' => 'kvinna med boll',
    '🏋‍♂' => 'man som lyfter tyngder',
    '🏋‍♀' => 'kvinna som lyfter tyngder',
    '🚴‍♂' => 'man som cyklar',
    '🚴‍♀' => 'kvinna som cyklar',
    '🚵‍♂' => 'man som cyklar på en mountainbike',
    '🚵‍♀' => 'kvinna som cyklar på en mountainbike',
    '🤸‍♂' => 'man som hjular',
    '🤸‍♀' => 'kvinna som hjular',
    '🤼‍♂' => 'brottande män',
    '🤼‍♀' => 'brottande kvinnor',
    '🤽‍♂' => 'man som spelar vattenpolo',
    '🤽‍♀' => 'kvinna som spelar vattenpolo',
    '🤾‍♂' => 'man som spelar handboll',
    '🤾‍♀' => 'kvinna som spelar handboll',
    '🤹‍♂' => 'man som jonglerar',
    '🤹‍♀' => 'kvinna som jonglerar',
    '🧘‍♂' => 'man i lotusposition',
    '🧘‍♀' => 'kvinna i lotusposition',
    '🧑‍🧒' => 'familj: vuxen, barn',
    '🐕‍🦺' => 'servicehund',
    '🐈‍⬛' => 'svart katt',
    '🐻‍❄' => 'isbjörn',
    '🐦‍⬛' => 'koltrast',
    '🐦‍🔥' => 'fenix',
    '🍋‍🟩' => 'lime',
    '🍄‍🟫' => 'brun svamp',
    '⛓‍💥' => 'bruten länk',
    '🏳‍🌈' => 'regnbågsflagga',
    '🏳‍⚧' => 'transflagga',
    '🏴‍☠' => 'sjörövarflagga',
    '👋🏻' => 'vinkande hand: ljus hy',
    '👋🏼' => 'vinkande hand: mellanljus hy',
    '👋🏽' => 'vinkande hand: mellanfärgad hy',
    '👋🏾' => 'vinkande hand: mellanmörk hy',
    '👋🏿' => 'vinkande hand: mörk hy',
    '🤚🏻' => 'höjd handrygg: ljus hy',
    '🤚🏼' => 'höjd handrygg: mellanljus hy',
    '🤚🏽' => 'höjd handrygg: mellanfärgad hy',
    '🤚🏾' => 'höjd handrygg: mellanmörk hy',
    '🤚🏿' => 'höjd handrygg: mörk hy',
    '🖐🏻' => 'hand med utspretade fingrar: ljus hy',
    '🖐🏼' => 'hand med utspretade fingrar: mellanljus hy',
    '🖐🏽' => 'hand med utspretade fingrar: mellanfärgad hy',
    '🖐🏾' => 'hand med utspretade fingrar: mellanmörk hy',
    '🖐🏿' => 'hand med utspretade fingrar: mörk hy',
    '✋🏻' => 'hand i luften: ljus hy',
    '✋🏼' => 'hand i luften: mellanljus hy',
    '✋🏽' => 'hand i luften: mellanfärgad hy',
    '✋🏾' => 'hand i luften: mellanmörk hy',
    '✋🏿' => 'hand i luften: mörk hy',
    '🖖🏻' => 'vulcan-hälsning: ljus hy',
    '🖖🏼' => 'vulcan-hälsning: mellanljus hy',
    '🖖🏽' => 'vulcan-hälsning: mellanfärgad hy',
    '🖖🏾' => 'vulcan-hälsning: mellanmörk hy',
    '🖖🏿' => 'vulcan-hälsning: mörk hy',
    '🫱🏻' => 'hand som pekar till höger: ljus hy',
    '🫱🏼' => 'hand som pekar till höger: mellanljus hy',
    '🫱🏽' => 'hand som pekar till höger: mellanfärgad hy',
    '🫱🏾' => 'hand som pekar till höger: mellanmörk hy',
    '🫱🏿' => 'hand som pekar till höger: mörk hy',
    '🫲🏻' => 'hand som pekar till vänster: ljus hy',
    '🫲🏼' => 'hand som pekar till vänster: mellanljus hy',
    '🫲🏽' => 'hand som pekar till vänster: mellanfärgad hy',
    '🫲🏾' => 'hand som pekar till vänster: mellanmörk hy',
    '🫲🏿' => 'hand som pekar till vänster: mörk hy',
    '🫳🏻' => 'handflatan nedåt: ljus hy',
    '🫳🏼' => 'handflatan nedåt: mellanljus hy',
    '🫳🏽' => 'handflatan nedåt: mellanfärgad hy',
    '🫳🏾' => 'handflatan nedåt: mellanmörk hy',
    '🫳🏿' => 'handflatan nedåt: mörk hy',
    '🫴🏻' => 'handflatan uppåt: ljus hy',
    '🫴🏼' => 'handflatan uppåt: mellanljus hy',
    '🫴🏽' => 'handflatan uppåt: mellanfärgad hy',
    '🫴🏾' => 'handflatan uppåt: mellanmörk hy',
    '🫴🏿' => 'handflatan uppåt: mörk hy',
    '🫷🏻' => 'hand som knuffar åt vänster: ljus hy',
    '🫷🏼' => 'hand som knuffar åt vänster: mellanljus hy',
    '🫷🏽' => 'hand som knuffar åt vänster: mellanfärgad hy',
    '🫷🏾' => 'hand som knuffar åt vänster: mellanmörk hy',
    '🫷🏿' => 'hand som knuffar åt vänster: mörk hy',
    '🫸🏻' => 'hand som knuffar åt höger: ljus hy',
    '🫸🏼' => 'hand som knuffar åt höger: mellanljus hy',
    '🫸🏽' => 'hand som knuffar åt höger: mellanfärgad hy',
    '🫸🏾' => 'hand som knuffar åt höger: mellanmörk hy',
    '🫸🏿' => 'hand som knuffar åt höger: mörk hy',
    '👌🏻' => 'OK-tecken: ljus hy',
    '👌🏼' => 'OK-tecken: mellanljus hy',
    '👌🏽' => 'OK-tecken: mellanfärgad hy',
    '👌🏾' => 'OK-tecken: mellanmörk hy',
    '👌🏿' => 'OK-tecken: mörk hy',
    '🤌🏻' => 'fingerportmonnä: ljus hy',
    '🤌🏼' => 'fingerportmonnä: mellanljus hy',
    '🤌🏽' => 'fingerportmonnä: mellanfärgad hy',
    '🤌🏾' => 'fingerportmonnä: mellanmörk hy',
    '🤌🏿' => 'fingerportmonnä: mörk hy',
    '🤏🏻' => 'nypande hand: ljus hy',
    '🤏🏼' => 'nypande hand: mellanljus hy',
    '🤏🏽' => 'nypande hand: mellanfärgad hy',
    '🤏🏾' => 'nypande hand: mellanmörk hy',
    '🤏🏿' => 'nypande hand: mörk hy',
    '✌🏻' => 'v-tecken: ljus hy',
    '✌🏼' => 'v-tecken: mellanljus hy',
    '✌🏽' => 'v-tecken: mellanfärgad hy',
    '✌🏾' => 'v-tecken: mellanmörk hy',
    '✌🏿' => 'v-tecken: mörk hy',
    '🤞🏻' => 'korsade fingrar: ljus hy',
    '🤞🏼' => 'korsade fingrar: mellanljus hy',
    '🤞🏽' => 'korsade fingrar: mellanfärgad hy',
    '🤞🏾' => 'korsade fingrar: mellanmörk hy',
    '🤞🏿' => 'korsade fingrar: mörk hy',
    '🫰🏻' => 'hand med tummen och pekfingret korsade: ljus hy',
    '🫰🏼' => 'hand med tummen och pekfingret korsade: mellanljus hy',
    '🫰🏽' => 'hand med tummen och pekfingret korsade: mellanfärgad hy',
    '🫰🏾' => 'hand med tummen och pekfingret korsade: mellanmörk hy',
    '🫰🏿' => 'hand med tummen och pekfingret korsade: mörk hy',
    '🤟🏻' => 'jag älskar dig-gest: ljus hy',
    '🤟🏼' => 'jag älskar dig-gest: mellanljus hy',
    '🤟🏽' => 'jag älskar dig-gest: mellanfärgad hy',
    '🤟🏾' => 'jag älskar dig-gest: mellanmörk hy',
    '🤟🏿' => 'jag älskar dig-gest: mörk hy',
    '🤘🏻' => 'djävulstecknet: ljus hy',
    '🤘🏼' => 'djävulstecknet: mellanljus hy',
    '🤘🏽' => 'djävulstecknet: mellanfärgad hy',
    '🤘🏾' => 'djävulstecknet: mellanmörk hy',
    '🤘🏿' => 'djävulstecknet: mörk hy',
    '🤙🏻' => 'ring mig-hand: ljus hy',
    '🤙🏼' => 'ring mig-hand: mellanljus hy',
    '🤙🏽' => 'ring mig-hand: mellanfärgad hy',
    '🤙🏾' => 'ring mig-hand: mellanmörk hy',
    '🤙🏿' => 'ring mig-hand: mörk hy',
    '👈🏻' => 'vänsterpekande finger: ljus hy',
    '👈🏼' => 'vänsterpekande finger: mellanljus hy',
    '👈🏽' => 'vänsterpekande finger: mellanfärgad hy',
    '👈🏾' => 'vänsterpekande finger: mellanmörk hy',
    '👈🏿' => 'vänsterpekande finger: mörk hy',
    '👉🏻' => 'högerpekande finger: ljus hy',
    '👉🏼' => 'högerpekande finger: mellanljus hy',
    '👉🏽' => 'högerpekande finger: mellanfärgad hy',
    '👉🏾' => 'högerpekande finger: mellanmörk hy',
    '👉🏿' => 'högerpekande finger: mörk hy',
    '👆🏻' => 'pekfinger upp: ljus hy',
    '👆🏼' => 'pekfinger upp: mellanljus hy',
    '👆🏽' => 'pekfinger upp: mellanfärgad hy',
    '👆🏾' => 'pekfinger upp: mellanmörk hy',
    '👆🏿' => 'pekfinger upp: mörk hy',
    '🖕🏻' => 'långfinger upp: ljus hy',
    '🖕🏼' => 'långfinger upp: mellanljus hy',
    '🖕🏽' => 'långfinger upp: mellanfärgad hy',
    '🖕🏾' => 'långfinger upp: mellanmörk hy',
    '🖕🏿' => 'långfinger upp: mörk hy',
    '👇🏻' => 'nedåtpekande finger: ljus hy',
    '👇🏼' => 'nedåtpekande finger: mellanljus hy',
    '👇🏽' => 'nedåtpekande finger: mellanfärgad hy',
    '👇🏾' => 'nedåtpekande finger: mellanmörk hy',
    '👇🏿' => 'nedåtpekande finger: mörk hy',
    '☝🏻' => 'finger upp: ljus hy',
    '☝🏼' => 'finger upp: mellanljus hy',
    '☝🏽' => 'finger upp: mellanfärgad hy',
    '☝🏾' => 'finger upp: mellanmörk hy',
    '☝🏿' => 'finger upp: mörk hy',
    '🫵🏻' => 'finger som pekar på mig: ljus hy',
    '🫵🏼' => 'finger som pekar på mig: mellanljus hy',
    '🫵🏽' => 'finger som pekar på mig: mellanfärgad hy',
    '🫵🏾' => 'finger som pekar på mig: mellanmörk hy',
    '🫵🏿' => 'finger som pekar på mig: mörk hy',
    '👍🏻' => 'tummen upp: ljus hy',
    '👍🏼' => 'tummen upp: mellanljus hy',
    '👍🏽' => 'tummen upp: mellanfärgad hy',
    '👍🏾' => 'tummen upp: mellanmörk hy',
    '👍🏿' => 'tummen upp: mörk hy',
    '👎🏻' => 'tummen ned: ljus hy',
    '👎🏼' => 'tummen ned: mellanljus hy',
    '👎🏽' => 'tummen ned: mellanfärgad hy',
    '👎🏾' => 'tummen ned: mellanmörk hy',
    '👎🏿' => 'tummen ned: mörk hy',
    '✊🏻' => 'knytnäve i luften: ljus hy',
    '✊🏼' => 'knytnäve i luften: mellanljus hy',
    '✊🏽' => 'knytnäve i luften: mellanfärgad hy',
    '✊🏾' => 'knytnäve i luften: mellanmörk hy',
    '✊🏿' => 'knytnäve i luften: mörk hy',
    '👊🏻' => 'knuten hand: ljus hy',
    '👊🏼' => 'knuten hand: mellanljus hy',
    '👊🏽' => 'knuten hand: mellanfärgad hy',
    '👊🏾' => 'knuten hand: mellanmörk hy',
    '👊🏿' => 'knuten hand: mörk hy',
    '🤛🏻' => 'vänstervänd näve: ljus hy',
    '🤛🏼' => 'vänstervänd näve: mellanljus hy',
    '🤛🏽' => 'vänstervänd näve: mellanfärgad hy',
    '🤛🏾' => 'vänstervänd näve: mellanmörk hy',
    '🤛🏿' => 'vänstervänd näve: mörk hy',
    '🤜🏻' => 'högervänd näve: ljus hy',
    '🤜🏼' => 'högervänd näve: mellanljus hy',
    '🤜🏽' => 'högervänd näve: mellanfärgad hy',
    '🤜🏾' => 'högervänd näve: mellanmörk hy',
    '🤜🏿' => 'högervänd näve: mörk hy',
    '👏🏻' => 'klappande händer: ljus hy',
    '👏🏼' => 'klappande händer: mellanljus hy',
    '👏🏽' => 'klappande händer: mellanfärgad hy',
    '👏🏾' => 'klappande händer: mellanmörk hy',
    '👏🏿' => 'klappande händer: mörk hy',
    '🙌🏻' => 'båda händerna i luften: ljus hy',
    '🙌🏼' => 'båda händerna i luften: mellanljus hy',
    '🙌🏽' => 'båda händerna i luften: mellanfärgad hy',
    '🙌🏾' => 'båda händerna i luften: mellanmörk hy',
    '🙌🏿' => 'båda händerna i luften: mörk hy',
    '🫶🏻' => 'handhjärta: ljus hy',
    '🫶🏼' => 'handhjärta: mellanljus hy',
    '🫶🏽' => 'handhjärta: mellanfärgad hy',
    '🫶🏾' => 'handhjärta: mellanmörk hy',
    '🫶🏿' => 'handhjärta: mörk hy',
    '👐🏻' => 'öppna händer: ljus hy',
    '👐🏼' => 'öppna händer: mellanljus hy',
    '👐🏽' => 'öppna händer: mellanfärgad hy',
    '👐🏾' => 'öppna händer: mellanmörk hy',
    '👐🏿' => 'öppna händer: mörk hy',
    '🤲🏻' => 'handflatorna upp: ljus hy',
    '🤲🏼' => 'handflatorna upp: mellanljus hy',
    '🤲🏽' => 'handflatorna upp: mellanfärgad hy',
    '🤲🏾' => 'handflatorna upp: mellanmörk hy',
    '🤲🏿' => 'handflatorna upp: mörk hy',
    '🤝🏻' => 'handskakning: ljus hy',
    '🤝🏼' => 'handskakning: mellanljus hy',
    '🤝🏽' => 'handskakning: mellanfärgad hy',
    '🤝🏾' => 'handskakning: mellanmörk hy',
    '🤝🏿' => 'handskakning: mörk hy',
    '🙏🏻' => 'beende händer: ljus hy',
    '🙏🏼' => 'beende händer: mellanljus hy',
    '🙏🏽' => 'beende händer: mellanfärgad hy',
    '🙏🏾' => 'beende händer: mellanmörk hy',
    '🙏🏿' => 'beende händer: mörk hy',
    '✍🏻' => 'hand som skriver: ljus hy',
    '✍🏼' => 'hand som skriver: mellanljus hy',
    '✍🏽' => 'hand som skriver: mellanfärgad hy',
    '✍🏾' => 'hand som skriver: mellanmörk hy',
    '✍🏿' => 'hand som skriver: mörk hy',
    '💅🏻' => 'nagellack: ljus hy',
    '💅🏼' => 'nagellack: mellanljus hy',
    '💅🏽' => 'nagellack: mellanfärgad hy',
    '💅🏾' => 'nagellack: mellanmörk hy',
    '💅🏿' => 'nagellack: mörk hy',
    '🤳🏻' => 'selfie: ljus hy',
    '🤳🏼' => 'selfie: mellanljus hy',
    '🤳🏽' => 'selfie: mellanfärgad hy',
    '🤳🏾' => 'selfie: mellanmörk hy',
    '🤳🏿' => 'selfie: mörk hy',
    '💪🏻' => 'spänd biceps: ljus hy',
    '💪🏼' => 'spänd biceps: mellanljus hy',
    '💪🏽' => 'spänd biceps: mellanfärgad hy',
    '💪🏾' => 'spänd biceps: mellanmörk hy',
    '💪🏿' => 'spänd biceps: mörk hy',
    '🦵🏻' => 'ben: ljus hy',
    '🦵🏼' => 'ben: mellanljus hy',
    '🦵🏽' => 'ben: mellanfärgad hy',
    '🦵🏾' => 'ben: mellanmörk hy',
    '🦵🏿' => 'ben: mörk hy',
    '🦶🏻' => 'fot: ljus hy',
    '🦶🏼' => 'fot: mellanljus hy',
    '🦶🏽' => 'fot: mellanfärgad hy',
    '🦶🏾' => 'fot: mellanmörk hy',
    '🦶🏿' => 'fot: mörk hy',
    '👂🏻' => 'öra: ljus hy',
    '👂🏼' => 'öra: mellanljus hy',
    '👂🏽' => 'öra: mellanfärgad hy',
    '👂🏾' => 'öra: mellanmörk hy',
    '👂🏿' => 'öra: mörk hy',
    '🦻🏻' => 'öra med hörapparat: ljus hy',
    '🦻🏼' => 'öra med hörapparat: mellanljus hy',
    '🦻🏽' => 'öra med hörapparat: mellanfärgad hy',
    '🦻🏾' => 'öra med hörapparat: mellanmörk hy',
    '🦻🏿' => 'öra med hörapparat: mörk hy',
    '👃🏻' => 'näsa: ljus hy',
    '👃🏼' => 'näsa: mellanljus hy',
    '👃🏽' => 'näsa: mellanfärgad hy',
    '👃🏾' => 'näsa: mellanmörk hy',
    '👃🏿' => 'näsa: mörk hy',
    '👶🏻' => 'bebis: ljus hy',
    '👶🏼' => 'bebis: mellanljus hy',
    '👶🏽' => 'bebis: mellanfärgad hy',
    '👶🏾' => 'bebis: mellanmörk hy',
    '👶🏿' => 'bebis: mörk hy',
    '🧒🏻' => 'barn: ljus hy',
    '🧒🏼' => 'barn: mellanljus hy',
    '🧒🏽' => 'barn: mellanfärgad hy',
    '🧒🏾' => 'barn: mellanmörk hy',
    '🧒🏿' => 'barn: mörk hy',
    '👦🏻' => 'pojke: ljus hy',
    '👦🏼' => 'pojke: mellanljus hy',
    '👦🏽' => 'pojke: mellanfärgad hy',
    '👦🏾' => 'pojke: mellanmörk hy',
    '👦🏿' => 'pojke: mörk hy',
    '👧🏻' => 'flicka: ljus hy',
    '👧🏼' => 'flicka: mellanljus hy',
    '👧🏽' => 'flicka: mellanfärgad hy',
    '👧🏾' => 'flicka: mellanmörk hy',
    '👧🏿' => 'flicka: mörk hy',
    '🧑🏻' => 'person: ljus hy',
    '🧑🏼' => 'person: mellanljus hy',
    '🧑🏽' => 'person: mellanfärgad hy',
    '🧑🏾' => 'person: mellanmörk hy',
    '🧑🏿' => 'person: mörk hy',
    '👱🏻' => 'blond person: ljus hy',
    '👱🏼' => 'blond person: mellanljus hy',
    '👱🏽' => 'blond person: mellanfärgad hy',
    '👱🏾' => 'blond person: mellanmörk hy',
    '👱🏿' => 'blond person: mörk hy',
    '👨🏻' => 'man: ljus hy',
    '👨🏼' => 'man: mellanljus hy',
    '👨🏽' => 'man: mellanfärgad hy',
    '👨🏾' => 'man: mellanmörk hy',
    '👨🏿' => 'man: mörk hy',
    '🧔🏻' => 'man med skägg: ljus hy',
    '🧔🏼' => 'man med skägg: mellanljus hy',
    '🧔🏽' => 'man med skägg: mellanfärgad hy',
    '🧔🏾' => 'man med skägg: mellanmörk hy',
    '🧔🏿' => 'man med skägg: mörk hy',
    '👩🏻' => 'kvinna: ljus hy',
    '👩🏼' => 'kvinna: mellanljus hy',
    '👩🏽' => 'kvinna: mellanfärgad hy',
    '👩🏾' => 'kvinna: mellanmörk hy',
    '👩🏿' => 'kvinna: mörk hy',
    '🧓🏻' => 'äldre person: ljus hy',
    '🧓🏼' => 'äldre person: mellanljus hy',
    '🧓🏽' => 'äldre person: mellanfärgad hy',
    '🧓🏾' => 'äldre person: mellanmörk hy',
    '🧓🏿' => 'äldre person: mörk hy',
    '👴🏻' => 'gammal man: ljus hy',
    '👴🏼' => 'gammal man: mellanljus hy',
    '👴🏽' => 'gammal man: mellanfärgad hy',
    '👴🏾' => 'gammal man: mellanmörk hy',
    '👴🏿' => 'gammal man: mörk hy',
    '👵🏻' => 'gammal kvinna: ljus hy',
    '👵🏼' => 'gammal kvinna: mellanljus hy',
    '👵🏽' => 'gammal kvinna: mellanfärgad hy',
    '👵🏾' => 'gammal kvinna: mellanmörk hy',
    '👵🏿' => 'gammal kvinna: mörk hy',
    '🙍🏻' => 'sur person: ljus hy',
    '🙍🏼' => 'sur person: mellanljus hy',
    '🙍🏽' => 'sur person: mellanfärgad hy',
    '🙍🏾' => 'sur person: mellanmörk hy',
    '🙍🏿' => 'sur person: mörk hy',
    '🙎🏻' => 'plutande person: ljus hy',
    '🙎🏼' => 'plutande person: mellanljus hy',
    '🙎🏽' => 'plutande person: mellanfärgad hy',
    '🙎🏾' => 'plutande person: mellanmörk hy',
    '🙎🏿' => 'plutande person: mörk hy',
    '🙅🏻' => 'person gestikulerar NEJ: ljus hy',
    '🙅🏼' => 'person gestikulerar NEJ: mellanljus hy',
    '🙅🏽' => 'person gestikulerar NEJ: mellanfärgad hy',
    '🙅🏾' => 'person gestikulerar NEJ: mellanmörk hy',
    '🙅🏿' => 'person gestikulerar NEJ: mörk hy',
    '🙆🏻' => 'person gestikulerar OK: ljus hy',
    '🙆🏼' => 'person gestikulerar OK: mellanljus hy',
    '🙆🏽' => 'person gestikulerar OK: mellanfärgad hy',
    '🙆🏾' => 'person gestikulerar OK: mellanmörk hy',
    '🙆🏿' => 'person gestikulerar OK: mörk hy',
    '💁🏻' => 'receptionist: ljus hy',
    '💁🏼' => 'receptionist: mellanljus hy',
    '💁🏽' => 'receptionist: mellanfärgad hy',
    '💁🏾' => 'receptionist: mellanmörk hy',
    '💁🏿' => 'receptionist: mörk hy',
    '🙋🏻' => 'person som räcker upp handen: ljus hy',
    '🙋🏼' => 'person som räcker upp handen: mellanljus hy',
    '🙋🏽' => 'person som räcker upp handen: mellanfärgad hy',
    '🙋🏾' => 'person som räcker upp handen: mellanmörk hy',
    '🙋🏿' => 'person som räcker upp handen: mörk hy',
    '🧏🏻' => 'hörselskadad person: ljus hy',
    '🧏🏼' => 'hörselskadad person: mellanljus hy',
    '🧏🏽' => 'hörselskadad person: mellanfärgad hy',
    '🧏🏾' => 'hörselskadad person: mellanmörk hy',
    '🧏🏿' => 'hörselskadad person: mörk hy',
    '🙇🏻' => 'bugande person: ljus hy',
    '🙇🏼' => 'bugande person: mellanljus hy',
    '🙇🏽' => 'bugande person: mellanfärgad hy',
    '🙇🏾' => 'bugande person: mellanmörk hy',
    '🙇🏿' => 'bugande person: mörk hy',
    '🤦🏻' => 'person som slår sig för pannan: ljus hy',
    '🤦🏼' => 'person som slår sig för pannan: mellanljus hy',
    '🤦🏽' => 'person som slår sig för pannan: mellanfärgad hy',
    '🤦🏾' => 'person som slår sig för pannan: mellanmörk hy',
    '🤦🏿' => 'person som slår sig för pannan: mörk hy',
    '🤷🏻' => 'person som rycker på axlarna: ljus hy',
    '🤷🏼' => 'person som rycker på axlarna: mellanljus hy',
    '🤷🏽' => 'person som rycker på axlarna: mellanfärgad hy',
    '🤷🏾' => 'person som rycker på axlarna: mellanmörk hy',
    '🤷🏿' => 'person som rycker på axlarna: mörk hy',
    '👮🏻' => 'polis: ljus hy',
    '👮🏼' => 'polis: mellanljus hy',
    '👮🏽' => 'polis: mellanfärgad hy',
    '👮🏾' => 'polis: mellanmörk hy',
    '👮🏿' => 'polis: mörk hy',
    '🕵🏻' => 'detektiv: ljus hy',
    '🕵🏼' => 'detektiv: mellanljus hy',
    '🕵🏽' => 'detektiv: mellanfärgad hy',
    '🕵🏾' => 'detektiv: mellanmörk hy',
    '🕵🏿' => 'detektiv: mörk hy',
    '💂🏻' => 'vakt: ljus hy',
    '💂🏼' => 'vakt: mellanljus hy',
    '💂🏽' => 'vakt: mellanfärgad hy',
    '💂🏾' => 'vakt: mellanmörk hy',
    '💂🏿' => 'vakt: mörk hy',
    '🥷🏻' => 'ninja: ljus hy',
    '🥷🏼' => 'ninja: mellanljus hy',
    '🥷🏽' => 'ninja: mellanfärgad hy',
    '🥷🏾' => 'ninja: mellanmörk hy',
    '🥷🏿' => 'ninja: mörk hy',
    '👷🏻' => 'byggarbetare: ljus hy',
    '👷🏼' => 'byggarbetare: mellanljus hy',
    '👷🏽' => 'byggarbetare: mellanfärgad hy',
    '👷🏾' => 'byggarbetare: mellanmörk hy',
    '👷🏿' => 'byggarbetare: mörk hy',
    '🫅🏻' => 'person med krona: ljus hy',
    '🫅🏼' => 'person med krona: mellanljus hy',
    '🫅🏽' => 'person med krona: mellanfärgad hy',
    '🫅🏾' => 'person med krona: mellanmörk hy',
    '🫅🏿' => 'person med krona: mörk hy',
    '🤴🏻' => 'prins: ljus hy',
    '🤴🏼' => 'prins: mellanljus hy',
    '🤴🏽' => 'prins: mellanfärgad hy',
    '🤴🏾' => 'prins: mellanmörk hy',
    '🤴🏿' => 'prins: mörk hy',
    '👸🏻' => 'prinsessa: ljus hy',
    '👸🏼' => 'prinsessa: mellanljus hy',
    '👸🏽' => 'prinsessa: mellanfärgad hy',
    '👸🏾' => 'prinsessa: mellanmörk hy',
    '👸🏿' => 'prinsessa: mörk hy',
    '👳🏻' => 'man med turban: ljus hy',
    '👳🏼' => 'man med turban: mellanljus hy',
    '👳🏽' => 'man med turban: mellanfärgad hy',
    '👳🏾' => 'man med turban: mellanmörk hy',
    '👳🏿' => 'man med turban: mörk hy',
    '👲🏻' => 'man med kinesisk hatt: ljus hy',
    '👲🏼' => 'man med kinesisk hatt: mellanljus hy',
    '👲🏽' => 'man med kinesisk hatt: mellanfärgad hy',
    '👲🏾' => 'man med kinesisk hatt: mellanmörk hy',
    '👲🏿' => 'man med kinesisk hatt: mörk hy',
    '🧕🏻' => 'kvinna i sjal: ljus hy',
    '🧕🏼' => 'kvinna i sjal: mellanljus hy',
    '🧕🏽' => 'kvinna i sjal: mellanfärgad hy',
    '🧕🏾' => 'kvinna i sjal: mellanmörk hy',
    '🧕🏿' => 'kvinna i sjal: mörk hy',
    '🤵🏻' => 'person i smoking: ljus hy',
    '🤵🏼' => 'person i smoking: mellanljus hy',
    '🤵🏽' => 'person i smoking: mellanfärgad hy',
    '🤵🏾' => 'person i smoking: mellanmörk hy',
    '🤵🏿' => 'person i smoking: mörk hy',
    '👰🏻' => 'person i brudslöja: ljus hy',
    '👰🏼' => 'person i brudslöja: mellanljus hy',
    '👰🏽' => 'person i brudslöja: mellanfärgad hy',
    '👰🏾' => 'person i brudslöja: mellanmörk hy',
    '👰🏿' => 'person i brudslöja: mörk hy',
    '🤰🏻' => 'gravid kvinna: ljus hy',
    '🤰🏼' => 'gravid kvinna: mellanljus hy',
    '🤰🏽' => 'gravid kvinna: mellanfärgad hy',
    '🤰🏾' => 'gravid kvinna: mellanmörk hy',
    '🤰🏿' => 'gravid kvinna: mörk hy',
    '🫃🏻' => 'gravid man: ljus hy',
    '🫃🏼' => 'gravid man: mellanljus hy',
    '🫃🏽' => 'gravid man: mellanfärgad hy',
    '🫃🏾' => 'gravid man: mellanmörk hy',
    '🫃🏿' => 'gravid man: mörk hy',
    '🫄🏻' => 'gravid person: ljus hy',
    '🫄🏼' => 'gravid person: mellanljus hy',
    '🫄🏽' => 'gravid person: mellanfärgad hy',
    '🫄🏾' => 'gravid person: mellanmörk hy',
    '🫄🏿' => 'gravid person: mörk hy',
    '🤱🏻' => 'amning: ljus hy',
    '🤱🏼' => 'amning: mellanljus hy',
    '🤱🏽' => 'amning: mellanfärgad hy',
    '🤱🏾' => 'amning: mellanmörk hy',
    '🤱🏿' => 'amning: mörk hy',
    '👼🏻' => 'bebisängel: ljus hy',
    '👼🏼' => 'bebisängel: mellanljus hy',
    '👼🏽' => 'bebisängel: mellanfärgad hy',
    '👼🏾' => 'bebisängel: mellanmörk hy',
    '👼🏿' => 'bebisängel: mörk hy',
    '🎅🏻' => 'jultomte: ljus hy',
    '🎅🏼' => 'jultomte: mellanljus hy',
    '🎅🏽' => 'jultomte: mellanfärgad hy',
    '🎅🏾' => 'jultomte: mellanmörk hy',
    '🎅🏿' => 'jultomte: mörk hy',
    '🤶🏻' => 'tomtemor: ljus hy',
    '🤶🏼' => 'tomtemor: mellanljus hy',
    '🤶🏽' => 'tomtemor: mellanfärgad hy',
    '🤶🏾' => 'tomtemor: mellanmörk hy',
    '🤶🏿' => 'tomtemor: mörk hy',
    '🦸🏻' => 'superhjälte: ljus hy',
    '🦸🏼' => 'superhjälte: mellanljus hy',
    '🦸🏽' => 'superhjälte: mellanfärgad hy',
    '🦸🏾' => 'superhjälte: mellanmörk hy',
    '🦸🏿' => 'superhjälte: mörk hy',
    '🦹🏻' => 'superskurk: ljus hy',
    '🦹🏼' => 'superskurk: mellanljus hy',
    '🦹🏽' => 'superskurk: mellanfärgad hy',
    '🦹🏾' => 'superskurk: mellanmörk hy',
    '🦹🏿' => 'superskurk: mörk hy',
    '🧙🏻' => 'magiker: ljus hy',
    '🧙🏼' => 'magiker: mellanljus hy',
    '🧙🏽' => 'magiker: mellanfärgad hy',
    '🧙🏾' => 'magiker: mellanmörk hy',
    '🧙🏿' => 'magiker: mörk hy',
    '🧚🏻' => 'fé: ljus hy',
    '🧚🏼' => 'fé: mellanljus hy',
    '🧚🏽' => 'fé: mellanfärgad hy',
    '🧚🏾' => 'fé: mellanmörk hy',
    '🧚🏿' => 'fé: mörk hy',
    '🧛🏻' => 'vampyr: ljus hy',
    '🧛🏼' => 'vampyr: mellanljus hy',
    '🧛🏽' => 'vampyr: mellanfärgad hy',
    '🧛🏾' => 'vampyr: mellanmörk hy',
    '🧛🏿' => 'vampyr: mörk hy',
    '🧜🏻' => 'vattenväsen: ljus hy',
    '🧜🏼' => 'vattenväsen: mellanljus hy',
    '🧜🏽' => 'vattenväsen: mellanfärgad hy',
    '🧜🏾' => 'vattenväsen: mellanmörk hy',
    '🧜🏿' => 'vattenväsen: mörk hy',
    '🧝🏻' => 'alv: ljus hy',
    '🧝🏼' => 'alv: mellanljus hy',
    '🧝🏽' => 'alv: mellanfärgad hy',
    '🧝🏾' => 'alv: mellanmörk hy',
    '🧝🏿' => 'alv: mörk hy',
    '💆🏻' => 'person som blir masserad: ljus hy',
    '💆🏼' => 'person som blir masserad: mellanljus hy',
    '💆🏽' => 'person som blir masserad: mellanfärgad hy',
    '💆🏾' => 'person som blir masserad: mellanmörk hy',
    '💆🏿' => 'person som blir masserad: mörk hy',
    '💇🏻' => 'person som får håret klippt: ljus hy',
    '💇🏼' => 'person som får håret klippt: mellanljus hy',
    '💇🏽' => 'person som får håret klippt: mellanfärgad hy',
    '💇🏾' => 'person som får håret klippt: mellanmörk hy',
    '💇🏿' => 'person som får håret klippt: mörk hy',
    '🚶🏻' => 'fotgängare: ljus hy',
    '🚶🏼' => 'fotgängare: mellanljus hy',
    '🚶🏽' => 'fotgängare: mellanfärgad hy',
    '🚶🏾' => 'fotgängare: mellanmörk hy',
    '🚶🏿' => 'fotgängare: mörk hy',
    '🧍🏻' => 'stående person: ljus hy',
    '🧍🏼' => 'stående person: mellanljus hy',
    '🧍🏽' => 'stående person: mellanfärgad hy',
    '🧍🏾' => 'stående person: mellanmörk hy',
    '🧍🏿' => 'stående person: mörk hy',
    '🧎🏻' => 'knäsittande person: ljus hy',
    '🧎🏼' => 'knäsittande person: mellanljus hy',
    '🧎🏽' => 'knäsittande person: mellanfärgad hy',
    '🧎🏾' => 'knäsittande person: mellanmörk hy',
    '🧎🏿' => 'knäsittande person: mörk hy',
    '🏃🏻' => 'person som springer: ljus hy',
    '🏃🏼' => 'person som springer: mellanljus hy',
    '🏃🏽' => 'person som springer: mellanfärgad hy',
    '🏃🏾' => 'person som springer: mellanmörk hy',
    '🏃🏿' => 'person som springer: mörk hy',
    '💃🏻' => 'dansande kvinna: ljus hy',
    '💃🏼' => 'dansande kvinna: mellanljus hy',
    '💃🏽' => 'dansande kvinna: mellanfärgad hy',
    '💃🏾' => 'dansande kvinna: mellanmörk hy',
    '💃🏿' => 'dansande kvinna: mörk hy',
    '🕺🏻' => 'dansande man: ljus hy',
    '🕺🏼' => 'dansande man: mellanljus hy',
    '🕺🏽' => 'dansande man: mellanfärgad hy',
    '🕺🏾' => 'dansande man: mellanmörk hy',
    '🕺🏿' => 'dansande man: mörk hy',
    '🕴🏻' => 'svävande man i kostym: ljus hy',
    '🕴🏼' => 'svävande man i kostym: mellanljus hy',
    '🕴🏽' => 'svävande man i kostym: mellanfärgad hy',
    '🕴🏾' => 'svävande man i kostym: mellanmörk hy',
    '🕴🏿' => 'svävande man i kostym: mörk hy',
    '👯🏻' => 'personer med kaninöron: ljus hy',
    '👯🏼' => 'personer med kaninöron: mellanljus hy',
    '👯🏽' => 'personer med kaninöron: mellanfärgad hy',
    '👯🏾' => 'personer med kaninöron: mellanmörk hy',
    '👯🏿' => 'personer med kaninöron: mörk hy',
    '🧖🏻' => 'person i ångbastu: ljus hy',
    '🧖🏼' => 'person i ångbastu: mellanljus hy',
    '🧖🏽' => 'person i ångbastu: mellanfärgad hy',
    '🧖🏾' => 'person i ångbastu: mellanmörk hy',
    '🧖🏿' => 'person i ångbastu: mörk hy',
    '🧗🏻' => 'person som klättrar: ljus hy',
    '🧗🏼' => 'person som klättrar: mellanljus hy',
    '🧗🏽' => 'person som klättrar: mellanfärgad hy',
    '🧗🏾' => 'person som klättrar: mellanmörk hy',
    '🧗🏿' => 'person som klättrar: mörk hy',
    '🏇🏻' => 'hästkapplöpning: ljus hy',
    '🏇🏼' => 'hästkapplöpning: mellanljus hy',
    '🏇🏽' => 'hästkapplöpning: mellanfärgad hy',
    '🏇🏾' => 'hästkapplöpning: mellanmörk hy',
    '🏇🏿' => 'hästkapplöpning: mörk hy',
    '🏂🏻' => 'snowboardåkare: ljus hy',
    '🏂🏼' => 'snowboardåkare: mellanljus hy',
    '🏂🏽' => 'snowboardåkare: mellanfärgad hy',
    '🏂🏾' => 'snowboardåkare: mellanmörk hy',
    '🏂🏿' => 'snowboardåkare: mörk hy',
    '🏌🏻' => 'person som spelar golf: ljus hy',
    '🏌🏼' => 'person som spelar golf: mellanljus hy',
    '🏌🏽' => 'person som spelar golf: mellanfärgad hy',
    '🏌🏾' => 'person som spelar golf: mellanmörk hy',
    '🏌🏿' => 'person som spelar golf: mörk hy',
    '🏄🏻' => 'person som surfar: ljus hy',
    '🏄🏼' => 'person som surfar: mellanljus hy',
    '🏄🏽' => 'person som surfar: mellanfärgad hy',
    '🏄🏾' => 'person som surfar: mellanmörk hy',
    '🏄🏿' => 'person som surfar: mörk hy',
    '🚣🏻' => 'person som ror en båt: ljus hy',
    '🚣🏼' => 'person som ror en båt: mellanljus hy',
    '🚣🏽' => 'person som ror en båt: mellanfärgad hy',
    '🚣🏾' => 'person som ror en båt: mellanmörk hy',
    '🚣🏿' => 'person som ror en båt: mörk hy',
    '🏊🏻' => 'person som simmar: ljus hy',
    '🏊🏼' => 'person som simmar: mellanljus hy',
    '🏊🏽' => 'person som simmar: mellanfärgad hy',
    '🏊🏾' => 'person som simmar: mellanmörk hy',
    '🏊🏿' => 'person som simmar: mörk hy',
    '⛹🏻' => 'person med boll: ljus hy',
    '⛹🏼' => 'person med boll: mellanljus hy',
    '⛹🏽' => 'person med boll: mellanfärgad hy',
    '⛹🏾' => 'person med boll: mellanmörk hy',
    '⛹🏿' => 'person med boll: mörk hy',
    '🏋🏻' => 'person som lyfter tyngder: ljus hy',
    '🏋🏼' => 'person som lyfter tyngder: mellanljus hy',
    '🏋🏽' => 'person som lyfter tyngder: mellanfärgad hy',
    '🏋🏾' => 'person som lyfter tyngder: mellanmörk hy',
    '🏋🏿' => 'person som lyfter tyngder: mörk hy',
    '🚴🏻' => 'person som cyklar: ljus hy',
    '🚴🏼' => 'person som cyklar: mellanljus hy',
    '🚴🏽' => 'person som cyklar: mellanfärgad hy',
    '🚴🏾' => 'person som cyklar: mellanmörk hy',
    '🚴🏿' => 'person som cyklar: mörk hy',
    '🚵🏻' => 'person som cyklar på en mountainbike: ljus hy',
    '🚵🏼' => 'person som cyklar på en mountainbike: mellanljus hy',
    '🚵🏽' => 'person som cyklar på en mountainbike: mellanfärgad hy',
    '🚵🏾' => 'person som cyklar på en mountainbike: mellanmörk hy',
    '🚵🏿' => 'person som cyklar på en mountainbike: mörk hy',
    '🤸🏻' => 'person som hjular: ljus hy',
    '🤸🏼' => 'person som hjular: mellanljus hy',
    '🤸🏽' => 'person som hjular: mellanfärgad hy',
    '🤸🏾' => 'person som hjular: mellanmörk hy',
    '🤸🏿' => 'person som hjular: mörk hy',
    '🤼🏻' => 'brottande personer: ljus hy',
    '🤼🏼' => 'brottande personer: mellanljus hy',
    '🤼🏽' => 'brottande personer: mellanfärgad hy',
    '🤼🏾' => 'brottande personer: mellanmörk hy',
    '🤼🏿' => 'brottande personer: mörk hy',
    '🤽🏻' => 'person som spelar vattenpolo: ljus hy',
    '🤽🏼' => 'person som spelar vattenpolo: mellanljus hy',
    '🤽🏽' => 'person som spelar vattenpolo: mellanfärgad hy',
    '🤽🏾' => 'person som spelar vattenpolo: mellanmörk hy',
    '🤽🏿' => 'person som spelar vattenpolo: mörk hy',
    '🤾🏻' => 'person som spelar handboll: ljus hy',
    '🤾🏼' => 'person som spelar handboll: mellanljus hy',
    '🤾🏽' => 'person som spelar handboll: mellanfärgad hy',
    '🤾🏾' => 'person som spelar handboll: mellanmörk hy',
    '🤾🏿' => 'person som spelar handboll: mörk hy',
    '🤹🏻' => 'person som jonglerar: ljus hy',
    '🤹🏼' => 'person som jonglerar: mellanljus hy',
    '🤹🏽' => 'person som jonglerar: mellanfärgad hy',
    '🤹🏾' => 'person som jonglerar: mellanmörk hy',
    '🤹🏿' => 'person som jonglerar: mörk hy',
    '🧘🏻' => 'person i lotusposition: ljus hy',
    '🧘🏼' => 'person i lotusposition: mellanljus hy',
    '🧘🏽' => 'person i lotusposition: mellanfärgad hy',
    '🧘🏾' => 'person i lotusposition: mellanmörk hy',
    '🧘🏿' => 'person i lotusposition: mörk hy',
    '🛀🏻' => 'person som badar: ljus hy',
    '🛀🏼' => 'person som badar: mellanljus hy',
    '🛀🏽' => 'person som badar: mellanfärgad hy',
    '🛀🏾' => 'person som badar: mellanmörk hy',
    '🛀🏿' => 'person som badar: mörk hy',
    '🛌🏻' => 'person i en säng: ljus hy',
    '🛌🏼' => 'person i en säng: mellanljus hy',
    '🛌🏽' => 'person i en säng: mellanfärgad hy',
    '🛌🏾' => 'person i en säng: mellanmörk hy',
    '🛌🏿' => 'person i en säng: mörk hy',
    '👭🏻' => 'två kvinnor håller hand: ljus hy',
    '👭🏼' => 'två kvinnor håller hand: mellanljus hy',
    '👭🏽' => 'två kvinnor håller hand: mellanfärgad hy',
    '👭🏾' => 'två kvinnor håller hand: mellanmörk hy',
    '👭🏿' => 'två kvinnor håller hand: mörk hy',
    '👫🏻' => 'man och kvinna håller hand: ljus hy',
    '👫🏼' => 'man och kvinna håller hand: mellanljus hy',
    '👫🏽' => 'man och kvinna håller hand: mellanfärgad hy',
    '👫🏾' => 'man och kvinna håller hand: mellanmörk hy',
    '👫🏿' => 'man och kvinna håller hand: mörk hy',
    '👬🏻' => 'två män håller hand: ljus hy',
    '👬🏼' => 'två män håller hand: mellanljus hy',
    '👬🏽' => 'två män håller hand: mellanfärgad hy',
    '👬🏾' => 'två män håller hand: mellanmörk hy',
    '👬🏿' => 'två män håller hand: mörk hy',
    '💏🏻' => 'puss: ljus hy',
    '💏🏼' => 'puss: mellanljus hy',
    '💏🏽' => 'puss: mellanfärgad hy',
    '💏🏾' => 'puss: mellanmörk hy',
    '💏🏿' => 'puss: mörk hy',
    '💑🏻' => 'par med hjärta: ljus hy',
    '💑🏼' => 'par med hjärta: mellanljus hy',
    '💑🏽' => 'par med hjärta: mellanfärgad hy',
    '💑🏾' => 'par med hjärta: mellanmörk hy',
    '💑🏿' => 'par med hjärta: mörk hy',
    '🇦🇨' => 'flagga: Ascension',
    '🇦🇩' => 'flagga: Andorra',
    '🇦🇪' => 'flagga: Förenade Arabemiraten',
    '🇦🇫' => 'flagga: Afghanistan',
    '🇦🇬' => 'flagga: Antigua och Barbuda',
    '🇦🇮' => 'flagga: Anguilla',
    '🇦🇱' => 'flagga: Albanien',
    '🇦🇲' => 'flagga: Armenien',
    '🇦🇴' => 'flagga: Angola',
    '🇦🇶' => 'flagga: Antarktis',
    '🇦🇷' => 'flagga: Argentina',
    '🇦🇸' => 'flagga: Amerikanska Samoa',
    '🇦🇹' => 'flagga: Österrike',
    '🇦🇺' => 'flagga: Australien',
    '🇦🇼' => 'flagga: Aruba',
    '🇦🇽' => 'flagga: Åland',
    '🇦🇿' => 'flagga: Azerbajdzjan',
    '🇧🇦' => 'flagga: Bosnien och Hercegovina',
    '🇧🇧' => 'flagga: Barbados',
    '🇧🇩' => 'flagga: Bangladesh',
    '🇧🇪' => 'flagga: Belgien',
    '🇧🇫' => 'flagga: Burkina Faso',
    '🇧🇬' => 'flagga: Bulgarien',
    '🇧🇭' => 'flagga: Bahrain',
    '🇧🇮' => 'flagga: Burundi',
    '🇧🇯' => 'flagga: Benin',
    '🇧🇱' => 'flagga: S:t Barthélemy',
    '🇧🇲' => 'flagga: Bermuda',
    '🇧🇳' => 'flagga: Brunei',
    '🇧🇴' => 'flagga: Bolivia',
    '🇧🇶' => 'flagga: Karibiska Nederländerna',
    '🇧🇷' => 'flagga: Brasilien',
    '🇧🇸' => 'flagga: Bahamas',
    '🇧🇹' => 'flagga: Bhutan',
    '🇧🇻' => 'flagga: Bouvetön',
    '🇧🇼' => 'flagga: Botswana',
    '🇧🇾' => 'flagga: Belarus',
    '🇧🇿' => 'flagga: Belize',
    '🇨🇦' => 'flagga: Kanada',
    '🇨🇨' => 'flagga: Kokosöarna',
    '🇨🇩' => 'flagga: Kongo-Kinshasa',
    '🇨🇫' => 'flagga: Centralafrikanska republiken',
    '🇨🇬' => 'flagga: Kongo-Brazzaville',
    '🇨🇭' => 'flagga: Schweiz',
    '🇨🇮' => 'flagga: Elfenbenskusten',
    '🇨🇰' => 'flagga: Cooköarna',
    '🇨🇱' => 'flagga: Chile',
    '🇨🇲' => 'flagga: Kamerun',
    '🇨🇳' => 'flagga: Kina',
    '🇨🇴' => 'flagga: Colombia',
    '🇨🇵' => 'flagga: Clippertonön',
    '🇨🇶' => 'flagga: Sark',
    '🇨🇷' => 'flagga: Costa Rica',
    '🇨🇺' => 'flagga: Kuba',
    '🇨🇻' => 'flagga: Kap Verde',
    '🇨🇼' => 'flagga: Curaçao',
    '🇨🇽' => 'flagga: Julön',
    '🇨🇾' => 'flagga: Cypern',
    '🇨🇿' => 'flagga: Tjeckien',
    '🇩🇪' => 'flagga: Tyskland',
    '🇩🇬' => 'flagga: Diego Garcia',
    '🇩🇯' => 'flagga: Djibouti',
    '🇩🇰' => 'flagga: Danmark',
    '🇩🇲' => 'flagga: Dominica',
    '🇩🇴' => 'flagga: Dominikanska republiken',
    '🇩🇿' => 'flagga: Algeriet',
    '🇪🇦' => 'flagga: Ceuta och Melilla',
    '🇪🇨' => 'flagga: Ecuador',
    '🇪🇪' => 'flagga: Estland',
    '🇪🇬' => 'flagga: Egypten',
    '🇪🇭' => 'flagga: Västsahara',
    '🇪🇷' => 'flagga: Eritrea',
    '🇪🇸' => 'flagga: Spanien',
    '🇪🇹' => 'flagga: Etiopien',
    '🇪🇺' => 'flagga: Europeiska unionen',
    '🇫🇮' => 'flagga: Finland',
    '🇫🇯' => 'flagga: Fiji',
    '🇫🇰' => 'flagga: Falklandsöarna',
    '🇫🇲' => 'flagga: Mikronesien',
    '🇫🇴' => 'flagga: Färöarna',
    '🇫🇷' => 'flagga: Frankrike',
    '🇬🇦' => 'flagga: Gabon',
    '🇬🇧' => 'flagga: Storbritannien',
    '🇬🇩' => 'flagga: Grenada',
    '🇬🇪' => 'flagga: Georgien',
    '🇬🇫' => 'flagga: Franska Guyana',
    '🇬🇬' => 'flagga: Guernsey',
    '🇬🇭' => 'flagga: Ghana',
    '🇬🇮' => 'flagga: Gibraltar',
    '🇬🇱' => 'flagga: Grönland',
    '🇬🇲' => 'flagga: Gambia',
    '🇬🇳' => 'flagga: Guinea',
    '🇬🇵' => 'flagga: Guadeloupe',
    '🇬🇶' => 'flagga: Ekvatorialguinea',
    '🇬🇷' => 'flagga: Grekland',
    '🇬🇸' => 'flagga: Sydgeorgien och Sydsandwichöarna',
    '🇬🇹' => 'flagga: Guatemala',
    '🇬🇺' => 'flagga: Guam',
    '🇬🇼' => 'flagga: Guinea-Bissau',
    '🇬🇾' => 'flagga: Guyana',
    '🇭🇰' => 'flagga: Hongkong SAR',
    '🇭🇲' => 'flagga: Heardön och McDonaldöarna',
    '🇭🇳' => 'flagga: Honduras',
    '🇭🇷' => 'flagga: Kroatien',
    '🇭🇹' => 'flagga: Haiti',
    '🇭🇺' => 'flagga: Ungern',
    '🇮🇨' => 'flagga: Kanarieöarna',
    '🇮🇩' => 'flagga: Indonesien',
    '🇮🇪' => 'flagga: Irland',
    '🇮🇱' => 'flagga: Israel',
    '🇮🇲' => 'flagga: Isle of Man',
    '🇮🇳' => 'flagga: Indien',
    '🇮🇴' => 'flagga: Brittiska territoriet i Indiska oceanen',
    '🇮🇶' => 'flagga: Irak',
    '🇮🇷' => 'flagga: Iran',
    '🇮🇸' => 'flagga: Island',
    '🇮🇹' => 'flagga: Italien',
    '🇯🇪' => 'flagga: Jersey',
    '🇯🇲' => 'flagga: Jamaica',
    '🇯🇴' => 'flagga: Jordanien',
    '🇯🇵' => 'flagga: Japan',
    '🇰🇪' => 'flagga: Kenya',
    '🇰🇬' => 'flagga: Kirgizistan',
    '🇰🇭' => 'flagga: Kambodja',
    '🇰🇮' => 'flagga: Kiribati',
    '🇰🇲' => 'flagga: Komorerna',
    '🇰🇳' => 'flagga: S:t Kitts och Nevis',
    '🇰🇵' => 'flagga: Nordkorea',
    '🇰🇷' => 'flagga: Sydkorea',
    '🇰🇼' => 'flagga: Kuwait',
    '🇰🇾' => 'flagga: Caymanöarna',
    '🇰🇿' => 'flagga: Kazakstan',
    '🇱🇦' => 'flagga: Laos',
    '🇱🇧' => 'flagga: Libanon',
    '🇱🇨' => 'flagga: S:t Lucia',
    '🇱🇮' => 'flagga: Liechtenstein',
    '🇱🇰' => 'flagga: Sri Lanka',
    '🇱🇷' => 'flagga: Liberia',
    '🇱🇸' => 'flagga: Lesotho',
    '🇱🇹' => 'flagga: Litauen',
    '🇱🇺' => 'flagga: Luxemburg',
    '🇱🇻' => 'flagga: Lettland',
    '🇱🇾' => 'flagga: Libyen',
    '🇲🇦' => 'flagga: Marocko',
    '🇲🇨' => 'flagga: Monaco',
    '🇲🇩' => 'flagga: Moldavien',
    '🇲🇪' => 'flagga: Montenegro',
    '🇲🇫' => 'flagga: Saint-Martin',
    '🇲🇬' => 'flagga: Madagaskar',
    '🇲🇭' => 'flagga: Marshallöarna',
    '🇲🇰' => 'flagga: Nordmakedonien',
    '🇲🇱' => 'flagga: Mali',
    '🇲🇲' => 'flagga: Myanmar (Burma)',
    '🇲🇳' => 'flagga: Mongoliet',
    '🇲🇴' => 'flagga: Macao SAR',
    '🇲🇵' => 'flagga: Nordmarianerna',
    '🇲🇶' => 'flagga: Martinique',
    '🇲🇷' => 'flagga: Mauretanien',
    '🇲🇸' => 'flagga: Montserrat',
    '🇲🇹' => 'flagga: Malta',
    '🇲🇺' => 'flagga: Mauritius',
    '🇲🇻' => 'flagga: Maldiverna',
    '🇲🇼' => 'flagga: Malawi',
    '🇲🇽' => 'flagga: Mexiko',
    '🇲🇾' => 'flagga: Malaysia',
    '🇲🇿' => 'flagga: Moçambique',
    '🇳🇦' => 'flagga: Namibia',
    '🇳🇨' => 'flagga: Nya Kaledonien',
    '🇳🇪' => 'flagga: Niger',
    '🇳🇫' => 'flagga: Norfolkön',
    '🇳🇬' => 'flagga: Nigeria',
    '🇳🇮' => 'flagga: Nicaragua',
    '🇳🇱' => 'flagga: Nederländerna',
    '🇳🇴' => 'flagga: Norge',
    '🇳🇵' => 'flagga: Nepal',
    '🇳🇷' => 'flagga: Nauru',
    '🇳🇺' => 'flagga: Niue',
    '🇳🇿' => 'flagga: Nya Zeeland',
    '🇴🇲' => 'flagga: Oman',
    '🇵🇦' => 'flagga: Panama',
    '🇵🇪' => 'flagga: Peru',
    '🇵🇫' => 'flagga: Franska Polynesien',
    '🇵🇬' => 'flagga: Papua Nya Guinea',
    '🇵🇭' => 'flagga: Filippinerna',
    '🇵🇰' => 'flagga: Pakistan',
    '🇵🇱' => 'flagga: Polen',
    '🇵🇲' => 'flagga: S:t Pierre och Miquelon',
    '🇵🇳' => 'flagga: Pitcairnöarna',
    '🇵🇷' => 'flagga: Puerto Rico',
    '🇵🇸' => 'flagga: Palestinska territorierna',
    '🇵🇹' => 'flagga: Portugal',
    '🇵🇼' => 'flagga: Palau',
    '🇵🇾' => 'flagga: Paraguay',
    '🇶🇦' => 'flagga: Qatar',
    '🇷🇪' => 'flagga: Réunion',
    '🇷🇴' => 'flagga: Rumänien',
    '🇷🇸' => 'flagga: Serbien',
    '🇷🇺' => 'flagga: Ryssland',
    '🇷🇼' => 'flagga: Rwanda',
    '🇸🇦' => 'flagga: Saudiarabien',
    '🇸🇧' => 'flagga: Salomonöarna',
    '🇸🇨' => 'flagga: Seychellerna',
    '🇸🇩' => 'flagga: Sudan',
    '🇸🇪' => 'flagga: Sverige',
    '🇸🇬' => 'flagga: Singapore',
    '🇸🇭' => 'flagga: S:t Helena',
    '🇸🇮' => 'flagga: Slovenien',
    '🇸🇯' => 'flagga: Svalbard och Jan Mayen',
    '🇸🇰' => 'flagga: Slovakien',
    '🇸🇱' => 'flagga: Sierra Leone',
    '🇸🇲' => 'flagga: San Marino',
    '🇸🇳' => 'flagga: Senegal',
    '🇸🇴' => 'flagga: Somalia',
    '🇸🇷' => 'flagga: Surinam',
    '🇸🇸' => 'flagga: Sydsudan',
    '🇸🇹' => 'flagga: São Tomé och Príncipe',
    '🇸🇻' => 'flagga: El Salvador',
    '🇸🇽' => 'flagga: Sint Maarten',
    '🇸🇾' => 'flagga: Syrien',
    '🇸🇿' => 'flagga: Eswatini',
    '🇹🇦' => 'flagga: Tristan da Cunha',
    '🇹🇨' => 'flagga: Turks- och Caicosöarna',
    '🇹🇩' => 'flagga: Tchad',
    '🇹🇫' => 'flagga: Franska sydterritorierna',
    '🇹🇬' => 'flagga: Togo',
    '🇹🇭' => 'flagga: Thailand',
    '🇹🇯' => 'flagga: Tadzjikistan',
    '🇹🇰' => 'flagga: Tokelauöarna',
    '🇹🇱' => 'flagga: Östtimor',
    '🇹🇲' => 'flagga: Turkmenistan',
    '🇹🇳' => 'flagga: Tunisien',
    '🇹🇴' => 'flagga: Tonga',
    '🇹🇷' => 'flagga: Turkiet',
    '🇹🇹' => 'flagga: Trinidad och Tobago',
    '🇹🇻' => 'flagga: Tuvalu',
    '🇹🇼' => 'flagga: Taiwan',
    '🇹🇿' => 'flagga: Tanzania',
    '🇺🇦' => 'flagga: Ukraina',
    '🇺🇬' => 'flagga: Uganda',
    '🇺🇲' => 'flagga: USA:s yttre öar',
    '🇺🇳' => 'flagga: Förenta Nationerna',
    '🇺🇸' => 'flagga: USA',
    '🇺🇾' => 'flagga: Uruguay',
    '🇺🇿' => 'flagga: Uzbekistan',
    '🇻🇦' => 'flagga: Vatikanstaten',
    '🇻🇨' => 'flagga: S:t Vincent och Grenadinerna',
    '🇻🇪' => 'flagga: Venezuela',
    '🇻🇬' => 'flagga: Brittiska Jungfruöarna',
    '🇻🇮' => 'flagga: Amerikanska Jungfruöarna',
    '🇻🇳' => 'flagga: Vietnam',
    '🇻🇺' => 'flagga: Vanuatu',
    '🇼🇫' => 'flagga: Wallis- och Futunaöarna',
    '🇼🇸' => 'flagga: Samoa',
    '🇽🇰' => 'flagga: Kosovo',
    '🇾🇪' => 'flagga: Jemen',
    '🇾🇹' => 'flagga: Mayotte',
    '🇿🇦' => 'flagga: Sydafrika',
    '🇿🇲' => 'flagga: Zambia',
    '🇿🇼' => 'flagga: Zimbabwe',
    '🏻' => 'ljus hy',
    '🏼' => 'mellanljus hy',
    '🏽' => 'mellanfärgad hy',
    '🏾' => 'mellanmörk hy',
    '🏿' => 'mörk hy',
    '😀' => 'ansikte med stort leende',
    '😃' => 'flinande ansikte med stora ögon',
    '😄' => 'flinande ansikte med leende ögon',
    '😁' => 'strålande ansikte med leende ögon',
    '😆' => 'flinande ansikte med kisande ögon',
    '😅' => 'flinande ansikte med svettdroppe',
    '🤣' => 'rullar runt på golvet och skrattar',
    '😂' => 'ansikte med glädjetårar',
    '🙂' => 'småleende ansikte',
    '🙃' => 'upp-och-nervänt ansikte',
    '🫠' => 'smältande ansikte',
    '😉' => 'ansikte som blinkar med ett öga',
    '😊' => 'leende ansikte och ögon',
    '😇' => 'leende ansikte med gloria',
    '🥰' => 'leende ansikte med tre hjärtan',
    '😍' => 'leende ansikte med hjärtformade ögon',
    '🤩' => 'stjärnögt ansikte',
    '😘' => 'ansikte ger en slängkyss',
    '😗' => 'pussande ansikte',
    '☺' => 'leende ansikte',
    '😚' => 'pussande ansikte med slutna ögon',
    '😙' => 'pussande ansikte med leende ögon',
    '🥲' => 'tårögt leende ansikte',
    '😋' => 'ansikte som njuter av god mat',
    '😛' => 'ansikte räcker ut tungan',
    '😜' => 'blinkande ansikte räcker ut tungan',
    '🤪' => 'tokigt ansikte',
    '😝' => 'ansikte räcker ut tungan med stängda ögon',
    '🤑' => 'ansikte med dollarögon',
    '🤗' => 'ansikte som kramas',
    '🤭' => 'ansikte med handen för munnen',
    '🫢' => 'ansikte med öppna ögon och hand för munnen',
    '🫣' => 'ansikte med kikande öga',
    '🤫' => 'hyssjande ansikte',
    '🤔' => 'ansikte som tänker',
    '🫡' => 'ansikte som gör honnör',
    '🤐' => 'ansikte som tiger',
    '🤨' => 'ansikte med höjt ögonbryn',
    '😐' => 'neutralt ansikte',
    '😑' => 'uttryckslöst ansikte',
    '😶' => 'ansikte utan mun',
    '🫥' => 'osynligt ansikte',
    '😏' => 'halvleende ansikte',
    '😒' => 'missnöjt ansikte',
    '🙄' => 'ansikte som himlar med ögonen',
    '😬' => 'grimaserande ansikte',
    '🤥' => 'ljugande ansikte',
    '🫨' => 'skakande ansikte',
    '😌' => 'lättat ansikte',
    '😔' => 'funderande ansikte',
    '😪' => 'sömnigt ansikte',
    '🤤' => 'dreglande ansikte',
    '😴' => 'sovande ansikte',
    '🫩' => 'ansikte med påsar under ögonen',
    '😷' => 'ansikte med munskydd',
    '🤒' => 'ansikte med termometer',
    '🤕' => 'ansikte med bandage på huvudet',
    '🤢' => 'äcklat ansikte',
    '🤮' => 'kräkande ansikte',
    '🤧' => 'nysande ansikte',
    '🥵' => 'hett ansikte',
    '🥶' => 'kallt ansikte',
    '🥴' => 'yrt ansikte',
    '😵' => 'omtumlat ansikte',
    '🤯' => 'exploderande huvud',
    '🤠' => 'ansikte med cowboyhatt',
    '🥳' => 'festande ansikte',
    '🥸' => 'maskerat ansikte',
    '😎' => 'leende ansikte med solglasögon',
    '🤓' => 'nördansikte',
    '🧐' => 'ansikte med monokel',
    '😕' => 'förbryllat ansikte',
    '🫤' => 'ansikte med diagonal mun',
    '😟' => 'bekymrat ansikte',
    '🙁' => 'ansikte med lite sur mun',
    '☹' => 'ansikte med sur mun',
    '😮' => 'förvånat ansikte',
    '😯' => 'hyssjat ansikte',
    '😲' => 'chockat ansikte',
    '😳' => 'rodnande ansikte',
    '🫪' => 'ansikte i närbild',
    '🥺' => 'bönfallande ansikte',
    '🥹' => 'ansikte som håller tillbaka tårarna',
    '😦' => 'ogillande ansikte med öppen mun',
    '😧' => 'plågat ansikte',
    '😨' => 'skrämt ansikte',
    '😰' => 'oroligt svettigt ansikte',
    '😥' => 'besviket men lättat ansikte',
    '😢' => 'gråtande ansikte',
    '😭' => 'storgråtande ansikte',
    '😱' => 'ansikte som skriker av fasa',
    '😖' => 'förvirrat ansikte',
    '😣' => 'uthålligt ansikte',
    '😞' => 'besviket ansikte',
    '😓' => 'nedslaget kallsvettigt ansikte',
    '😩' => 'uttröttat ansikte',
    '😫' => 'trött ansikte',
    '🥱' => 'gäspande ansikte',
    '😤' => 'ansikte med ånga ur näsan',
    '😡' => 'rasande ansikte',
    '😠' => 'argt ansikte',
    '🤬' => 'ansikte med symboler på munnen',
    '😈' => 'leende ansikte med horn',
    '👿' => 'argt ansikte med horn',
    '💀' => 'dödskalle',
    '☠' => 'dödskalle med ben i kors',
    '💩' => 'bajshög',
    '🤡' => 'clownansikte',
    '👹' => 'japanskt monster',
    '👺' => 'japanskt troll',
    '👻' => 'spöke',
    '👽' => 'utomjording',
    '👾' => 'utomjordiskt monster',
    '🤖' => 'robotansikte',
    '😺' => 'flinande kattansikte',
    '😸' => 'flinande kattansikte med leende ögon',
    '😹' => 'kattansikte med glädjetårar',
    '😻' => 'leende kattansikte med hjärtformade ögon',
    '😼' => 'kattansikte med snett leende',
    '😽' => 'kyssande kattansikte',
    '🙀' => 'uttröttat kattansikte',
    '😿' => 'gråtande kattansikte',
    '😾' => 'tjurande katt',
    '🙈' => 'apa ser inget',
    '🙉' => 'apa hör inget',
    '🙊' => 'apa säger inget',
    '💌' => 'kärleksbrev',
    '💘' => 'hjärta med pil',
    '💝' => 'hjärta med rosett',
    '💖' => 'gnistrande hjärta',
    '💗' => 'växande hjärta',
    '💓' => 'bultande hjärta',
    '💞' => 'snurrande hjärtan',
    '💕' => 'två hjärtan',
    '💟' => 'hjärtdekoration',
    '❣' => 'utropstecken i form av ett hjärta',
    '💔' => 'brustet hjärta',
    '❤' => 'rött hjärta',
    '🩷' => 'rosa hjärta',
    '🧡' => 'hjärta i orange',
    '💛' => 'gult hjärta',
    '💚' => 'grönt hjärta',
    '💙' => 'blått hjärta',
    '🩵' => 'ljusblått hjärta',
    '💜' => 'lila hjärta',
    '🤎' => 'brunt hjärta',
    '🖤' => 'svart hjärta',
    '🩶' => 'grått hjärta',
    '🤍' => 'vitt hjärta',
    '💋' => 'läppavtryck',
    '💯' => '100 poäng',
    '💢' => 'symbol för ilska',
    '🫯' => 'slagsmål',
    '💥' => 'explosion',
    '💫' => 'omtumlad',
    '💦' => 'stänkande svett',
    '💨' => 'fartsymbol',
    '🕳' => 'hål',
    '💬' => 'pratbubbla',
    '🗨' => 'pratbubbla åt vänster',
    '🗯' => 'arg pratbubbla åt höger',
    '💭' => 'tankebubbla',
    '💤' => 'snarkningar',
    '👋' => 'vinkande hand',
    '🤚' => 'höjd handrygg',
    '🖐' => 'hand med utspretade fingrar',
    '✋' => 'hand i luften',
    '🖖' => 'vulcan-hälsning',
    '🫱' => 'hand som pekar till höger',
    '🫲' => 'hand som pekar till vänster',
    '🫳' => 'handflatan nedåt',
    '🫴' => 'handflatan uppåt',
    '🫷' => 'hand som knuffar åt vänster',
    '🫸' => 'hand som knuffar åt höger',
    '👌' => 'OK-tecken',
    '🤌' => 'fingerportmonnä',
    '🤏' => 'nypande hand',
    '✌' => 'v-tecken',
    '🤞' => 'korsade fingrar',
    '🫰' => 'hand med tummen och pekfingret korsade',
    '🤟' => 'jag älskar dig-gest',
    '🤘' => 'djävulstecknet',
    '🤙' => 'ring mig-hand',
    '👈' => 'vänsterpekande finger',
    '👉' => 'högerpekande finger',
    '👆' => 'pekfinger upp',
    '🖕' => 'långfinger upp',
    '👇' => 'nedåtpekande finger',
    '☝' => 'finger upp',
    '🫵' => 'finger som pekar på mig',
    '👍' => 'tummen upp',
    '👎' => 'tummen ned',
    '✊' => 'knytnäve i luften',
    '👊' => 'knuten hand',
    '🤛' => 'vänstervänd näve',
    '🤜' => 'högervänd näve',
    '👏' => 'klappande händer',
    '🙌' => 'båda händerna i luften',
    '🫶' => 'handhjärta',
    '👐' => 'öppna händer',
    '🤲' => 'handflatorna upp',
    '🤝' => 'handskakning',
    '🙏' => 'beende händer',
    '✍' => 'hand som skriver',
    '💅' => 'nagellack',
    '🤳' => 'selfie',
    '💪' => 'spänd biceps',
    '🦾' => 'mekanisk arm',
    '🦿' => 'mekaniskt ben',
    '🦵' => 'ben',
    '🦶' => 'fot',
    '👂' => 'öra',
    '🦻' => 'öra med hörapparat',
    '👃' => 'näsa',
    '🧠' => 'hjärna',
    '🫀' => 'hjärta',
    '🫁' => 'lungor',
    '🦷' => 'tand',
    '🦴' => 'benknota',
    '👀' => 'ögon',
    '👁' => 'öga',
    '👅' => 'tunga',
    '👄' => 'mun',
    '🫦' => 'biter i läppen',
    '👶' => 'bebis',
    '🧒' => 'barn',
    '👦' => 'pojke',
    '👧' => 'flicka',
    '🧑' => 'person',
    '👱' => 'blond person',
    '👨' => 'man',
    '🧔' => 'man med skägg',
    '👩' => 'kvinna',
    '🧓' => 'äldre person',
    '👴' => 'gammal man',
    '👵' => 'gammal kvinna',
    '🙍' => 'sur person',
    '🙎' => 'plutande person',
    '🙅' => 'person gestikulerar NEJ',
    '🙆' => 'person gestikulerar OK',
    '💁' => 'receptionist',
    '🙋' => 'person som räcker upp handen',
    '🧏' => 'hörselskadad person',
    '🙇' => 'bugande person',
    '🤦' => 'person som slår sig för pannan',
    '🤷' => 'person som rycker på axlarna',
    '👮' => 'polis',
    '🕵' => 'detektiv',
    '💂' => 'vakt',
    '🥷' => 'ninja',
    '👷' => 'byggarbetare',
    '🫅' => 'person med krona',
    '🤴' => 'prins',
    '👸' => 'prinsessa',
    '👳' => 'man med turban',
    '👲' => 'man med kinesisk hatt',
    '🧕' => 'kvinna i sjal',
    '🤵' => 'person i smoking',
    '👰' => 'person i brudslöja',
    '🤰' => 'gravid kvinna',
    '🫃' => 'gravid man',
    '🫄' => 'gravid person',
    '🤱' => 'amning',
    '👼' => 'bebisängel',
    '🎅' => 'jultomte',
    '🤶' => 'tomtemor',
    '🦸' => 'superhjälte',
    '🦹' => 'superskurk',
    '🧙' => 'magiker',
    '🧚' => 'fé',
    '🧛' => 'vampyr',
    '🧜' => 'vattenväsen',
    '🧝' => 'alv',
    '🧞' => 'ande',
    '🧟' => 'zombie',
    '🧌' => 'troll',
    '🫈' => 'hårig varelse',
    '💆' => 'person som blir masserad',
    '💇' => 'person som får håret klippt',
    '🚶' => 'fotgängare',
    '🧍' => 'stående person',
    '🧎' => 'knäsittande person',
    '🏃' => 'person som springer',
    '💃' => 'dansande kvinna',
    '🕺' => 'dansande man',
    '🕴' => 'svävande man i kostym',
    '👯' => 'personer med kaninöron',
    '🧖' => 'person i ångbastu',
    '🧗' => 'person som klättrar',
    '🤺' => 'person som fäktas',
    '🏇' => 'hästkapplöpning',
    '⛷' => 'skidåkare',
    '🏂' => 'snowboardåkare',
    '🏌' => 'person som spelar golf',
    '🏄' => 'person som surfar',
    '🚣' => 'person som ror en båt',
    '🏊' => 'person som simmar',
    '⛹' => 'person med boll',
    '🏋' => 'person som lyfter tyngder',
    '🚴' => 'person som cyklar',
    '🚵' => 'person som cyklar på en mountainbike',
    '🤸' => 'person som hjular',
    '🤼' => 'brottande personer',
    '🤽' => 'person som spelar vattenpolo',
    '🤾' => 'person som spelar handboll',
    '🤹' => 'person som jonglerar',
    '🧘' => 'person i lotusposition',
    '🛀' => 'person som badar',
    '🛌' => 'person i en säng',
    '👭' => 'två kvinnor håller hand',
    '👫' => 'man och kvinna håller hand',
    '👬' => 'två män håller hand',
    '💏' => 'puss',
    '💑' => 'par med hjärta',
    '🗣' => 'silhuett som talar',
    '👤' => 'figur i silhuett',
    '👥' => 'figurer i silhuett',
    '🫂' => 'personer kramas',
    '👪' => 'familj',
    '👣' => 'fotavtryck',
    '🫆' => 'fingeravtryck',
    '🦰' => 'rödhårig',
    '🦱' => 'lockigt hår',
    '🦳' => 'vithårig',
    '🦲' => 'skallig',
    '🐵' => 'apansikte',
    '🐒' => 'apa',
    '🦍' => 'gorilla',
    '🦧' => 'orangutang',
    '🐶' => 'hundansikte',
    '🐕' => 'hund',
    '🦮' => 'ledarhund',
    '🐩' => 'pudel',
    '🐺' => 'vargansikte',
    '🦊' => 'rävansikte',
    '🦝' => 'tvättbjörn',
    '🐱' => 'kattansikte',
    '🐈' => 'katt',
    '🦁' => 'lejonansikte',
    '🐯' => 'tigeransikte',
    '🐅' => 'tiger',
    '🐆' => 'leopard',
    '🐴' => 'hästansikte',
    '🫎' => 'älg',
    '🫏' => 'åsna',
    '🐎' => 'häst',
    '🦄' => 'enhörningsansikte',
    '🦓' => 'zebra',
    '🦌' => 'hjort',
    '🦬' => 'bisonoxe',
    '🐮' => 'koansikte',
    '🐂' => 'oxe',
    '🐃' => 'vattenbuffel',
    '🐄' => 'ko',
    '🐷' => 'grisansikte',
    '🐖' => 'gris',
    '🐗' => 'vildsvin',
    '🐽' => 'gristryne',
    '🐏' => 'vädur',
    '🐑' => 'tacka',
    '🐐' => 'get',
    '🐪' => 'dromedar',
    '🐫' => 'kamel',
    '🦙' => 'lama',
    '🦒' => 'giraff',
    '🐘' => 'elefant',
    '🦣' => 'mammut',
    '🦏' => 'noshörning',
    '🦛' => 'flodhäst',
    '🐭' => 'musansikte',
    '🐁' => 'mus',
    '🐀' => 'råtta',
    '🐹' => 'hamsteransikte',
    '🐰' => 'kaninansikte',
    '🐇' => 'kanin',
    '🐿' => 'jordekorre',
    '🦫' => 'bäver',
    '🦔' => 'igelkott',
    '🦇' => 'fladdermus',
    '🐻' => 'björnansikte',
    '🐨' => 'koala',
    '🐼' => 'pandaansikte',
    '🦥' => 'sengångare',
    '🦦' => 'utter',
    '🦨' => 'skunk',
    '🦘' => 'känguru',
    '🦡' => 'grävling',
    '🐾' => 'tassavtryck',
    '🦃' => 'kalkon',
    '🐔' => 'höna',
    '🐓' => 'tupp',
    '🐣' => 'nykläckt kyckling',
    '🐤' => 'kyckling',
    '🐥' => 'kyckling framifrån',
    '🐦' => 'fågel',
    '🐧' => 'pingvin',
    '🕊' => 'duva',
    '🦅' => 'örn',
    '🦆' => 'and',
    '🦢' => 'svan',
    '🦉' => 'uggla',
    '🦤' => 'dront',
    '🪶' => 'fågelfjäder',
    '🦩' => 'flamingo',
    '🦚' => 'påfågel',
    '🦜' => 'papegoja',
    '🪽' => 'vinge',
    '🪿' => 'gås',
    '🐸' => 'grodansikte',
    '🐊' => 'krokodil',
    '🐢' => 'sköldpadda',
    '🦎' => 'ödla',
    '🐍' => 'orm',
    '🐲' => 'drakansikte',
    '🐉' => 'drake',
    '🦕' => 'sauropod',
    '🦖' => 'T-rex',
    '🐳' => 'val som sprutar vatten',
    '🐋' => 'val',
    '🐬' => 'delfin',
    '🫍' => 'späckhuggare',
    '🦭' => 'säl',
    '🐟' => 'fisk',
    '🐠' => 'tropisk fisk',
    '🐡' => 'blåsfisk',
    '🦈' => 'haj',
    '🐙' => 'bläckfisk',
    '🐚' => 'snäcka',
    '🪸' => 'korall',
    '🪼' => 'manet',
    '🦀' => 'krabba',
    '🦞' => 'hummer',
    '🦐' => 'räka',
    '🦑' => 'mindre bläckfisk',
    '🦪' => 'ostron',
    '🐌' => 'snigel',
    '🦋' => 'fjäril',
    '🐛' => 'tusenfoting',
    '🐜' => 'myra',
    '🐝' => 'bi',
    '🪲' => 'skalbagge',
    '🐞' => 'nyckelpiga',
    '🦗' => 'syrsa',
    '🪳' => 'kackerlacka',
    '🕷' => 'spindel',
    '🕸' => 'spindelnät',
    '🦂' => 'skorpion',
    '🦟' => 'mygga',
    '🪰' => 'fluga',
    '🪱' => 'mask',
    '🦠' => 'mikrob',
    '💐' => 'blombukett',
    '🌸' => 'körsbärsblomma',
    '💮' => 'vit blomma',
    '🪷' => 'lotus',
    '🏵' => 'bandros',
    '🌹' => 'ros',
    '🥀' => 'vissnad blomma',
    '🌺' => 'hibiskus',
    '🌻' => 'solros',
    '🌼' => 'blomma',
    '🌷' => 'tulpan',
    '🪻' => 'hyacint',
    '🌱' => 'skott',
    '🪴' => 'krukväxt',
    '🌲' => 'barrträd',
    '🌳' => 'lövträd',
    '🌴' => 'palm',
    '🌵' => 'kaktus',
    '🌾' => 'risax',
    '🌿' => 'ört',
    '☘' => 'treklöver',
    '🍀' => 'fyrklöver',
    '🍁' => 'lönnlöv',
    '🍂' => 'fallande löv',
    '🍃' => 'löv i vinden',
    '🪹' => 'tomt bo',
    '🪺' => 'bo med ägg',
    '🍄' => 'svamp',
    '🪾' => 'träd utan löv',
    '🍇' => 'vindruvor',
    '🍈' => 'melon',
    '🍉' => 'vattenmelon',
    '🍊' => 'mandarin',
    '🍋' => 'citron',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'rött äpple',
    '🍏' => 'grönt äpple',
    '🍐' => 'päron',
    '🍑' => 'persika',
    '🍒' => 'körsbär',
    '🍓' => 'jordgubbe',
    '🫐' => 'blåbär',
    '🥝' => 'kiwifrukt',
    '🍅' => 'tomat',
    '🫒' => 'oliv',
    '🥥' => 'kokosnöt',
    '🥑' => 'avokado',
    '🍆' => 'aubergine',
    '🥔' => 'potatis',
    '🥕' => 'morot',
    '🌽' => 'majskolv',
    '🌶' => 'chili',
    '🫑' => 'paprika',
    '🥒' => 'gurka',
    '🥬' => 'sallat',
    '🥦' => 'broccoli',
    '🧄' => 'vitlök',
    '🧅' => 'lök',
    '🥜' => 'jordnötter',
    '🫘' => 'bönor',
    '🌰' => 'kastanj',
    '🫚' => 'ingefära',
    '🫛' => 'ärtskida',
    '🫜' => 'rotfrukt',
    '🍞' => 'bröd',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'tunnbröd',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'pannkakor',
    '🧇' => 'våffla',
    '🧀' => 'ostbit',
    '🍖' => 'köttben',
    '🍗' => 'kycklinglår',
    '🥩' => 'styckdel',
    '🥓' => 'bacon',
    '🍔' => 'hamburgare',
    '🍟' => 'pommes frites',
    '🍕' => 'pizzabit',
    '🌭' => 'varmkorv',
    '🥪' => 'smörgås',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'pitabröd',
    '🧆' => 'falafel',
    '🥚' => 'ägg',
    '🍳' => 'matlagning',
    '🥘' => 'paella',
    '🍲' => 'gryta',
    '🫕' => 'fondue',
    '🥣' => 'skål och sked',
    '🥗' => 'grönsallad',
    '🍿' => 'popcorn',
    '🧈' => 'smör',
    '🧂' => 'salt',
    '🥫' => 'konserv',
    '🍱' => 'bentolåda',
    '🍘' => 'riskaka',
    '🍙' => 'risboll',
    '🍚' => 'kokt ris',
    '🍛' => 'curry och ris',
    '🍜' => 'skål nudelsoppa',
    '🍝' => 'spagetti',
    '🍠' => 'rostad sötpotatis',
    '🍢' => 'skaldjursspett',
    '🍣' => 'sushi',
    '🍤' => 'friterad räka',
    '🍥' => 'fiskkaka',
    '🥮' => 'månkaka',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'lyckokaka',
    '🥡' => 'hämtmatkartong',
    '🍦' => 'mjukglass',
    '🍧' => 'kakigōri',
    '🍨' => 'glass',
    '🍩' => 'munk',
    '🍪' => 'kaka',
    '🎂' => 'födelsedagstårta',
    '🍰' => 'tårtbit',
    '🧁' => 'muffin',
    '🥧' => 'paj',
    '🍫' => 'chokladkaka',
    '🍬' => 'godis',
    '🍭' => 'klubba',
    '🍮' => 'brylépudding',
    '🍯' => 'honungsburk',
    '🍼' => 'nappflaska',
    '🥛' => 'mjölkglas',
    '☕' => 'varm dryck',
    '🫖' => 'tekanna',
    '🍵' => 'tekopp',
    '🍶' => 'sake',
    '🍾' => 'champagne',
    '🍷' => 'vinglas',
    '🍸' => 'cocktailglas',
    '🍹' => 'tropisk drink',
    '🍺' => 'ölstop',
    '🍻' => 'skålande ölstop',
    '🥂' => 'skålande glas',
    '🥃' => 'whiskyglas',
    '🫗' => 'hälla vätska',
    '🥤' => 'mugg med sugrör',
    '🧋' => 'bubbelte',
    '🧃' => 'dryckeskartong',
    '🧉' => 'mate-te',
    '🧊' => 'isbit',
    '🥢' => 'ätpinnar',
    '🍽' => 'tallrik, kniv och gaffel',
    '🍴' => 'kniv och gaffel',
    '🥄' => 'sked',
    '🔪' => 'kökskniv',
    '🫙' => 'burk',
    '🏺' => 'amfora',
    '🌍' => 'jordglob Europa–Afrika',
    '🌎' => 'jordglob nord- och sydamerika',
    '🌏' => 'jordglob Asien–Australien',
    '🌐' => 'jordglob med meridianer',
    '🗺' => 'världskarta',
    '🗾' => 'karta över Japan',
    '🧭' => 'kompass',
    '🏔' => 'snöklätt berg',
    '⛰' => 'berg',
    '🛘' => 'jordskred',
    '🌋' => 'vulkan',
    '🗻' => 'Fuji',
    '🏕' => 'camping',
    '🏖' => 'strand med parasoll',
    '🏜' => 'öken',
    '🏝' => 'öde ö',
    '🏞' => 'nationalpark',
    '🏟' => 'stadion',
    '🏛' => 'klassisk byggnad',
    '🏗' => 'byggarbetsplats',
    '🧱' => 'tegelsten',
    '🪨' => 'sten',
    '🪵' => 'trästockar',
    '🛖' => 'koja',
    '🏘' => 'flera hus',
    '🏚' => 'fallfärdigt hus',
    '🏠' => 'hus',
    '🏡' => 'hus med trädgård',
    '🏢' => 'kontorsbyggnad',
    '🏣' => 'japanskt postkontor',
    '🏤' => 'postkontor',
    '🏥' => 'sjukhus',
    '🏦' => 'bank',
    '🏨' => 'hotell',
    '🏩' => 'kärlekshotell',
    '🏪' => 'jourbutik',
    '🏫' => 'skola',
    '🏬' => 'varuhus',
    '🏭' => 'fabrik',
    '🏯' => 'japanskt slott',
    '🏰' => 'slott',
    '💒' => 'bröllop',
    '🗼' => 'Tokyo Tower',
    '🗽' => 'Frihetsgudinnan',
    '⛪' => 'kyrka',
    '🕌' => 'moské',
    '🛕' => 'hindutempel',
    '🕍' => 'synagoga',
    '⛩' => 'shintohelgedom',
    '🕋' => 'kaba',
    '⛲' => 'fontän',
    '⛺' => 'tält',
    '🌁' => 'dimmigt',
    '🌃' => 'stjärnklar natt',
    '🏙' => 'stadsbild',
    '🌄' => 'soluppgång över berg',
    '🌅' => 'soluppgång',
    '🌆' => 'stad i skymning',
    '🌇' => 'solnedgång',
    '🌉' => 'bro på natten',
    '♨' => 'varma källor',
    '🎠' => 'karusellhäst',
    '🛝' => 'rutschbana',
    '🎡' => 'pariserhjul',
    '🎢' => 'berg- och dalbana',
    '💈' => 'barberarstolpe',
    '🎪' => 'cirkustält',
    '🚂' => 'ånglok',
    '🚃' => 'tågvagn',
    '🚄' => 'snabbtåg',
    '🚅' => 'höghastighetståg',
    '🚆' => 'tåg',
    '🚇' => 'tunnelbana',
    '🚈' => 'snabbspårväg',
    '🚉' => 'tågstation',
    '🚊' => 'spårvagn',
    '🚝' => 'monorail',
    '🚞' => 'bergbana',
    '🚋' => 'spårvagnsvagn',
    '🚌' => 'buss',
    '🚍' => 'mötande buss',
    '🚎' => 'trådbuss',
    '🚐' => 'minibuss',
    '🚑' => 'ambulans',
    '🚒' => 'brandbil',
    '🚓' => 'polisbil',
    '🚔' => 'mötande polisbil',
    '🚕' => 'taxi',
    '🚖' => 'mötande taxi',
    '🚗' => 'bil',
    '🚘' => 'mötande bil',
    '🚙' => 'SUV',
    '🛻' => 'pickup',
    '🚚' => 'budbil',
    '🚛' => 'lastbil',
    '🚜' => 'traktor',
    '🏎' => 'racerbil',
    '🏍' => 'motorcykel',
    '🛵' => 'skoter',
    '🦽' => 'manuell rullstol',
    '🦼' => 'eldriven rullstol',
    '🛺' => 'automatisk riksha',
    '🚲' => 'cykel',
    '🛴' => 'sparkcykel',
    '🛹' => 'skateboard',
    '🛼' => 'rullskridsko',
    '🚏' => 'busshållplats',
    '🛣' => 'motorväg',
    '🛤' => 'räls',
    '🛢' => 'oljefat',
    '⛽' => 'bränslepump',
    '🛞' => 'hjul',
    '🚨' => 'polisbilslampa',
    '🚥' => 'vågräta trafikljus',
    '🚦' => 'lodräta trafikljus',
    '🛑' => 'stoppskylt',
    '🚧' => 'skylt för byggområde',
    '⚓' => 'ankare',
    '🛟' => 'livboj',
    '⛵' => 'segelbåt',
    '🛶' => 'kanot',
    '🚤' => 'racerbåt',
    '🛳' => 'passagerarfartyg',
    '⛴' => 'färja',
    '🛥' => 'motorbåt',
    '🚢' => 'fartyg',
    '✈' => 'flygplan',
    '🛩' => 'litet flygplan',
    '🛫' => 'avgång med flyg',
    '🛬' => 'ankomst med flyg',
    '🪂' => 'fallskärm',
    '💺' => 'flygstol',
    '🚁' => 'helikopter',
    '🚟' => 'hängbana',
    '🚠' => 'linbana',
    '🚡' => 'kabinbana',
    '🛰' => 'satellit',
    '🚀' => 'raket',
    '🛸' => 'flygande tefat',
    '🛎' => 'receptionsklocka',
    '🧳' => 'bagage',
    '⌛' => 'utrunnet timglas',
    '⏳' => 'timglas med rinnande sand',
    '⌚' => 'armbandsur',
    '⏰' => 'väckarklocka',
    '⏱' => 'tidtagarur',
    '⏲' => 'timer',
    '🕰' => 'mantelklocka',
    '🕛' => 'klockan tolv',
    '🕧' => 'halv ett',
    '🕐' => 'klockan ett',
    '🕜' => 'halv två',
    '🕑' => 'klockan två',
    '🕝' => 'halv tre',
    '🕒' => 'klockan tre',
    '🕞' => 'halv fyra',
    '🕓' => 'klockan fyra',
    '🕟' => 'halv fem',
    '🕔' => 'klockan fem',
    '🕠' => 'halv sex',
    '🕕' => 'klockan sex',
    '🕡' => 'halv sju',
    '🕖' => 'klockan sju',
    '🕢' => 'halv åtta',
    '🕗' => 'klockan åtta',
    '🕣' => 'halv nio',
    '🕘' => 'klockan nio',
    '🕤' => 'halv tio',
    '🕙' => 'klockan tio',
    '🕥' => 'halv elva',
    '🕚' => 'klockan elva',
    '🕦' => 'halv tolv',
    '🌑' => 'nymåne',
    '🌒' => 'måne i första kvarteret',
    '🌓' => 'tilltagande halvmåne',
    '🌔' => 'måne i andra kvarteret',
    '🌕' => 'fullmåne',
    '🌖' => 'måne i tredje kvarteret',
    '🌗' => 'avtagande halvmåne',
    '🌘' => 'måne i fjärde kvarteret',
    '🌙' => 'månskära',
    '🌚' => 'nymåne med ansikte',
    '🌛' => 'tilltagande halvmåne med ansikte',
    '🌜' => 'avtagande halvmåne med ansikte',
    '🌡' => 'termometer',
    '☀' => 'sol',
    '🌝' => 'fullmåne med ansikte',
    '🌞' => 'sol med ansikte',
    '🪐' => 'planet med ringar',
    '⭐' => 'stjärna',
    '🌟' => 'blänkande stjärna',
    '🌠' => 'stjärnfall',
    '🌌' => 'Vintergatan',
    '☁' => 'moln',
    '⛅' => 'sol bakom moln',
    '⛈' => 'moln med regn och blixtar',
    '🌤' => 'sol bakom litet moln',
    '🌥' => 'sol bakom stort moln',
    '🌦' => 'sol bakom moln med regn',
    '🌧' => 'regnmoln',
    '🌨' => 'moln med snö',
    '🌩' => 'moln med blixt',
    '🌪' => 'tornado',
    '🌫' => 'dimma',
    '🌬' => 'blåser vind',
    '🌀' => 'cyklon',
    '🌈' => 'regnbåge',
    '🌂' => 'hopfällt paraply',
    '☂' => 'paraply',
    '☔' => 'paraply med regndroppar',
    '⛱' => 'parasoll på marken',
    '⚡' => 'högspänning',
    '❄' => 'snöflinga',
    '☃' => 'snögubbe',
    '⛄' => 'snögubbe utan snö',
    '☄' => 'komet',
    '🔥' => 'eld',
    '💧' => 'droppe',
    '🌊' => 'våg',
    '🎃' => 'lyktgubbe',
    '🎄' => 'julgran',
    '🎆' => 'fyrverkerier',
    '🎇' => 'glittrande fyrverkeri',
    '🧨' => 'smällare',
    '✨' => 'gnistrande stjärnor',
    '🎈' => 'ballong',
    '🎉' => 'konfettismällare',
    '🎊' => 'konfettiboll',
    '🎋' => 'tanabataträd',
    '🎍' => 'pinjedekoration',
    '🎎' => 'japanska dockor',
    '🎏' => 'karpvindstrut',
    '🎐' => 'vindspel',
    '🎑' => 'månskådning',
    '🧧' => 'rött kuvert',
    '🎀' => 'rosett',
    '🎁' => 'inslagen present',
    '🎗' => 'påminnelseband',
    '🎟' => 'inträdesbiljetter',
    '🎫' => 'biljett',
    '🎖' => 'militär medalj',
    '🏆' => 'pokal',
    '🏅' => 'sportmedalj',
    '🥇' => 'guldmedalj',
    '🥈' => 'silvermedalj',
    '🥉' => 'bronsmedalj',
    '⚽' => 'fotboll',
    '⚾' => 'baseboll',
    '🥎' => 'softboll',
    '🏀' => 'basketboll',
    '🏐' => 'volleyboll',
    '🏈' => 'amerikansk fotboll',
    '🏉' => 'rugbyboll',
    '🎾' => 'tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'landhockey',
    '🏒' => 'ishockey',
    '🥍' => 'lacrosse',
    '🏓' => 'bordtennis',
    '🏸' => 'badminton',
    '🥊' => 'boxningshandske',
    '🥋' => 'kampsportdräkt',
    '🥅' => 'målnät',
    '⛳' => 'flagga i hål',
    '⛸' => 'skridsko',
    '🎣' => 'fiskespö',
    '🤿' => 'dykmask',
    '🎽' => 'löparlinne',
    '🎿' => 'skidor',
    '🛷' => 'kälke',
    '🥌' => 'curlingsten',
    '🎯' => 'mitt i prick',
    '🪀' => 'jojo',
    '🪁' => 'flygande drake',
    '🔫' => 'vattenpistol',
    '🎱' => 'biljardboll',
    '🔮' => 'kristallkula',
    '🪄' => 'trollspö',
    '🎮' => 'tv-spel',
    '🕹' => 'joystick',
    '🎰' => 'enarmad bandit',
    '🎲' => 'speltärning',
    '🧩' => 'pusselbit',
    '🧸' => 'nallebjörn',
    '🪅' => 'piñata',
    '🪩' => 'discokula',
    '🪆' => 'ryska dockor',
    '♠' => 'spader',
    '♥' => 'hjärter',
    '♦' => 'ruter',
    '♣' => 'klöver',
    '♟' => 'schackbonde',
    '🃏' => 'joker',
    '🀄' => 'mahjong-bricka',
    '🎴' => 'spelkort med blomma',
    '🎭' => 'dans och teater',
    '🖼' => 'tavla',
    '🎨' => 'färgpalett',
    '🧵' => 'tråd',
    '🪡' => 'synål',
    '🧶' => 'garn',
    '🪢' => 'knut',
    '👓' => 'glasögon',
    '🕶' => 'solglasögon',
    '🥽' => 'simglasögon',
    '🥼' => 'labbrock',
    '🦺' => 'varselväst',
    '👔' => 'skjorta med slips',
    '👕' => 't-shirt',
    '👖' => 'jeans',
    '🧣' => 'halsduk',
    '🧤' => 'handske',
    '🧥' => 'jacka',
    '🧦' => 'sockor',
    '👗' => 'klänning',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'baddräkt',
    '🩲' => 'badbyxor',
    '🩳' => 'shorts',
    '👙' => 'bikini',
    '👚' => 'blus',
    '🪭' => 'solfjäder',
    '👛' => 'portmonnä',
    '👜' => 'handväska',
    '👝' => 'kuvertväska',
    '🛍' => 'shoppingpåsar',
    '🎒' => 'ryggsäck',
    '🩴' => 'flip-flops',
    '👞' => 'herrsko',
    '👟' => 'gympasko',
    '🥾' => 'vandringskänga',
    '🥿' => 'ballerinasko',
    '👠' => 'högklackad sko',
    '👡' => 'damsandal',
    '🩰' => 'ballettskor',
    '👢' => 'damstövel',
    '🪮' => 'afrokam',
    '👑' => 'krona',
    '👒' => 'damhatt',
    '🎩' => 'hög hatt',
    '🎓' => 'examenshatt',
    '🧢' => 'skärmmössa',
    '🪖' => 'militärhjälm',
    '⛑' => 'räddningsarbetarhjälm',
    '📿' => 'radband',
    '💄' => 'läppstift',
    '💍' => 'ring',
    '💎' => 'ädelsten',
    '🔇' => 'avstängd högtalare',
    '🔈' => 'högtalare',
    '🔉' => 'högtalare med medium volym',
    '🔊' => 'högtalare med hög volym',
    '📢' => 'handhögtalare',
    '📣' => 'megafon',
    '📯' => 'postsymbol',
    '🔔' => 'ringklocka',
    '🔕' => 'överstruken ringklocka',
    '🎼' => 'g-klav',
    '🎵' => 'musiknot',
    '🎶' => 'musiknoter',
    '🎙' => 'studiomikrofon',
    '🎚' => 'nivåreglage',
    '🎛' => 'reglagevred',
    '🎤' => 'mikrofon',
    '🎧' => 'hörlur',
    '📻' => 'radio',
    '🎷' => 'saxofon',
    '🎺' => 'trumpet',
    '🪊' => 'trombon',
    '🪗' => 'dragspel',
    '🎸' => 'gitarr',
    '🎹' => 'klaviatur',
    '🎻' => 'fiol',
    '🪕' => 'banjo',
    '🥁' => 'trumma',
    '🪘' => 'congatrumma',
    '🪇' => 'maracas',
    '🪈' => 'flöjt',
    '🪉' => 'harpa',
    '📱' => 'mobiltelefon',
    '📲' => 'mobiltelefon med pil',
    '☎' => 'telefon',
    '📞' => 'telefonlur',
    '📟' => 'personsökare',
    '📠' => 'fax',
    '🔋' => 'batteri',
    '🪫' => 'låg batterinivå',
    '🔌' => 'elkontakt',
    '💻' => 'bärbar dator',
    '🖥' => 'stationär dator',
    '🖨' => 'skrivare',
    '⌨' => 'tangentbord',
    '🖱' => 'datormus',
    '🖲' => 'styrkula',
    '💽' => 'datordiskett',
    '💾' => 'diskett',
    '💿' => 'optisk skiva',
    '📀' => 'dvd-skiva',
    '🧮' => 'kulram',
    '🎥' => 'filmkamera',
    '🎞' => 'filmnegativ',
    '📽' => 'filmprojektor',
    '🎬' => 'filmklappa',
    '📺' => 'tv',
    '📷' => 'kamera',
    '📸' => 'kamera med blixt',
    '📹' => 'videokamera',
    '📼' => 'videokassett',
    '🔍' => 'förstoringsglas som lutar åt vänster',
    '🔎' => 'förstoringsglas som lutar åt höger',
    '🕯' => 'stearinljus',
    '💡' => 'glödlampa',
    '🔦' => 'ficklampa',
    '🏮' => 'röd papperslykta',
    '🪔' => 'diyalampa',
    '📔' => 'anteckningsbok med dekorativt omslag',
    '📕' => 'stängd bok',
    '📖' => 'öppen bok',
    '📗' => 'grön bok',
    '📘' => 'blå bok',
    '📙' => 'orange bok',
    '📚' => 'böcker',
    '📓' => 'anteckningsbok',
    '📒' => 'liggare',
    '📃' => 'upprullad sida',
    '📜' => 'bokrulle',
    '📄' => 'sida med text uppåt',
    '📰' => 'tidning',
    '🗞' => 'ihoprullad tidning',
    '📑' => 'bokmärkesflikar',
    '🔖' => 'bokmärke',
    '🏷' => 'etikett',
    '🪙' => 'mynt',
    '💰' => 'pengapåse',
    '🪎' => 'skattkista',
    '💴' => 'yensedel',
    '💵' => 'dollarsedel',
    '💶' => 'eurosedel',
    '💷' => 'pundsedel',
    '💸' => 'pengar med vingar',
    '💳' => 'kreditkort',
    '🧾' => 'kvitto',
    '💹' => 'stigande diagram med yen',
    '✉' => 'kuvert',
    '📧' => 'e-post',
    '📨' => 'inkommande brev',
    '📩' => 'kuvert med pil',
    '📤' => 'utkorg',
    '📥' => 'inkorg',
    '📦' => 'paket',
    '📫' => 'stängd brevlåda med hissad flagga',
    '📪' => 'stängd brevlåda med sänkt flagga',
    '📬' => 'öppen brevlåda med hissad flagga',
    '📭' => 'öppen brevlåda med sänkt flagga',
    '📮' => 'postlåda',
    '🗳' => 'valurna med röstsedel',
    '✏' => 'blyertspenna',
    '✒' => 'stiftpenna',
    '🖋' => 'reservoarpenna',
    '🖊' => 'kulspetspenna',
    '🖌' => 'målarpensel',
    '🖍' => 'krita',
    '📝' => 'kom ihåg-block',
    '💼' => 'portfölj',
    '📁' => 'arkivmapp',
    '📂' => 'öppen mapp',
    '🗂' => 'indexflikar',
    '📅' => 'kalender',
    '📆' => 'avdragbar kalender',
    '🗒' => 'anteckningsblock',
    '🗓' => 'spiralbunden kalender',
    '📇' => 'kortregister',
    '📈' => 'uppåtgående trend',
    '📉' => 'nedåtgående trend',
    '📊' => 'stapeldiagram',
    '📋' => 'skrivplatta',
    '📌' => 'kartnål',
    '📍' => 'knappnål',
    '📎' => 'gem',
    '🖇' => 'länkade gem',
    '📏' => 'linjal',
    '📐' => 'rätvinklig linjal',
    '✂' => 'sax',
    '🗃' => 'kartotek',
    '🗄' => 'dokumentskåp',
    '🗑' => 'papperskorg',
    '🔒' => 'låst lås',
    '🔓' => 'öppet lås',
    '🔏' => 'lås med bläckpenna',
    '🔐' => 'lås med nyckel',
    '🔑' => 'nyckel',
    '🗝' => 'gammal nyckel',
    '🔨' => 'hammare',
    '🪓' => 'yxa',
    '⛏' => 'hacka',
    '⚒' => 'hammare och hacka',
    '🛠' => 'hammare och skiftnyckel',
    '🗡' => 'dolk',
    '⚔' => 'korslagda svärd',
    '💣' => 'bomb',
    '🪃' => 'boomerang',
    '🏹' => 'pil och båge',
    '🛡' => 'sköld',
    '🪚' => 'fogsvans',
    '🔧' => 'skiftnyckel',
    '🪛' => 'skruvmejsel',
    '🔩' => 'skruv och mutter',
    '⚙' => 'kugghjul',
    '🗜' => 'skruvtving',
    '⚖' => 'balansvåg',
    '🦯' => 'blindkäpp',
    '🔗' => 'länk',
    '⛓' => 'kedjor',
    '🪝' => 'krok',
    '🧰' => 'verktygslåda',
    '🧲' => 'magnet',
    '🪜' => 'stege',
    '🪏' => 'spade',
    '⚗' => 'retort',
    '🧪' => 'provrör',
    '🧫' => 'petriskål',
    '🧬' => 'DNA',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'tv-satellit',
    '💉' => 'spruta',
    '🩸' => 'blodsdroppe',
    '💊' => 'piller',
    '🩹' => 'plåster',
    '🩼' => 'krycka',
    '🩺' => 'stetoskop',
    '🩻' => 'röntgen',
    '🚪' => 'dörr',
    '🛗' => 'hiss',
    '🪞' => 'spegel',
    '🪟' => 'fönster',
    '🛏' => 'säng',
    '🛋' => 'soffa och lampa',
    '🪑' => 'stol',
    '🚽' => 'toalett',
    '🪠' => 'vaskrensare',
    '🚿' => 'dusch',
    '🛁' => 'badkar',
    '🪤' => 'musfälla',
    '🪒' => 'rakhyvel',
    '🧴' => 'lotionflaska',
    '🧷' => 'säkerhetsnål',
    '🧹' => 'kvast',
    '🧺' => 'korg',
    '🧻' => 'toarulle',
    '🪣' => 'spann',
    '🧼' => 'tvål',
    '🫧' => 'bubblor',
    '🪥' => 'tandborste',
    '🧽' => 'tvättsvamp',
    '🧯' => 'brandsläckare',
    '🛒' => 'shoppingvagn',
    '🚬' => 'cigarett',
    '⚰' => 'kista',
    '🪦' => 'gravsten',
    '⚱' => 'begravningsurna',
    '🧿' => 'onda ögat-sten',
    '🪬' => 'hamsa',
    '🗿' => 'staty',
    '🪧' => 'plakat',
    '🪪' => 'ID-kort',
    '🏧' => 'bankomat',
    '🚮' => 'soptunna',
    '🚰' => 'dricksvatten',
    '♿' => 'rullstolssymbol',
    '🚹' => 'herrtoalett',
    '🚺' => 'damtoalett',
    '🚻' => 'wc-skylt',
    '🚼' => 'bebissymbol',
    '🚾' => 'WC',
    '🛂' => 'passkontroll',
    '🛃' => 'tull',
    '🛄' => 'bagagehämtning',
    '🛅' => 'kvarlämnat bagage',
    '⚠' => 'varning',
    '🚸' => 'passerande barn',
    '⛔' => 'förbud mot infart med fordon',
    '🚫' => 'förbjudet',
    '🚳' => 'förbud mot trafik med cykel',
    '🚭' => 'rökning förbjuden',
    '🚯' => 'skräpa inte ner',
    '🚱' => 'ej dricksvatten',
    '🚷' => 'förbud mot gångtrafik',
    '📵' => 'mobil förbjuden',
    '🔞' => 'ej för minderåriga',
    '☢' => 'varning för strålrisk',
    '☣' => 'biologisk fara',
    '⬆' => 'uppåtpil',
    '↗' => 'uppåtpil höger',
    '➡' => 'högerpil',
    '↘' => 'nedåtpil höger',
    '⬇' => 'nedåtpil',
    '↙' => 'nedåtpil vänster',
    '⬅' => 'vänsterpil',
    '↖' => 'uppåtpil vänster',
    '↕' => 'pil upp och ned',
    '↔' => 'pil höger och vänster',
    '↩' => 'svängd vänsterpil',
    '↪' => 'svängd högerpil',
    '⤴' => 'svängd uppåtpil',
    '⤵' => 'svängd nedåtpil',
    '🔃' => 'vertikala pilar medurs',
    '🔄' => 'pilar moturs',
    '🔙' => 'Back med vänsterpil',
    '🔚' => 'End med högerpil',
    '🔛' => 'ON! med pil höger och vänster ovanför',
    '🔜' => 'Soon med högerpil ovanför',
    '🔝' => 'Top med uppåtpil',
    '🛐' => 'plats för tillbedjan',
    '⚛' => 'symbol för atom',
    '🕉' => 'aum-tecken',
    '✡' => 'davidsstjärna',
    '☸' => 'livets hjul',
    '☯' => 'yin och yang',
    '✝' => 'latinskt kors',
    '☦' => 'ortodoxt kors',
    '☪' => 'stjärna och halvmåne',
    '☮' => 'fredssymbol',
    '🕎' => 'menora',
    '🔯' => 'sexuddig stjärna med prick',
    '🪯' => 'khanda',
    '♈' => 'Väduren',
    '♉' => 'Oxen',
    '♊' => 'Tvillingarna',
    '♋' => 'Kräftan',
    '♌' => 'Lejonet',
    '♍' => 'Jungfrun',
    '♎' => 'Vågen',
    '♏' => 'Skorpionen',
    '♐' => 'Skytten',
    '♑' => 'Stenbocken',
    '♒' => 'Vattumannen',
    '♓' => 'Fiskarna',
    '⛎' => 'Ormbäraren',
    '🔀' => 'blanda låtar',
    '🔁' => 'upprepning',
    '🔂' => 'upprepa en låt',
    '▶' => 'uppspelningsknapp',
    '⏩' => 'framåtspolningsknapp',
    '⏭' => 'knapp för nästa spår',
    '⏯' => 'knapp för spela eller pausa',
    '◀' => 'bakåtspolningsknapp',
    '⏪' => 'knapp för snabbspola tillbaka',
    '⏮' => 'knapp för sista spåret',
    '🔼' => 'uppåtknapp',
    '⏫' => 'dubbla uppåtpilar',
    '🔽' => 'nedåtknapp',
    '⏬' => 'dubbla nedåtpilar',
    '⏸' => 'pausknapp',
    '⏹' => 'stoppknapp',
    '⏺' => 'inspelningsknapp',
    '⏏' => 'utmatningsknapp',
    '🎦' => 'bio',
    '🔅' => 'låg ljusstyrka',
    '🔆' => 'hög ljusstyrka',
    '📶' => 'stapel signalstyrka',
    '🛜' => 'trådlös',
    '📳' => 'vibrationsläge',
    '📴' => 'avstängd mobil',
    '♀' => 'kvinnosymbol',
    '♂' => 'manssymbol',
    '⚧' => 'transgendersymbol',
    '✖' => 'multiplicera',
    '➕' => 'addera',
    '➖' => 'subtrahera',
    '➗' => 'dividera',
    '🟰' => 'fetstilt likamedtecken',
    '♾' => 'oändlighet',
    '‼' => 'dubbla utropstecken',
    '⁉' => 'utropstecken och frågetecken',
    '❓' => 'rött frågetecken',
    '❔' => 'vitt frågetecken',
    '❕' => 'vitt utropstecken',
    '❗' => 'rött utropstecken',
    '〰' => 'vågigt tankstreck',
    '💱' => 'valutaväxling',
    '💲' => 'dollartecken',
    '⚕' => 'medicinsk symbol',
    '♻' => 'återvinningssymbol',
    '⚜' => 'fransk lilja',
    '🔱' => 'treudd',
    '📛' => 'namnskylt',
    '🔰' => 'japansk symbol för nybörjare',
    '⭕' => 'tung stor cirkel',
    '✅' => 'vit bockmarkering',
    '☑' => 'kryssruta med bockmarkering',
    '✔' => 'bockmarkering',
    '❌' => 'rött kryss',
    '❎' => 'vitt kryss i ruta',
    '➰' => 'ögla',
    '➿' => 'dubbel ögla',
    '〽' => 'japansk kommatering',
    '✳' => 'åttauddig spetsig stjärna',
    '✴' => 'åttauddig stjärna',
    '❇' => 'glittra',
    '™' => 'skyddat varumärke',
    '🫟' => 'stänk',
    '🔠' => 'versaler',
    '🔡' => 'gemener',
    '🔢' => 'siffror',
    '🔣' => 'specialtecken',
    '🔤' => 'bokstäver',
    '🅰' => 'blodgrupp A',
    '🆎' => 'blodgrupp AB',
    '🅱' => 'blodgrupp B',
    '🆑' => 'rensa-symbol',
    '🆒' => 'COOL-knapp',
    '🆓' => 'FREE-knapp',
    'ℹ' => 'information',
    '🆔' => 'ID-knapp',
    'Ⓜ' => 'm i en cirkel',
    '🆕' => 'NEW-knapp',
    '🆖' => 'NG-knapp',
    '🅾' => 'blodgrupp 0',
    '🆗' => 'OK-knapp',
    '🅿' => 'P-knapp',
    '🆘' => 'SOS-knapp',
    '🆙' => 'UP!-knapp',
    '🆚' => 'VS-knapp',
    '🈁' => 'japansk ”här”-knapp',
    '🈂' => 'japansk ”serviceavgift”-knapp',
    '🈷' => 'japansk ”månadsbelopp”-knapp',
    '🈶' => 'japansk ”inte gratis”-knapp',
    '🈯' => 'japansk ”reserverad”-knapp',
    '🉐' => 'japansk ”fynd”-knapp',
    '🈹' => 'japansk ”rabatt”-knapp',
    '🈚' => 'japansk ”gratis”-knapp',
    '🈲' => 'japansk ”förbjudet”-knapp',
    '🉑' => 'japansk ”godtagbart”-knapp',
    '🈸' => 'japansk ”användning”-knapp',
    '🈴' => 'japansk ”godkänt betyg”-knapp',
    '🈳' => 'japansk ”lediga rum”-knapp',
    '㊗' => 'japansk ”grattis”-knapp',
    '㊙' => 'japansk ”hemligt”-knapp',
    '🈺' => 'japansk ”öppet”-knapp',
    '🈵' => 'japansk ”fullbelagt”-knapp',
    '🔴' => 'röd cirkel',
    '🟠' => 'orange cirkel',
    '🟡' => 'gul cirkel',
    '🟢' => 'grön cirkel',
    '🔵' => 'blå cirkel',
    '🟣' => 'lila cirkel',
    '🟤' => 'brun cirkel',
    '⚫' => 'svart cirkel',
    '⚪' => 'vit cirkel',
    '🟥' => 'röd kvadrat',
    '🟧' => 'orange kvadrat',
    '🟨' => 'gul kvadrat',
    '🟩' => 'grön kvadrat',
    '🟦' => 'blå kvadrat',
    '🟪' => 'lila kvadrat',
    '🟫' => 'brun kvadrat',
    '⬛' => 'stor svart ruta',
    '⬜' => 'stor vit ruta',
    '◼' => 'mellanstor svart ruta',
    '◻' => 'mellanstor vit ruta',
    '◾' => 'mellanliten svart ruta',
    '◽' => 'mellanliten vit ruta',
    '▪' => 'liten svart ruta',
    '▫' => 'liten vit ruta',
    '🔶' => 'stor orange diamantform',
    '🔷' => 'stor blå diamantform',
    '🔸' => 'liten orange diamantform',
    '🔹' => 'liten blå romb',
    '🔺' => 'uppåtpekande röd triangel',
    '🔻' => 'nedåtpekande röd triangel',
    '💠' => 'diamantform med en prick',
    '🔘' => 'alternativknapp',
    '🔳' => 'vit fyrkantig knapp',
    '🔲' => 'svart fyrkantig knapp',
    '🏁' => 'schackrutig flagga',
    '🚩' => 'trekantig flagga',
    '🎌' => 'korsade flaggor',
    '🏴' => 'svart flagga',
    '🏳' => 'vit flagga',
];
